#
# spec file for package netdata
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define netdata_user    netdata
%define netdata_group   netdata

%define __builder ninja

Name:           netdata
Version:        1.46.1
Release:        1.1
Summary:        A system for distributed real-time performance and health monitoring
# netdata is GPL-3.0+, other licenses refer to included third-party software (see REDISTRIBUTED.md)
License:        Apache-2.0 AND BSD-2-Clause AND GPL-3.0-or-later AND MIT AND BSD-3-Clause AND LGPL-2.1-or-later AND OFL-1.1 AND CC-BY-4.0 AND WTFPL
Group:          System/Monitoring
URL:            http://my-netdata.io/
Source0:        https://github.com/netdata/%{name}/releases/download/v%{version}/%{name}-v%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        netdata-rpmlintrc
Patch0:         netdata-logrotate-su.patch
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  cups-devel
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  git-core
BuildRequires:  judy-devel
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  snappy-devel
BuildRequires:  golang(API) >= 1.22
BuildRequires:  pkgconfig(grpc)
BuildRequires:  pkgconfig(json)
BuildRequires:  pkgconfig(libcap)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libelf)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(libmnl)
BuildRequires:  pkgconfig(libmosquitto)
BuildRequires:  pkgconfig(libnetfilter_acct)
BuildRequires:  pkgconfig(libuv)
BuildRequires:  pkgconfig(libwebsockets)
BuildRequires:  pkgconfig(openssl)
# Broken with current upstream protobuf - uses bundled copy
# BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(yajl)
BuildRequires:  pkgconfig(yaml-0.1)
BuildRequires:  pkgconfig(zlib)
Requires(pre):  shadow permissions
Recommends:     PyYAML
Recommends:     curl
Recommends:     iproute-tc
Recommends:     lm_sensors
Recommends:     nmap-ncat
Recommends:     openssl(cli)
Suggests:       logrotate
Suggests:       nodejs
%if 0%{?suse_version} > 1550
BuildRequires:  python3
%else
BuildRequires:  python311
%endif
%ifarch %ix86 x86_64 aarch64
BuildRequires:  pkgconfig(xenstat)
%endif
BuildRequires:  pkgconfig(libipmimonitoring)
Provides:       group(%{netdata_group})
Provides:       user(%{netdata_user})

%description
Netdata is a system for distributed real-time performance and
health monitoring.
It provides insights, in real-time, of everything happening on the
system it runs on (including applications such as web and database
servers), using interactive web dashboards.

%package plugin-cups
Summary:        The CUPS metrics collection plugin for the Netdata Agent
Enhances:       cups
Requires:       netdata = %{version}
Supplements:    netdata
Provides:       netdata:%{_libexecdir}/%{name}/plugins.d/cups.plugin

%description plugin-cups
This plugin allows the Netdata Agent to collect metrics from the
Common UNIX Printing System.

%files plugin-cups
%attr(0750,root,%{netdata_user}) %{_libexecdir}/%{name}/plugins.d/cups.plugin

%package plugin-freeipmi
Summary:        The FreeIPMI metrics collection plugin for the Netdata Agent
Enhances:       freeipmi
Requires:       netdata = %{version}
Enhances:       netdata
Provides:       netdata:%{_libexecdir}/%{name}/plugins.d/freeipmi.plugin

%description plugin-freeipmi
This plugin allows the Netdata Agent to collect metrics from
hardware using FreeIPMI.

%post plugin-freeipmi
%set_permissions

%files plugin-freeipmi
%attr(0750,root,%{netdata_user}) %{_libexecdir}/%{name}/plugins.d/freeipmi.plugin

%package plugin-nfacct
Summary:        The NFACCT metrics collection plugin for the Netdata Agent
Requires:       netdata = %{version}
Enhances:       netdata
Provides:       netdata:%{_libexecdir}/%{name}/plugins.d/nfacct.plugin

%description plugin-nfacct
This plugin allows the Netdata Agent to collect metrics from the
firewall using NFACCT objects.

%post plugin-nfacct
%set_permissions

%files plugin-nfacct
%attr(0750,root,%{netdata_user}) %{_libexecdir}/%{name}/plugins.d/nfacct.plugin

%package plugin-chartsd
Summary:        The charts.d metrics collection plugin for the Netdata Agent
Requires:       bash
Requires:       netdata = %{version}
Enhances:       nut
Enhances:       apcupsd
Enhances:       iw
Suggests:       sudo
Enhances:       netdata
Provides:       netdata:%{_libexecdir}/%{name}/plugins.d/charts.d.plugin
BuildArch:      noarch

%description plugin-chartsd
This plugin adds a selection of additional collectors written in
shell script to the Netdata Agent.
It includes collectors for NUT, APCUPSD, LibreSWAN, OpenSIPS, and
Wireless access point statistics.

%files plugin-chartsd
%defattr(0750,root,%{netdata_user},0750)
%{_libexecdir}/%{name}/plugins.d/charts.d.plugin
%{_libexecdir}/%{name}/plugins.d/charts.d.dryrun-helper.sh
%{_libexecdir}/%{name}/charts.d/
%defattr(0644,root,%{netdata_user},0644)
%{_prefix}/lib/%{name}/conf.d/charts.d.conf
%{_prefix}/lib/%{name}/conf.d/charts.d/

%package plugin-pythond
Summary:        The python.d metrics collection plugin for the Netdata Agent
Requires:       netdata = %{version}
Enhances:       netdata
%if 0%{?suse_version} > 1550
Requires:       python3
%else
Requires:       python311
%endif
Suggests:       sudo
Provides:       netdata:%{_libexecdir}/%{name}/plugins.d/python.d.plugin
BuildArch:      noarch

%description plugin-pythond
This plugin adds a selection of additional collectors written in
Python to the Netdata Agent.
Many of the collectors provided by this package are also available
in netdata-plugin-go. In msot cases, you probably want to use those
versions instead of the Python versions.

%files plugin-pythond
%defattr(0750,root,%{netdata_user},0750)
%{_libexecdir}/%{name}/plugins.d/python.d.plugin
%{_libexecdir}/%{name}/python.d
%defattr(0640,root,%{netdata_user},0640)
%{_prefix}/lib/%{name}/conf.d/python.d.conf
%{_prefix}/lib/%{name}/conf.d/python.d

%package plugin-go
Summary:        The go.d metrics collection plugin for the Netdata Agent
Requires:       netdata = %{version}
Suggests:       nvme-cli
Suggests:       sudo
Supplements:    netdata
Provides:       netdata:%{_libexecdir}/%{name}/plugins.d/go.d.plugin

%description plugin-go
This plugin adds a selection of additional collectors written in Go
to the Netdata Agent.
A significant percentage of the application specific collectors
provided by Netdata are part of this plugin, so most users will
want it installed.

%post plugin-go
%set_permissions

%files plugin-go
%defattr(0750,root,%{netdata_user},0750)
# CAP_NET_ADMIN needed for WireGuard collector
# CAP_NET_RAW needed for ping collector
%caps(cap_net_admin,cap_net_raw=eip) %{_libexecdir}/%{name}/plugins.d/go.d.plugin
%defattr(0644,root,%{netdata_user},0644)
%{_prefix}/lib/%{name}/conf.d/go.d.conf
%{_prefix}/lib/%{name}/conf.d/go.d

%package plugin-apps
Summary:        The per-application metrics collection plugin for the Netdata Agent
Requires:       netdata = %{version}
Enhances:       netdata
Provides:       netdata:%{_libexecdir}/%{name}/plugins.d/apps.plugin

%description plugin-apps
This plugin allows the Netdata Agent to collect per-application and
per-user metrics without using cgroups.

%post plugin-apps
%set_permissions

%files plugin-apps
%defattr(0750,root,%{netdata_user},0750)
# CAP_DAC_READ_SEARCH and CAP_SYS_PTRACE needed for data collection by the plugin.
%caps(cap_dac_read_search,cap_sys_ptrace=ep) %{_libexecdir}/%{name}/plugins.d/apps.plugin
%defattr(0644,root,%{netdata_user},0644)
%{_prefix}/lib/%{name}/conf.d/apps_groups.conf

%package plugin-slabinfo
Summary:        The slabinfo metrics collector for the Netdata Agent
Requires:       netdata = %{version}
Enhances:       netdata
Provides:       netdata:%{_libexecdir}/%{name}/plugins.d/slabinfo.plugin

%description plugin-slabinfo
This plugin allows the Netdata Agent to collect perfromance and
utilization metrics for the Linux kernel’s SLAB allocator.

%post plugin-slabinfo
%set_permissions

%files plugin-slabinfo
%defattr(0750,root,%{netdata_user},0750)
# CAP_DAC_READ_SEARCH needed to access the files the plugin reads to collect data.
%caps(cap_dac_read_search=ep) %{_libexecdir}/%{name}/plugins.d/slabinfo.plugin

%package plugin-perf
Summary:        The perf metrics collector for the Netdata Agent
Requires:       netdata = %{version}
Enhances:       netdata
Provides:       netdata:%{_libexecdir}/%{name}/plugins.d/perf.plugin

%description plugin-perf
This plugin allows the Netdata to collect metrics from the Linux
perf subsystem.

%post plugin-perf
%set_permissions

%files plugin-perf
%defattr(0750,root,%{netdata_user},0750)
# Either CAP_SYS_ADMIN or CAP_PERFMON needed for data collection
%caps(cap_perfmon=ep) %{_libexecdir}/%{name}/plugins.d/perf.plugin

%package plugin-debugfs
Summary:        The debugfs metrics collector for the Netdata Agent
Requires:       netdata = %{version}
Enhances:       netdata
Provides:       netdata:%{_libexecdir}/%{name}/plugins.d/debugfs.plugin

%description plugin-debugfs
This plugin allows the Netdata Agent to collect Linux kernel
metrics exposed through debugfs.

%post plugin-debugfs
%set_permissions

%files plugin-debugfs
# CAP_DAC_READ_SEARCH required for data collection.
%caps(cap_dac_read_search=ep) %attr(0750,root,%{netdata_user}) %{_libexecdir}/%{name}/plugins.d/debugfs.plugin

%package plugin-logs-management
Summary:        The logs-management plugin for the Netdata Agent
Requires:       netdata = %{version}
Enhances:       netdata
Provides:       netdata:%{_libexecdir}/%{name}/plugins.d/logs-management.plugin

%description plugin-logs-management
This plugin allows the Netdata Agent to collect logs from the system
and parse them to extract metrics.

%files plugin-logs-management
%defattr(0644,root,%{netdata_user},0755)
%{_prefix}/lib/%{name}/conf.d/logsmanagement.d.conf
%{_prefix}/lib/%{name}/conf.d/logsmanagement.d
%defattr(0750,root,%{netdata_user},0750)
# CAP_DAC_READ_SEARCH and CAP_SYSLOG needed for data collection.
%caps(cap_dac_read_search,cap_syslog=ep) %attr(0750,root,%{netdata_user}) %{_libexecdir}/%{name}/plugins.d/logs-management.plugin

%package plugin-network-viewer
Summary:        The network viewer plugin for the Netdata Agent
Requires:       netdata = %{version}
Enhances:       netdata
Provides:       netdata:%{_libexecdir}/%{name}/plugins.d/network-viewer.plugin

%description plugin-network-viewer
This plugin allows the Netdata Agent to provide network connection
mapping functionality for use in netdata Cloud.

%files plugin-network-viewer
%defattr(0750,root,%{netdata_user},0750)
# CAP_SYS_ADMIN, CAP_SYS_PTRACE and CAP_DAC_READ_SEARCH needed for data collection.
%caps(cap_sys_admin,cap_sys_ptrace,cap_dac_read_search=ep) %attr(0750,root,%{netdata_user}) %{_libexecdir}/%{name}/plugins.d/network-viewer.plugin

%package plugin-systemd-journal
Summary:        The systemd-journal plugin for the Netdata Agent
Requires:       netdata = %{version}
Enhances:       netdata
Provides:       netdata:%{_libexecdir}/%{name}/plugins.d/systemd-journal.plugin

%description plugin-systemd-journal
This plugin allows the Netdata Agent to present entries from the systemd
journal on Netdata Cloud or the local Agent Dashboard.

%files plugin-systemd-journal
%defattr(0750,root,%{netdata_user},0750)
# CAP_DAC_READ_SEARCH required for data collection.
%caps(cap_dac_read_search=ep) %attr(0750,root,%{netdata_user}) %{_libexecdir}/%{name}/plugins.d/systemd-journal.plugin

%prep
%autosetup -n %{name}-v%{version} -p1
sed -i 's,%{_bindir}/env bash,/bin/bash,' src/claim/%{name}-claim.sh.in

%if 0%{?sle_version} >= 150200 || 0%{?suse_version} > 1500
%if 0%{?suse_version} > 1550
sed -i 's,^pybinary=.*,pybinary=%{_bindir}/python3,' src/collectors/python.d.plugin/python.d.plugin.in
%else
sed -i 's,^pybinary=.*,pybinary=%{_bindir}/python3.11,' src/collectors/python.d.plugin/python.d.plugin.in
%endif

tar -xf %{SOURCE1} -C src/go/collectors/go.d.plugin
%endif

%build
export GOFLAGS=-mod=vendor
%ifnarch ppc64
    export GOFLAGS="$GOFLAGS -buildmode=pie"
%endif

# Agent-Cloud Link and the Prometheus exporter require protobuf,
# which is broken with openSUSE’s version (too new).
# Bundled protobuf requires Abseil, which this build system
# will fetch from a Git repo.
# They explicitly disable disconnected mode.
%cmake \
    -DENABLE_PLUGIN_EBPF=False \
    -DENABLE_ACLK=False -DENABLE_EXPORTER_PROMETHEUS_REMOTE_WRITE=False \
    -DNETDATA_USER=%{netdata_user} \
    -DCMAKE_INSTALL_PREFIX=/
%cmake_build

%install
%cmake_install
install -D -m 0644 %{buildroot}%{_prefix}/lib/%{name}/system/systemd/%{name}.service %{buildroot}%{_unitdir}/%{name}.service
install -D -m 0644 %{buildroot}%{_prefix}/lib/%{name}/system/logrotate/%{name} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -D -m 0644 system/%{name}.conf %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

ln -s -f %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

sed -i 's,^#!%{_bindir}/env bash,#!/bin/bash,;s,^#!%{_bindir}/env sh,#!/bin/sh,' \
    %{buildroot}%{_libexecdir}/%{name}/plugins.d/* \
    %{buildroot}%{_sysconfdir}/%{name}/edit-config

# Respect FHS
mv %{buildroot}%{_sysconfdir}/%{name}/edit-config %{buildroot}%{_libexecdir}/%{name}
sed -i 's|%{_prefix}/lib|%{_libdir}|' %{buildroot}%{_libexecdir}/%{name}/edit-config

# This should be opt-in, not opt-out.
# Disable statistics by default.
touch %{buildroot}%{_sysconfdir}/%{name}/.opt-out-from-anonymous-statistics

install -m 755 -d %{buildroot}%{_localstatedir}/cache/%{name}
install -m 755 -d %{buildroot}%{_localstatedir}/log/%{name}
install -m 755 -d %{buildroot}%{_localstatedir}/lib/%{name}/registry

rm %{buildroot}%{_prefix}/lib/%{name}/conf.d/netdata-updater.conf
rm -r %{buildroot}%{_prefix}/lib/%{name}/system
rm %{buildroot}%{_libexecdir}/%{name}/install-service.sh
rm %{buildroot}%{_libexecdir}/%{name}/netdata-updater.sh

# This is a suid binary that is supposed to allow Netdata to run
# some privileged commands. Not packaged due to security concerns.
rm %{buildroot}%{_libexecdir}/%{name}/plugins.d/ndsudo

%fdupes %{buildroot}/lib %{buildroot}%{_libexecdir} %{buildroot}%{_datadir}

%check

%pre
getent group %{netdata_group} >/dev/null || \
    %{_sbindir}/groupadd -r %{netdata_group}
getent passwd %{netdata_user} >/dev/null || \
    %{_sbindir}/useradd -r -g %{netdata_group} -s /bin/false \
    -c "netdata daemon user" -d %{_localstatedir}/lib/empty %{netdata_user}
%{_sbindir}/usermod -g %{netdata_group} %{netdata_user} >/dev/null
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%doc README.md CHANGELOG.md
%license LICENSE REDISTRIBUTED.md

%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}

%dir %{_libexecdir}/%{name}
%dir %{_libexecdir}/%{name}/plugins.d
%{_libexecdir}/%{name}/plugins.d/*.sh
%exclude %{_libexecdir}/%{name}/plugins.d/charts.d.dryrun-helper.sh
%{_libexecdir}/%{name}/plugins.d/cgroup-network
%{_libexecdir}/%{name}/plugins.d/ioping.plugin
%{_libexecdir}/%{name}/plugins.d/local-listeners
%{_libexecdir}/%{name}/plugins.d/loopsleepms.sh.inc
%ifarch %ix86 x86_64 aarch64
%{_libexecdir}/%{name}/plugins.d/xenstat.plugin
%endif

%dir %{_prefix}/lib/%{name}
%dir %{_prefix}/lib/%{name}/conf.d
%dir %{_prefix}/lib/%{name}/conf.d/schema.d
%{_prefix}/lib/%{name}/conf.d/health.d
%{_prefix}/lib/%{name}/conf.d/statsd.d
%{_prefix}/lib/%{name}/conf.d/vnodes
%{_prefix}/lib/%{name}/conf.d/exporting.conf
%{_prefix}/lib/%{name}/conf.d/health_alarm_notify.conf
%{_prefix}/lib/%{name}/conf.d/health_email_recipients.conf
%{_prefix}/lib/%{name}/conf.d/ioping.conf
%{_prefix}/lib/%{name}/conf.d/netdata.conf
%{_prefix}/lib/%{name}/conf.d/stream.conf
%{_prefix}/lib/%{name}/conf.d/schema.d/*.json

%{_sbindir}/%{name}
%{_sbindir}/%{name}-claim.sh
%{_sbindir}/%{name}cli
%{_sbindir}/rc%{name}
%{_sbindir}/systemd-cat-native

%{_unitdir}/%{name}.service

%attr(-,root,%{netdata_group}) %dir %{_datadir}/%{name}
%attr(-,root,%{netdata_group}) %{_datadir}/%{name}/web

%attr(0750,%{netdata_user},root) %dir %{_localstatedir}/cache/%{name}
%attr(0750,%{netdata_user},root) %dir %{_localstatedir}/log/%{name}
%attr(0750,%{netdata_user},root) %dir %{_localstatedir}/lib/%{name}

# Do not allow users to read netdata config dir and files as they can
# contain passwords!
%defattr(0640,root,%{netdata_group},0750)

%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/health.d
%dir %{_sysconfdir}/%{name}/python.d
%dir %{_sysconfdir}/%{name}/statsd.d

%config(noreplace) %{_sysconfdir}/%{name}/.opt-out-from-anonymous-statistics
%config(noreplace) %{_sysconfdir}/%{name}/*.conf
# used for statistics
%config %{_sysconfdir}/%{name}/.install-type

%attr(0750,root,%{netdata_group}) %{_libexecdir}/%{name}/edit-config

%changelog
* Sat Jun 22 2024 Mia Herkt <mia@0x0.st>
- Update to 1.46.1
  * Fixed Rspamd collector to handle responses without FuzzyHashes
    (go.d/rspamd)
    gh#netdata/netdata#17974
  * Added validation for dyncfg job names to prevent invalid
    characters (go.d.plugin)
    gh#netdata/netdata#17971
  * Fixed cgroups version detection on non-systemd nodes with
    cgroups v1 (cgroups.plugin)
    gh#netdata/netdata#17969
  * Improved check to ensure that job names in configuration files
    do not contain colons (go.d.plugin)
    gh#netdata/netdata#17967
  * Fixed space percentage calculation in dbengine retention chart
    gh#netdata/netdata#17963
* Wed Jun 19 2024 Mia Herkt <mia@0x0.st>
- Update to 1.46.0
  See https://github.com/netdata/netdata/releases/tag/v1.46.0
  * This bumps the Go version requirement to 1.22.0
* Sat Jun  8 2024 Mia Herkt <mia@0x0.st>
- Update to 1.45.6
  * Fixed a service discovery issue that affected applications
    without parameters in their command line
    gh#netdata/netdata#17763 (go.d.plugin)
* Sat May 25 2024 Mia Herkt <mia@0x0.st>
- Update to 1.45.5
  * Fixed streaming sender functions payload corruption
    gh#netdata/netdata#17696
  * Fixed crashes due to missing dimension IDs (external protocol)
    by detecting incorrect syntax and disabling plugins
    gh#netdata/netdata#17690
  * Fixed calculation issue in the go.d/cockroachdb collector
    gh#netdata/netdata#17659
- Changes in 1.45.4
  * Added missing update_every property to the health prototype
    JSON schema
    gh#netdata/netdata#17613
  * Fixed issue where parent alerts remained active after child
    disconnection, by resetting health on child disconnect
    gh#netdata/netdata#17612
  * Increased spawn server command size and added shutdown
    safeguard to prevent crashes from command size limit exceeded
    gh#netdata/netdata#17566
  * Fixed error code reporting for failed data insertion in SQLite
    gh#netdata/netdata#17508
  * Fixed issue with name-only label matching
    gh#netdata/netdata#17482
  * Improved termination handling: start watcher thread post-fork,
    preventing main process from waiting indefinitely on TERM
    signal
    gh#netdata/netdata#17436
  * Fixed priority order for alarms and alarm templates: now,
    alarms are applied before alarm templates consistently,
    regardless of their order in configuration files
    gh#netdata/netdata#17398
  * Added option for health table cleanup with
    'netdata -W sqlite-alert-cleanup' command
    gh#netdata/netdata#17385
* Fri Apr 12 2024 Mia Herkt <mia@0x0.st>
- Update to 1.45.3
  This release mitigates a security issue in ndsudo.
  openSUSE packages are unaffected because they do not contain
  the ndsudo tool—for security reasons.
  See https://github.com/netdata/netdata/security/advisories/GHSA-pmhq-4cxq-wj93
  * Resolved an issue that prevented the "percentage" option from
    functioning correctly in alert lookups
    gh#netdata/netdata#17391
  * Increased the default minimum thread stack size to 1 MB to
    address potential stability issues caused by the musl libc's
    smaller default (128kB)
    gh#netdata/netdata#17317
* Wed Apr 10 2024 Mia Herkt <mia@0x0.st>
- Update to 1.45.2
  * Improved PostgreSQL/MySQL local listener discovery to
    automatically check for connections using both TCP and Unix
    sockets, enabling support for passwordless Unix socket
    connections
    gh#netdata/netdata#17304
    gh#netdata/netdata#17305
  * Fixed an issue that prevented negative matching of host/chart
    labels in alert configurations
    gh#netdata/netdata#17290
    gh#netdata/netdata#17292
  * Improved go.d.plugin stability by preventing Netdata from
    shutting down the entire plugin due to an issue with
    registering jobs for unregistered modules
    gh#netdata/netdata#17289
  * Improved go.d.plugin HTTP requests now include a UserAgent
    string, enhancing identification in server log
    gh#netdata/netdata#17286
  * Improved Nginx discovery in go.d.plugin by automatically trying
    multiple status endpoints when discovering Nginx containers
    gh#netdata/netdata#17285
  * Fixed a go.d.plugin panic that could occur when using the
    Unbound collector with TLS
    gh#netdata/netdata#17283
  * Fixed a libyaml linking issue
    gh#netdata/netdata#17276
  * Improved go.d.plugin configuration validation, preventing
    unexpected or invalid options through dynamic configurations
    gh#netdata/netdata#17269
* Thu Mar 28 2024 Mia Herkt <mia@0x0.st>
- Update to 1.45.1
  See https://github.com/netdata/netdata/releases/tag/v1.45.0
  and https://github.com/netdata/netdata/releases/tag/v1.45.1
- Build system switched to CMake. There are some issues with it,
  see https://github.com/netdata/netdata/discussions/17287
- Disabled Agent-Cloud-Link and Prometheus exporter due to build
  system woes and incompatible protobuf on openSUSE.
- go.d.plugin is now bundled with each Netdata release
- Added plugins:
  * logs-management
  * network-viewer
  * systemd-journal
* Sun Mar 17 2024 Mia Herkt <mia@0x0.st>
- Update to 1.44.3 (go.d.plugin 0.58.1)
  See https://github.com/netdata/go.d.plugin/tree/v0.58.1
  and https://github.com/netdata/go.d.plugin/tree/v0.58.0
  * Improved handling of slow queries and CPU usage of the ACLKSYNC
    thread.
    gh#netdata/netdata#16838
  * Improved error handling for listen bind failures. Instead of
    terminating fatally, Netdata now exits gracefully.
    gh#netdata/netdata#16937
  * Fixed invalid alert durations in health log entries.
    gh#netdata/netdata#16931
  * Fixed a race condition during analytics data setup, preventing
    potential Netdata crashes.
    gh#netdata/netdata#16929
  * - Changes in 1.44.2
  * Fixed an inconsistency where the NETDATA_LOG_LEVEL environment
    variable did not affect log level in Docker containers.
    gh#netdata/netdata#16943
  * Fixed inconsistent log severity across sources: log severity
    level setting now work for all Netdata log sources (daemon,
    collector, health, access, aclk).
    gh#netdata/netdata#16922
  * Fixed a bug in chartd.d.plugin that prevented loading of its
    modules configuration files.
    gh#netdata/netdata#16939
  * Fixed inaccurate server type identification in Netdata Cloud
    for FreeBSD jails. Jails are now recognized correctly.
    gh#netdata/netdata#16858
  * Fixed a bug that prevented the edit-config script from running
    correctly in Podman containers. The script now accurately
    identifies container environments.
    gh#netdata/netdata#16825
  * Fixed a bug that caused excessive logging of "Using host prefix
    directory" messages.
    gh#netdata/netdata#16814
  * Fixed incorrect label source for apps.plugin charts, ensuring
    they are now accessible when querying Prometheus metrics.
    gh#netdata/netdata#16810
  * Fixed a bug in the cgroups.plugin that could lead to crashes.
    Additionally, addressed incorrect thread name during fatal
    Agent exits.
    gh#netdata/netdata#16771
  * Fixed a race condition related to pthread_detach() calls,
    preventing potential Netdata crashes during thread creation.
    gh#netdata/netdata#16760
  * Fixed a bug that caused "maximum number of cgroups reached"
    messages to spam logs.
    gh#netdata/netdata#16730
  * Fixed missing host label streaming from child nodes: host
    labels are now transmitted reliably to parent nodes.
    gh#netdata/netdata#16821
  * Fixes a bug in clock resolution calculation that prevented some
    data collection plugins from working correctly.
    gh#netdata/netdata#16720
  * Fixed a bug that caused Netdata to crash when calculating
    database size due to missing or single datafiles.
    gh#netdata/netdata#16699
  * Fixed a bug that caused the cups.plugin to not terminate upon
    receiving a SIGPIPE (Broken Pipe) signal.
    gh#netdata/netdata#16691
  * Fixed a reference counting issue that could lead to Netdata
    crashes.
    gh#netdata/netdata#16687
  * Fixed charts context and family definitions of exporting
    engine.
    gh#netdata/netdata#16683
  * Fixed a bug that could cause crashes when processing web
    requests.
    gh#netdata/netdata#16664
  * Fixed improper handling of the dbengine event loop during
    shutdown.
    gh#netdata/netdata#16658
  * Fixed a potential memory corruption issue in database code.
    gh#netdata/netdata#16654
  * Fixed "response too big" error for Systemd-journal: addressed
    limitations by raising the maximum web response size.
    gh#netdata/netdata#16649
  * Fixed compilation issues with --disable-dbengine: addressed
    errors that prevented successful builds when this flag was
    used.
    gh#netdata/netdata#16611
  * Fixed labels corruption due to duplicate key/value pairs.
    Additionally, addressed logging errors that occurred during
    fatal Agent exits. (commit, @ktsaou)
  * Update go.d.plugin to v0.58.0.
    gh#netdata/netdata#16725.
* Wed Feb  7 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Provide user/group symbol for the user generated during pre.
* Thu Dec 14 2023 Mia Herkt <mia@0x0.st>
- Update to 1.44.1
  See https://github.com/netdata/netdata/tree/v1.44.1
* Sat Dec  9 2023 ecsos <ecsos@opensuse.org>
- Update to v1.44.0 (go.d.plugin 0.57.2)
  See https://github.com/netdata/netdata/tree/v1.44.0
  and https://github.com/netdata/go.d.plugin/tree/v0.57.2
    https://github.com/netdata/go.d.plugin/tree/v0.57.1
    https://github.com/netdata/go.d.plugin/tree/v0.57.0
- Fix some forgotten code to use python311 in Leap.
* Mon Nov 13 2023 Andreas Schwab <schwab@suse.de>
- XEN only exists on x86 and aarch64
- Enable freeipmi plugin everywhere
* Mon Nov  6 2023 Mia Herkt <mia@0x0.st>
- Update to v1.43.2
  See https://github.com/netdata/netdata/releases/tag/v1.43.2
* Mon Nov  6 2023 Mia Herkt <mia@0x0.st>
- Update to v1.43.1 (go.d.plugin 0.56.4)
  See https://github.com/netdata/netdata/releases/tag/v1.43.1
  and https://github.com/netdata/go.d.plugin/releases/tag/v0.56.4
- Required golang bumped to 1.21
- Remove suid bits from freeipmi and nfacct plugins
* Mon Oct 23 2023 Mia Herkt <mia@0x0.st>
- Update to v1.43.0 (go.d.plugin 0.56.3)
  See https://github.com/netdata/netdata/releases/tag/v1.43.0
  and https://github.com/netdata/go.d.plugin/releases/tag/v0.56.3
    https://github.com/netdata/go.d.plugin/releases/tag/v0.56.2
    https://github.com/netdata/go.d.plugin/releases/tag/v0.56.1
    https://github.com/netdata/go.d.plugin/releases/tag/v0.56.0
* Sat Sep 23 2023 ecsos <ecsos@opensuse.org>
- Update to v1.42.4 (go.d.plugin 0.55.0)
  See https://github.com/netdata/netdata/releases/tag/v1.42.4
  and https://github.com/netdata/go.d.plugin/releases/tag/v0.55.0
  Also https://github.com/netdata/netdata/releases/tag/v1.42.3
* Sat Sep  9 2023 ecsos <ecsos@opensuse.org>
- Update to v1.42.2 (go.d.plugin 0.54.1)
  See https://github.com/netdata/netdata/releases/tag/v1.42.2
  and https://github.com/netdata/go.d.plugin/releases/tag/v0.54.1
  Also https://github.com/netdata/netdata/releases/tag/v1.42.1
  and https://github.com/netdata/netdata/releases/tag/v1.42.0
  and https://github.com/netdata/netdata/releases/tag/v1.41.0
- Switch Leap to python311 and remove python2 completely.
- Extended rpmlintrc to build also under Leap.
* Thu Jun 15 2023 Mia Herkt <mia@0x0.st>
- Update to v1.40.1 (go.d.plugin 0.54.0)
  See https://github.com/netdata/netdata/releases/tag/v1.40.1
  and https://github.com/netdata/go.d.plugin/releases/tag/v0.54.0
  Also https://github.com/netdata/netdata/releases/tag/v1.40.0
  and https://github.com/netdata/go.d.plugin/releases/tag/v0.53.2
- Split off plugin packages
* Sun May 21 2023 Mia Herkt <mia@0x0.st>
- Update to v1.39.1 (go.d.plugin 0.53.0)
  See https://github.com/netdata/netdata/releases/tag/v1.39.1
  and https://github.com/netdata/go.d.plugin/releases/tag/v0.53.0
* Thu May 11 2023 Mia Herkt <mia@0x0.st>
- Update to v1.39.0 (go.d.plugin 0.52.2)
  Changes:
  https://github.com/netdata/netdata/releases/tag/v1.39.0
  https://github.com/netdata/go.d.plugin/releases/tag/v0.52.0
  https://github.com/netdata/go.d.plugin/releases/tag/v0.52.1
  https://github.com/netdata/go.d.plugin/releases/tag/v0.52.2
  Note: Future package versions will be split, with each collector
  plugin getting its own package.
  See also https://blog.netdata.cloud/split-plugin-packages/
  On openSUSE, when using ZYpp-based package management, dependency
  resolution should cause these split-off packages to be installed
  automatically when upgrading from older versions, such that
  existing configurations should not be negatively affected by this
  change. For new installs, they will be soft dependencies, and
  only selected automatically when installation of recommended
  packages is requested.
- Refresh netdata-logrotate-su.patch
* Sun Apr  2 2023 Duarte Pousa <pousaduarte@gmail.com>
- Update go.d.plugin to 0.51.4
  See https://github.com/netdata/go.d.plugin/releases/tag/v0.51.4
* Tue Feb 21 2023 Mia Herkt <mia@0x0.st>
- Update to v1.38.1 (go.d.plugin 0.51.0)
  See https://github.com/netdata/netdata/releases/tag/v1.38.0
  and https://github.com/netdata/netdata/releases/tag/v1.38.1
* Wed Dec  7 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.37.1:
  * Parent agent crash when many children instances (re)connect at
    the same time, causing simultaneous SSL re-initialization.
  * Agent crash during dbengine database file rotation while a page
    is being read while being deleted.
  * Agent crash on metrics page alignment when metrics were stopped
    being collected for a long time and then started again.
  * Broken Fedora native packages.
  * Fix dbengine backfilling statistics.
* Thu Dec  1 2022 Mia Herkt <mia@0x0.st>
- Update to 1.37.0 (go.d.plugin 0.45.0)
  Collectors
  * New collectors
    + Add Pandas collector (python.d/pandas)
    gh#netdata/netdata#13773
    + Add NGINX Plus collector (go.d/nginxplus)
    gh#netdata/go.d.plugin#992
    + Add NVMe collector (go.d/nvme)
    gh#netdata/go.d.plugin#973
    + Add Ping collector (go.d/ping)
    gh#netdata/go.d.plugin#952
    + Add Cassandra collector (go.d/cassandra)
    gh#netdata/go.d.plugin#901
    + Add systemd-logind collector (go.d/logind)
    gh#netdata/go.d.plugin#786
    + Add Docker collector (go.d/docker)
    gh#netdata/go.d.plugin#760
    + Add PgBouncer collector (go.d/pgbouncer)
    gh#netdata/go.d.plugin#748
    + Add ProxySQL collector (go.d/proxysql)
    gh#netdata/go.d.plugin#703
  * Improvements
    + Allow statsd tags to modify chart metadata on the fly
    (stats.d.plugin)
    gh#netdata/netdata#14014
    + Add Cassandra icon to dashboard info (go.d/cassandra)
    gh#netdata/netdata#13975
    + Add ping dashboard info and alarms (go.d/ping)
    gh#netdata/netdata#13916
    + Add WMI Process dashboard info (go.d/wmi)
    gh#netdata/netdata#13910
    + Add processes dashboard info (go.d/wmi)
    gh#netdata/netdata#13910
    + Add TCP dashboard description (go.d/wmi)
    gh#netdata/netdata#13878
    + Add Cassandra dashboard description (go.d/cassandra)
    gh#netdata/netdata#13835
    + Respect NETDATA_INTERNALS_MONITORING (python.d.plugin)
    gh#netdata/netdata#13793
    + Add ZFS hit rate charts (proc.plugin)
    gh#netdata/netdata#13757
    + Add alarms filtering via config (python.d/alarms)
    gh#netdata/netdata#13701
    + Add ProxySQL dashboard info (go.d/proxysql)
    gh#netdata/netdata#13669
    + Update PostgreSQL dashboard info (go.d/postgres)
    gh#netdata/netdata#13661
    + Add _collect_job label (job name) to charts (python.d.plugin)
    gh#netdata/netdata#13648
    + Re-add chrome to the webbrowser group (apps.plugin)
    gh#netdata/netdata#13642
    + Add labels to charts (tc.plugin)
    gh#netdata/netdata#13634
    + Improve the gui and email app groups and improve GUI coverage
    (apps.plugin)
    gh#netdata/netdata#13631
    + Update Postgres "connections" dashboard info (go.d/postgres)
    gh#netdata/netdata#13619
    + Assorted updates for apps_groups.conf (apps.plugin)
    gh#netdata/netdata#13618
    + Add spiceproxy to proxmox group (apps.plugin)
    gh#netdata/netdata#13615
    + Improve coverage of Linux kernel threads (apps.plugin)
    gh#netdata/netdata#13612
    + Improve dashboard info for WAL and checkpoints
    (go.d/postgres)
    gh#netdata/netdata#13607
    + Update logind dashboard info (go.d/logind)
    gh#netdata/netdata#13597
    + Add collecting power state (python.d/nvidia_smi)
    gh#netdata/netdata#13580
    + Improve PostgreSQL dashboard info (go.d/postgres)
    gh#netdata/netdata#13573
    + Add apt group to apps_groups.conf (apps.plguin)
    gh#netdata/netdata#13571
    + Add more monitoring tools to apps_groups.conf (apps.plugin)
    gh#netdata/netdata#13566
    + Add docker dashboard info (go.d/docker)
    gh#netdata/netdata#13547
    + Add discovering chips, and features at runtime
    (python.d/sensors)
    gh#netdata/netdata#13545
    + Add summary dashboard for PostgreSQL (go.d/postgres)
    gh#netdata/netdata#13534
    + Add jupyter to apps_groups.conf (apps.plugin)
    gh#netdata/netdata#13533
    + Improve performance and add co-re support for more modules
    (ebpf.plugin)
    gh#netdata/netdata#13530
    + Use LVM UUIDs in chart ids for logical volumes (proc.plugin)
    gh#netdata/netdata#13525
    + Reduce CPU and memory usage (ebpf.plugin)
    gh#netdata/netdata#13397
    + Add 'domain' label to charts (go.d/whoisquery)
    gh#netdata/go.d.plugin#1002
    + Add 'source' label to charts (go.d/x509check)
    gh#netdata/go.d.plugin#1001
    + Add 'host' label to charts (go.d/portcheck)
    gh#netdata/go.d.plugin#1000
    + Add 'url' label to charts (go.d/httpcheck)
    gh#netdata/go.d.plugin#999
    + Remove pipeline instance from family and add it as a chart
    label (go.d/logstash)
    gh#netdata/go.d.plugin#998
    + Add http cache io/iops metrics (go.d/nginxplus)
    gh#netdata/go.d.plugin#997
    + Add resolver metrics (go.d/nginxplus)
    gh#netdata/go.d.plugin#996
    + Add MSSQL metrics (go.d/wmi)
    gh#netdata/go.d.plugin#991
    + Add IIS data collection job (go.d/web_log)
    gh#netdata/go.d.plugin#977
    + Add IIS metrics (go.d/wmi)
    gh#netdata/go.d.plugin#972
    + Add services metrics (go.d/wmi)
    gh#netdata/go.d.plugin#961
    + Resolve 'hostname' in job name (go.d.plugin)
    gh#netdata/go.d.plugin#959
    + Add processes metrics (go.d/wmi)
    gh#netdata/go.d.plugin#953
    + Resolve 'hostname' in URL (go.d.plugin)
    gh#netdata/go.d.plugin#941
    + Add TCP metrics (go.d/wmi)
    gh#netdata/go.d.plugin#938
    + Add collection of Table_open_cache_overflows (go.d/dns_query)
    gh#netdata/go.d.plugin#936
    + Allow to set a list of record types in config
    (go.d/dns_query)
    gh#netdata/go.d.plugin#912
    + Create a chart per server instead of a dimension per server
    (go.d/dns_query)
    gh#netdata/go.d.plugin#911
    + Respect NETDATA_INTERNALS_MONITORING env variable
    (go.d.plugin)
    gh#netdata/go.d.plugin#908
    + Add query status chart (go.d/dns_query)
    gh#netdata/go.d.plugin#903
    + Add collection of agent metrics (go.d/consul)
    gh#netdata/go.d.plugin#900
    + Create a chart per health check (go.d/consul)
    gh#netdata/go.d.plugin#899
    + Add collection of master link status (go.d/redis)
    gh#netdata/go.d.plugin#856
    + Add collection of master slave link metrics (go.d/redis)
    gh#netdata/go.d.plugin#851
    + Add collection of time elapsed since last RDB save
    (go.d/redis)
    gh#netdata/go.d.plugin#850
    + Add ping latency chart (go.d/redis)
    gh#netdata/go.d.plugin#849
    + Check for 'connect' privilege before querying database size
    (go.d/postgres)
    gh#netdata/go.d.plugin#845
    + Allow to set data collection job labels in config
    (go.d.plugin)
    gh#netdata/go.d.plugin#840
    + Improve histogram buckets dimensions (go.d/postgres)
    gh#netdata/go.d.plugin#833
    + Add acquired locks utilization chart (go.d/postgres)
    gh#netdata/go.d.plugin#831
    + Add _collect_job label (job name) to charts (go.d.plugin)
    gh#netdata/go.d.plugin#814
    + Add TCP socket connection support and the state path
    modification (go.d/phpfpm)
    gh#netdata/go.d.plugin#805
    + Create a dimension for every unit state (go.d/systemdunits)
    gh#netdata/go.d.plugin#795
    + Improve Galera state and status charts
    gh#netdata/go.d.plugin#779
    + Add discovering dhcp-ranges at runtime (go.d/dnsmasq_dhcp)
    gh#netdata/go.d.plugin#778
    + Add collecting image and volume stats (go.d/docker)
    gh#netdata/go.d.plugin#777
    + Add Percona MySQL compatibility (go.d/mysql)
    gh#netdata/go.d.plugin#776
    + Add collection of additional user statistics metrics
    gh#netdata/go.d.plugin#775
  * Bug fixes
    + Fix eBPF crashes on exit (ebpf.plugin)
    gh#netdata/netdata#14012
    + Fix not working on Oracle linux (ebpf.plugin)
    gh#netdata/netdata#13935
    + Fix retry logic when reading network interfaces speed
    (proc.plugin)
    gh#netdata/netdata#13893
    + Fix systemd chart update (ebpf.plugin)
    gh#netdata/netdata#13884
    + Fix handling qemu-1- prefix when extracting virsh domain
    gh#netdata/netdata#13866
    + Fix collection of carrier, duplex, and speed metrics when
    network interface is down (proc.plugin)
    gh#netdata/netdata#13850
    + Fix various issues (ebpf.plugin)
    gh#netdata/netdata#13624
    + Fix apps plugin users charts description (apps.plugin)
    gh#netdata/netdata#13621
    + Fix chart id length check (cgroups.plugin)
    gh#netdata/netdata#13601
    + Fix not respecting update_every for polling
    (python.d/nvidia_smi)
    gh#netdata/netdata#13579
    + Fix containers name resolution when Docker is a snap package
    (cgroups.plugin)
    gh#netdata/netdata#13523
    + Fix handling string and float values (go.d/nvme)
    gh#netdata/go.d.plugin#993
    + Fix handling ExpirationDate with space (go.d/whoisquery)
    gh#netdata/go.d.plugin#974
    + Fix query queryable databases (go.d/postgres)
    gh#netdata/go.d.plugin#960
    + Fix not respecting headers config option (go.d/pihole)
    gh#netdata/go.d.plugin#942
    + Fix dns_queries_percentage metric calculation (go.d/pihole)
    gh#netdata/go.d.plugin#922
    + Fix data collection when auth.bind query is not supported
    (go.d/dnsmasq)
    gh#netdata/go.d.plugin#902
    + Fix data collection when too many db tables and indexes
    (go.d/postgres)
    gh#netdata/go.d.plugin#857
    + Fix creation of bloat charts if no bloat metrics collected
    (go.d/postgres)
    gh#netdata/go.d.plugin#846
    + Fix unregistering connStr at runtime (go.d/postgres)
    gh#netdata/go.d.plugin#843
    + Fix bloat size percentage calculation (go.d/postgres)
    gh#netdata/go.d.plugin#841
    + Fix charts when binary log and MyISAM are disabled
    (go.d/mysql)
    gh#netdata/go.d.plugin#763
    + Fix data collection jobs cleanup on exit (go.d.plugin)
    gh#netdata/go.d.plugin#758
    + Fix handling the case when no images are found (go.d/docker)
    gh#netdata/go.d.plugin#739
  * Other
    + Don't let slow disk plugin thread delay shutdown
    gh#netdata/netdata#14044
    + Remove nginx_plus collector (python.d.plugin)
    gh#netdata/netdata#13995
    + Enable collecting ECC memory errors by default
    gh#netdata/netdata#13970
    + Make Statsd dictionaries multi-threaded
    gh#netdata/netdata#13938
    + Remove NFS readahead histogram (proc.plugin)
    gh#netdata/netdata#13819
    + Merge netstat, snmp, and snmp6 modules (proc.plugin)
    gh#netdata/netdata#13806
    + Rename dockerd job on lock registration (python.d/dockerd)
    gh#netdata/netdata#13537
    + Remove python.d/* announced in v1.36.0 deprecation notice
    (python.d.plugin)
    gh#netdata/netdata#13503
    + Remove blocklist file existence state chart (go.d/pihole)
    gh#netdata/go.d.plugin#914
    + Remove instance-specific information from chart families
    (go.d/portcheck)
    gh#netdata/go.d.plugin#790
    + Remove spaces in "HTTP Response Time" chart dimensions
    (go.d/httpcheck)
    gh#netdata/go.d.plugin#788
  Health
  * Engine
    + Add support of chart labels in alerts
    gh#netdata/netdata#13290
  * Notifications
    + Add an option to retry on telegram API limit error
    gh#netdata/netdata#13119
    + Set default curl connection timeout if not set
    gh#netdata/netdata#13529
  * Alarms
    + Use 'host' label in alerts info (health.d/ping.conf)
    gh#netdata/netdata#13955
    + Remove pihole_blocklist_gravity_file_existence_state
    (health.d/pihole.conf)
    gh#netdata/netdata#13826
    + Fix the systemd_mount_unit_failed_state alarm name
    (health.d/systemdunits.conf)
    gh#netdata/netdata#13796
    + Add 1m delay for tcp reset alarms (health.d/tcp_resets.conf)
    gh#netdata/netdata#13761
    + Add new Redis alarms (health.d/redis.conf)
    gh#netdata/netdata#13715
    + Fix inconsistent alert class names
    gh#netdata/netdata#13699
    + Disable Postgres last vacuum/analyze alarms
    (health.d/postgres.conf)
    gh#netdata/netdata#13698
    + Add node level AR based example (health.d/ml.conf)
    gh#netdata/netdata#13684
    + Add Postgres alarms (health.d/postgres.conf)
    gh#netdata/netdata#13671
    + Adjust systemdunits alarms (health.d/systemdunits.conf)
    gh#netdata/netdata#13623
    + Add Postgres total connection utilization alarm
    (health.d/postgres.conf)
    gh#netdata/netdata#13620
    + Adjust mysql_galera_cluster_size_max_2m lookup to make time
    in warn/crit predictable (health.d/mysql.conf)
    gh#netdata/netdata#13563
  Other Notable Changes
  * Improvements
    + Add replication of metrics (gaps filling) during streaming
    gh#netdata/netdata#13873
    + Remove anomaly rates chart
    gh#netdata/netdata#13763
    + Add disabling netdata monitoring section of the dashboard
    gh#netdata/netdata#13788
    + Add host labels for ephemerality and nodes with unstable
    connections
    gh#netdata/netdata#13784
    + Allow netdata plugins to expose functions for querying more
    information about specific charts
    gh#netdata/netdata#13720
    + Improve Health engine performance by adding a thread per host
    gh#netdata/netdata#13712
    + Improve streaming performance by 25%% on the child
    gh#netdata/netdata#13708
    + Improve agent shutdown time
    gh#netdata/netdata#13649
    + Add disabling Cloud functionality via NETDATA_DISABLE_CLOUD
    environment variable
    gh#netdata/netdata#13106
  * Bug Fixes
    + Fix sanitizing command arguments executed by the health
    component
    gh#netdata/netdata#14064
    + Fix control of streaming API keys and MACHINE GUIDs in
    stream.conf
    gh#netdata/netdata#14063
    + Fix build on old versions of openssl on Centos
    gh#netdata/netdata#14045
    + Fix merging duplicate replication requests
    gh#netdata/netdata#14037
    + Fix various problems in streaming compression, query planner
    and replication
    gh#netdata/netdata#14023
    + Fix ACLK connection resets on parents with a lot of children
    gh#netdata/netdata#14004
    + Fix crash when netdata cannot execute its external plugins
    gh#netdata/netdata#13978
    + Fix metrics suffix for counters when using remote write
    exporter
    gh#netdata/netdata#13977
    + Fix replicating non-existing child host
    gh#netdata/netdata#13968
    + Fix local dashboard cloud links
    gh#netdata/netdata#13953
    + Fix stopping Netdata on WSL1
    gh#netdata/netdata#13948
    + Fix  negative values when removing a "percentage-of-
    incremental-row" dimension
    gh#netdata/netdata#13945
    + Fix chart definition end time_t printing and parsing
    gh#netdata/netdata#13942
    + Fix not using system CA certificates when streaming
    gh#netdata/netdata#13941
    + Fix segfault when a dimension is deleted while replicated
    gh#netdata/netdata#13932
    + Fix compiling without dbengine
    gh#netdata/netdata#13931
    + Fix crash on query plan switch
    gh#netdata/netdata#13920
    + Fix crash when free hosts if a change on db mode is not
    needed
    gh#netdata/netdata#13912
    + Fix timeframe matching in query engine
    gh#netdata/netdata#13911
    + Fix reading health "enable" from the configuration
    gh#netdata/netdata#13894
    + Fix segmentation fault on 32-bit RPi
    gh#netdata/netdata#13876
    + Fix ml_info call via ACLK
    gh#netdata/netdata#13863
    + Fix compiling with LTO enabled on FreeBSD
    gh#netdata/netdata#13854
    + Fix tiers update frequency
    gh#netdata/netdata#13844
    + Fix crash on child reconnect and lost metrics
    gh#netdata/netdata#13821
    + Fix post-processing of contexts
    gh#netdata/netdata#13807
    + Fix initialization of chart variables
    gh#netdata/netdata#13795
    + Fix Array Allocator memory leak
    gh#netdata/netdata#13792
    + Fix chart variables initialization
    gh#netdata/netdata#13786
    + Fix compilation on CentOS 7.9
    gh#netdata/netdata#13775
    + Fix count of currently streaming senders on the localhost
    gh#netdata/netdata#13755
    + Fix streaming crash when child reconnects and is archived on
    the parent
    gh#netdata/netdata#13754
    + Fix sending NodeInfo during first database cleanup
    gh#netdata/netdata#13740
    + Fix starting an archived host in dbengine if dbengine is not
    compiled
    gh#netdata/netdata#13724
    + Fix building judy without dbengine
    gh#netdata/netdata#13703
    + fix typo not deleting collected flag; force removing
    collected flag on child disconnect
    gh#netdata/netdata#13672
    + Fix access to old data when nmap is used
    gh#netdata/netdata#13666
    + Fix container virtualization info detection
    gh#netdata/netdata#13653
    + Fix rrdcontexts left in the post-processing queue from the
    garbage collector
    gh#netdata/netdata#13645
    + Fix a memory leak on archived host creation
    gh#netdata/netdata#13641
    + Fix worker utilization cleanup
    gh#netdata/netdata#13633
    + Fix loading db rows when chart_id or dim_id is null
    gh#netdata/netdata#13608
    + Fix crash on rrdcontext apis when rrdcontexts is not
    initialized
    gh#netdata/netdata#13578
    + Fix a failure to build eBPF with CMake
    gh#netdata/netdata#13568
    + Fix a crash when xen libraries are misconfigured
    gh#netdata/netdata#13535
    + Fix crashes on 32bit system
    gh#netdata/netdata#13511
* Thu Sep 29 2022 Mia Herkt <mia@0x0.st>
- Update to 1.36.1
  Fixes
  * An issue that could cause agents running on 32bit distributions
    to crash during data exchange with the cloud.
    gh#netdata/netdata#13511
- go.d.plugin 0.40.1
  Fixes
  * agent: do cleanup on exit
    gh#netdata/go.d.plugin#758
  * mysql: create a dimension per Galera state/status.
    gh#netdata/go.d.plugin#779
  * docker: remove data usage call.
    gh#netdata/go.d.plugin#780
  * httpcheck: remove spaces in "HTTP Response Time" chart
    dimensions.
    gh#netdata/go.d.plugin#788
  * portcheck: remove instance-specific information from chart
    families.
    gh#netdata/go.d.plugin#790
  * docker: handle the case when no images are found.
    gh#netdata/go.d.plugin#739
  * postgres: delay unregistering connString.
    gh#netdata/go.d.plugin#839
  * postgres: fix bloat size perc calc.
    gh#netdata/go.d.plugin#841
  * postgres: fix unregistering connStr at runtime.
    gh#netdata/go.d.plugin#843
  * postgres: query database size only if has 'connect' privilege.
    gh#netdata/go.d.plugin#845
  * postgres: don't create bloat charts if no bloat metrics
    collected.
    gh#netdata/go.d.plugin#846
  Collectors
  * docker: collect the number of running containers and their
    health state
    gh#netdata/go.d.plugin#760
  * logind: Keeps track of user logins and sessions by querying the
    systemd-logind API.
    gh#netdata/go.d.plugin#786
  * proxysql: Monitor connections, slow queries, lagging, backends
    status, and more.
    gh#netdata/go.d.plugin#703
  * [WIP] nvidia_smi: Monitors Nvidia GPU using the nvidia-smi
    CLI tool.
    gh#netdata/go.d.plugin#844
  Improvements
  * mysql: produce binary log and MyISAM charts if they're enabled
    gh#netdata/go.d.plugin#763
  * mysql: collect more user stats metrics.
    gh#netdata/go.d.plugin#775
  * mysql: add Percona MySQL compatibility.
    gh#netdata/go.d.plugin#776
  * docker: collect images and volumes stats.
    gh#netdata/go.d.plugin#777
  * dnsmasq_dhcp: discover dhcp-ranges at runtime.
    gh#netdata/go.d.plugin#778
  * postgres: collect table and index metrics.
  * systemdunits: create dimension for each unit state.
    gh#netdata/go.d.plugin#795
  * phpfpm: added the ability to directly connect to a TCP socket
    and modify the status path.
    gh#netdata/go.d.plugin#805
  * agent: add _collect label (job name) to charts.
    gh#netdata/go.d.plugin#814
  * postgres: track acquired locks utilization.
    gh#netdata/go.d.plugin#831
  * postgres: human-friendly histogram buckets.
    gh#netdata/go.d.plugin#833
  * postgres: human-friendly histogram buckets.
    gh#netdata/go.d.plugin#833
  * agent: allow to define labels in config.
    gh#netdata/go.d.plugin#840
* Wed Aug 10 2022 Mia Herkt <mia@0x0.st>
- Drop netdata-smartd-log-path.patch
- Update to 1.36.0 (go.d.plugin 0.35.0)
  Collectors
  * New
    + Add PgBouncer collector (go.d/pgbouncer)
    gh#netdata/netdata#748
    + Add WireGuard collector (go.d/wireguard)
    gh#netdata/netdata#744
    + Add PostgresSQL collector (go.d/postgres)
    gh#netdata/netdata#718
    + Add Chrony collector (go.d/chrony)
    gh#netdata/netdata#678
    + Add Kubernetes State collector (go.d/k8s_state)
    gh#netdata/netdata#673
  * Improvements
    + Add WireGuard description and icon to dashboard info
    gh#netdata/netdata#13483
    + Resolve nomad containers name (cgroups.plugin)
    gh#netdata/netdata#13481
    + Update postgres dashboard info
    gh#netdata/netdata#13474
    + Improve Chrony dashboard info
    gh#netdata/netdata#13371
    + Improve config file parsing error message (python.d)
    gh#netdata/netdata#13363
    + Add fstype label to disk charts (diskspace.plugin)
    gh#netdata/netdata#13245
    + Add support for loadin modules from user plugin directories
    (python.d)
    gh#netdata/netdata#13214
    + Add user plugin dirs to environment variables
    gh#netdata/netdata#13203
    + Add second data collection job that tries to read from
    '/var/lib/smartmontools/' (python.d/smartd)
    gh#netdata/netdata#13188
    + Add type label for network interfaces (proc.plugin)
    gh#netdata/netdata#13187
    + Add k8s_state dashboard_info
    gh#netdata/netdata#13181
    + Add dimension per physical link state to the
    "Interface Physical Link State" chart (proc.plugin)
    gh#netdata/netdata#13176
    + Add dimension per operational state to the
    "Interface Operational State" chart (proc.plugin)
    gh#netdata/netdata#13167
    + Add dimension per duplex state to the
    "Interface Duplex State" chart (proc.plugin)
    gh#netdata/netdata#13165
    + Add cargo/rustc/bazel/buck to apps_groups.conf (apps.plugin)
    gh#netdata/netdata#13143
    + Add a separate thread for slow mountpoints in the diskspace
    plugin (diskspace.plugin)
    gh#netdata/netdata#13067
    + Add simple dimension algorithm guess logic when algorithm is
    not set (go.d/snmp)
    gh#netdata/netdata#737
    + Add common stub_status locations (go.d/nginx)
    gh#netdata/netdata#702
  * Bug fixes
    + Fix cgroup name detection for docker containers in containerd
    cgroup (cgroups.plugin)
    gh#netdata/netdata#13470
    + Fix not handling log rotation (python.d/smartd)
    gh#netdata/netdata#13460
    + Fix kubepods patterns to filter pods when using Kind cluster
    (cgroups.plugin)
    gh#netdata/netdata#13324
    + Fix 'zmstat*' pattern to exclude zoneminder scripts
    (apps.plugin)
    gh#netdata/netdata#13314
    + Fix kubepods name resolution in a kind cluster
    (cgroups.plugin)
    gh#netdata/netdata#13302
    + Fix extensive error logging (cgroups.plugin)
    gh#netdata/netdata#13274
    + Fix qemu VMs and LXC containers name resolution
    (cgroups.plugin)
    gh#netdata/netdata#13220
    + Fix duplicate mountinfo (proc.plugin)
    gh#netdata/netdata#13215
    + Fix removing netdev chart labels (cgroups.plugin)
    gh#netdata/netdata#13200
    + Fix import collection for py3.10+ (python.d)
    gh#netdata/netdata#13136
    + Fix not setting connection timeout for pymongo4+
    (python.d/mongodb)
    gh#netdata/netdata#13135
    + Fix not handling slow setting spec.NodeName for Pods
    (go.d/k8s_state)
    gh#netdata/netdata#717
    + Fix empty charts when ServerMPM is prefork
    gh#netdata/netdata#715
    + Fix parsing multiple values in nginx upstream_response_time
    (go.d/web_log)
    gh#netdata/netdata#711
    + Fix collecting metrics for Nodes with dots in name
    (go.d/k8s_state)
    gh#netdata/netdata#710
    + Fix adding dimensions to User CPU Time chart at runtime
    (go.d/mysql)
    gh#netdata/netdata#689
  eBPF
  * Fix data collection frequency
    gh#netdata/netdata#13351
  * Fix crash on cleanup
    gh#netdata/netdata#13259
  Exporting
  * Fix a base64_encode bug
    gh#netdata/netdata#13074
  * Fix sent metrics calculation
    gh#netdata/netdata#13435
  * Move host tags to netdata_info
    gh#netdata/netdata#13358
  * Fix exporting to OpenTSDB
    gh#netdata/netdata#13355
  * Fix exporting to Graphite
    gh#netdata/netdata#13261
  * Add exporting chart variables
    gh#netdata/netdata#13221
  Other notable changes
  * Improvements
    + Enable rrdcontexts by default
    gh#netdata/netdata#13471
    + Add rrdcontext support for hidden charts
    gh#netdata/netdata#13466
    + Load host labels for archived hosts
    gh#netdata/netdata#13464
    + Add /api/v1/weights endpoint
    gh#netdata/netdata#13449
    + Add stats about currently collected metrics and disk space
    to tiering endpoint
    gh#netdata/netdata#13445
    + Show last 15 alerts in notification
    gh#netdata/netdata#13434
    + Add tiering statistics API endpoint
    gh#netdata/netdata#13420
    + Send chart context with alert events to the cloud
    gh#netdata/netdata#13409
    + Send node info message sooner
    gh#netdata/netdata#13348
    + Use new MQTT as default
    gh#netdata/netdata#13287
    + Better ACLK debug communication log
    gh#netdata/netdata#13281
    + Add Multi-Tier database backend for long term metrics storage
    gh#netdata/netdata#13263
    + Add natural and virtual points support to Query Engine
    gh#netdata/netdata#13248
    + Delay health until obsoletions check is complete
    gh#netdata/netdata#13239
    + Enable ML by default
    gh#netdata/netdata#13158
    + Add multi-granularity support to Query Engine and MC
    improvements
    gh#netdata/netdata#13155
    + Add an option to use malloc for page cache instead of mmap
    gh#netdata/netdata#13142
    + Significantly improve metrics correlations (73x times faster)
    gh#netdata/netdata#13107
    + Add SSL received/send bytes statistics to ACLK
    gh#netdata/netdata#13091
  * Bug fixes
    + Fix crash on Agent startup if data rotation needs to be done
    gh#netdata/netdata#13473
    + Fix agent crash when archived host has not been registered
    to the cloud
    gh#netdata/netdata#13437
    + Fix gap filling on dbengine gaps
    gh#netdata/netdata#13417
    + Fix 32bit calculation on array allocator
    gh#netdata/netdata#13343
    + Fix crash on start on slow disks because ml is initialized
    before dbengine starts
    gh#netdata/netdata#13342
    + Fix crash when the host_labels health line contains the
    name/value of a label that does not exist on the host
    gh#netdata/netdata#13305
    + Fix incorrect dimension names in Redis alarms
    gh#netdata/netdata#13296
    + Fix Query Engine alignment
    gh#netdata/netdata#13282
    + Fix vbi parser in mqtt5 implementation
    gh#netdata/netdata#13277
    + Fix alignment in charts endpoint
    gh#netdata/netdata#13275
    + Fix data query on stale chart
    gh#netdata/netdata#13159
    + Fix crashes due to misaligned allocations
    gh#netdata/netdata#13137
    + Fix buffer overflow detected by the compiler
    gh#netdata/netdata#13120
    + Fix 100%% CPU when using SSL and a child disconnect from a
    parent
    gh#netdata/netdata#13112
  Deprecation notice
  The following items will be removed in our next minor release
  (v1.37.0):
  Component                   Type          Will be replaced by
  python.d/postgres           collector     go.d/postgres
  Deprecated in this release:
  Component                   Type          Replaced by
  python.d/chrony	collector   collector     go.d/chrony
  python.d/ovpn_status_log    collector     go.d/openvpn_status_log
* Sun Jul 31 2022 Mia Herkt <mia@0x0.st>
- Fix %%fdupes usage that resulted in the webserver refusing to
  serve required assets
- Update to 1.35.1 (go.d.plugin 0.33.1)
  Netdata now comes with on-device machine learning. Unsupervised ML
  models are trained for every metric, at the edge (on your devices),
  enabling real time anomaly detection across your infrastructure.
  Update netdata.conf with the following information to enable ML
  on your agent:
  [ml]
    enabled = yes
  More information on the Netdata blog:
  https://www.netdata.cloud/blog/introducing-anomaly-advisor-unsupervised-anomaly-detection-in-netdata/
  Collectors
  * New
    + Add "UPS Load Usage" in Watts chart (charts.d/apcupsd)
    gh#netdata/netdata#12965
    + Add Pressure Stall Information stall time charts
    (proc.plugin, cgroups.plugin)
    gh#netdata/netdata#12869
    + Add "CPU Time Relative Share" chart when running inside a
    K8s cluster (cgroups.plugin)
    gh#netdata/netdata#12741
    + Add a collector that parses the log files of the OpenVPN
    server (go.d/openvpn_status_log)
    gh#netdata/netdata#675
  * Improvements
    + Add Tailscale apps_groups.conf (apps.plugin)
    gh#netdata/netdata#13033
    + Skip collecting network interface speed and duplex if carrier
    is down (proc.plugin)
    gh#netdata/netdata#13019
    + Run the /net/dev module in a separate thread (proc.plugin)
    gh#netdata/netdata#12996
    + Add dictionary support to statsd
    gh#netdata/netdata#12980
    + Add an option to filter the alarms (python.d/alarms)
    gh#netdata/netdata#12972
    + Update net, aws, and ha groups in apps_groups.conf
    (apps.plugin)
    gh#netdata/netdata#12921
    + Add k8s_cluster_name label to cgroup charts in K8s on GKE
    (cgroups.plugin)
    gh#netdata/netdata#12858
    + Exclude Proxmox bridge interfaces (proc.plugin)
    gh#netdata/netdata#12789
    + Add filtering by cgroups name and improve renaming in K8s
    (cgroups.plugin)
    gh#netdata/netdata#12778
    + Execute the renaming script only for containers in K8s
    (cgroups.plugin)
    gh#netdata/netdata#12747
    + Add k8s_qos_class label to cgroup charts in K8s
    (cgroups.plugin)
    gh#netdata/netdata#12737
    + Reduce the CPU time required for cgroup-network-helper.sh
    (cgroups.plugin)
    gh#netdata/netdata#12711
    + Add Proxmox VE processes to apps_groups.conf (apps.plugin)
    gh#netdata/netdata#12704
    + Add Caddy to apps_groups.conf (apps.plugin)
    gh#netdata/netdata#12678
  * Bug fixse
    + Fix adding wrong labels to cgroup charts (cgroups.plugin)
    gh#netdata/netdata#13062
    + Fix cpu_guest chart context (apps.plugin)
    gh#netdata/netdata#12983
    + Fix counting unique values in Sets (statsd.plugin)
    gh#netdata/netdata#12963
    + Fix collecting data from uninitialized containers in K8s
    (cgroups.plugin)
    gh#netdata/netdata#12912
    + Fix CPU-specific data in the "C-state residency time" chart
    dimensions (proc.plugin)
    gh#netdata/netdata#12898
    + Fix disabling K8s pod/container cgroups when fail to rename
    them (cgroups.plugin)
    gh#netdata/netdata#12865
    + Fix memory usage calculation by considering ZFS ARC as cache
    on Linux (proc.plugin)
    gh#netdata/netdata#12847
    + Fix adding network interfaces when the cgroup proc is in the
    host network namespace (cgroups.plugin)
    gh#netdata/netdata#12788
    + Fix not setting chart units (go.d/snmp)
    gh#netdata/netdata#682
    + Fix not collecting Integer type values (go.d/snmp)
    gh#netdata/netdata#680
  eBPF
  * Add CO-RE algorithms to all threads related to memory
    gh#netdata/netdata#12684
  * Fix wrong chart type for ip charts
    gh#netdata/netdata#12698
  * Fix disabled apps (ebpf.plugin)
    gh#netdata/netdata#13044
  * Fix "libbpf: failed to load" warnings
    gh#netdata/netdata#12831
  * Re-enable socket module by default
    gh#netdata/netdata#12702
  Health
  * Fix not respecting host labels when creating alerts for
    children instances
    gh#netdata/netdata#13053
  * Expose anomaly-bit option to health
    gh#netdata/netdata#12835
  * Add priority to Gotify notifications to trigger
    sound & vibration on the Gotify phone app
    gh#netdata/netdata#12753
  * Add Gotify notification method
    gh#netdata/netdata#12639
  Streaming
  * Improve failover logic when the Agent is configured to stream
    to multiple destinations
    gh#netdata/netdata#12866
  * Increase the default "buffer size bytes" to 10MB
    gh#netdata/netdata#12913
  Exporting
  * Add the URL query parameter that filters charts from the
    /allmetrics API query
    gh#netdata/netdata#12820
  * Make the "send charts matching" option behave the same as the
    "filter" URL query parameter for prometheus format
    gh#netdata/netdata#12832
  Other Notable Changes
  * Improvements
    + Add hostname to mirrored hosts int the /api/v1/info endpoint
    gh#netdata/netdata#13030
    + Optimize query engine queries
    gh#netdata/netdata#12988
    + Optimize query engine and cleanup
    gh#netdata/netdata#12978
    + Improve the web server work distribution across worker
    threads
    gh#netdata/netdata#12975
    + Check link local address before querying cloud instance
    metadata
    gh#netdata/netdata#12973
    + Speed up query engine by refactoring
    rrdeng_load_metric_next()
    gh#netdata/netdata#12966
    + Optimize the dimensions option store to the metadata database
    gh#netdata/netdata#12952
    + Add detailed dbengine stats
    gh#netdata/netdata#12948
    + Stream Metric Correlation version to parent and advertise
    Metric Correlation status to the Cloud
    gh#netdata/netdata#12940
    + Move directories, logs, and environment variables
    configuration options to separate sections
    gh#netdata/netdata#12935
    + Adjust the dimension liveness status check
    gh#netdata/netdata#12933
    + Make sqlite PRAGMAs user configurable
    gh#netdata/netdata#12917
    + Add worker jobs for cgroup-rename, cgroup-network and
    cgroup-first-time
    gh#netdata/netdata#12910
    + Return stable or nightly based on version if the file check
    fails
    gh#netdata/netdata#12894
    + Take into account the in queue wait time when executing a
    data query
    gh#netdata/netdata#12885
    + Add fixes and improvements to workers library
    gh#netdata/netdata#12863
    + Pause alert pushes to the cloud
    gh#netdata/netdata#12852
    + Allow to use the new MQTT 5 implementation
    gh#netdata/netdata#12838
    + Set a page wait timeout and retry count
    gh#netdata/netdata#12836
    + Allow external plugins to create chart labels
    gh#netdata/netdata#12834
    + Reduce the number of messages written in the error log due to
    out of bound timestamps
    gh#netdata/netdata#12829
    + Cleanup the node instance table on startup
    gh#netdata/netdata#12825
    + Accept a data query timeout parameter from the cloud
    gh#netdata/netdata#12823
    + Write the entire request with parameters in the access.log
    file
    gh#netdata/netdata#12815
    + Add a parameter for how many worker threads the libuv library
    needs to pre-initialize
    gh#netdata/netdata#12814
    + Optimize linking of foreach alarms to dimensions
    gh#netdata/netdata#12813
    + Add a hyphen to the list of available characters for chart
    names
    gh#netdata/netdata#12812
    + Speed up queries by providing optimization in the main loop
    gh#netdata/netdata#12811
    + Add workers utilization charts for Netdata components
    gh#netdata/netdata#12807
    + Fill missing removed events after a crash
    gh#netdata/netdata#12803
    + Speed up buffer increases (minimize reallocs)
    gh#netdata/netdata#12792
    + Speed up reading big proc files
    gh#netdata/netdata#12791
    + Make dbengine page cache undumpable and dedupuble
    gh#netdata/netdata#12765
    + Speed up execution of external programs
    gh#netdata/netdata#12759
    + Remove per chart configuration
    gh#netdata/netdata#12728
    + Check for chart obsoletion on children re-connections
    gh#netdata/netdata#12707
    + Add a 2 minute timeout to stream receiver socket
    gh#netdata/netdata#12673
    + Improve Agent cloud chart synchronization
    gh#netdata/netdata#12655
    + Add the ability to perform a data query using an offline node
    id
    gh#netdata/netdata#12650
    + Implement ks_2samp test for Metric Correlations
    gh#netdata/netdata#12582
    + Reduce alert events sent to the cloud
    gh#netdata/netdata#12544
    + Store alert log entries even if alert it is repeating
    gh#netdata/netdata#12226
    + Improve storage number unpacking by using a lookup table
    gh#netdata/netdata#11048
  * Bug fixes
    + Fix locking access to chart labels
    gh#netdata/netdata#13064
    + Fix coverity 378625
    gh#netdata/netdata#13055
    + Fix dictionary crash walkthrough empty
    gh#netdata/netdata#13051
    + Fix the retry count and netdata_exit check when running a
    sqlite3_step command
    gh#netdata/netdata#13040
    + Fix sending first time seen dimensions with zero timestamp to
    the Cloud
    gh#netdata/netdata#13035
    + Fix gap filling on dbengine gaps
    gh#netdata/netdata#13027
    + Fix coverity issue 378598
    gh#netdata/netdata#13022
    + Fix coverity issue 378617,378615
    gh#netdata/netdata#13021
    + Fix a dimension 100%% anomaly rate despite no change in the
    metric value
    gh#netdata/netdata#13005
    + Fix compilation warnings
    gh#netdata/netdata#12993
    + Fix crash because of corrupted label message from streaming
    gh#netdata/netdata#12992
    + Fix nanosleep on platforms other than Linux
    gh#netdata/netdata#12991
    + Fix disabling a streaming destination because of denied
    access
    gh#netdata/netdata#12971
    + Fix "unused variable" compilation warning
    gh#netdata/netdata#12969
    + Fix virtualization detection on FreeBSD
    gh#netdata/netdata#12964
    + Fix buffer overflow when logging "command_to_be_logged" in
    analytics
    gh#netdata/netdata#12947
    + Fix "global statistics" section in netdata.conf
    gh#netdata/netdata#12916
    + Fix virtualization detection when systemd-detect-virt is not
    available
    gh#netdata/netdata#12911
    + Fix the log entry for incoming cloud start streaming commands
    gh#netdata/netdata#12908
    + Fix release channel in the node info message
    gh#netdata/netdata#12905
    + Fix alarms count in /api/v1/alarm_count
    gh#netdata/netdata#12896
    + Fix multihost queries alignment
    gh#netdata/netdata#12870
    + Fix negative worker jobs busy time
    gh#netdata/netdata#12867
    + Fix reported by coverity issues related to memory and
    structure dereference
    gh#netdata/netdata#12846
    + Fix memory leaks and mismatches of the use of the z functions
    for allocations
    gh#netdata/netdata#12841
    + Fix using obsolete charts/dims in prediction thread
    gh#netdata/netdata#12833
    + Fix not skipping ACLK dimension update when dimension is
    freed
    gh#netdata/netdata#12777
    + Fix coverity warning about not checking return value in
    receiver setsockopt
    gh#netdata/netdata#12772
    + Fix disk size calculation on macOS
    gh#netdata/netdata#12764
    + Fix "implicit declaration of function" compilation warning
    gh#netdata/netdata#12756
    + Fix Valgrind errors
    gh#netdata/netdata#12619
    + Fix redirecting alert emails for a child to the parent
    gh#netdata/netdata#12609
  Deprecation Notice
  The following items will be removed in our next minor release (v1.36.0):
  Component                   Type          Will be replaced by
  python.d/chrony	collector   go.d/chrony   -
  python.d/ovpn_status_log    collector     go.d/openvpn_status_log
  Deprecated in this release:
  Component                   Type          Replaced by
  node.d                      plugin        -
  node.d/snmp                 collector     go.d/snmp
  python.d/apache             collector     go.d/apache
  python.d/couchdb            collector     go.d/couchdb
  python.d/dns_query_time     collector     go.d/dnsquery
  python.d/dnsdist            collector     go.d/dnsdist
  python.d/elasticsearch      collector     go.d/elasticsearch
  python.d/energid            collector     go.d/energid
  python.d/freeradius         collector     go.d/freeradius
  python.d/httpcheck          collector     go.d/httpcheck
  python.d/isc_dhcpd          collector     go.d/isc_dhcpd
  python.d/mysql              collector     go.d/mysql
  python.d/nginx              collector     go.d/nginx
  python.d/phpfpm             collector     go.d/phpfpm
  python.d/portcheck          collector     go.d/portcheck
  python.d/powerdns           collector     go.d/powerdns
  python.d/redis              collector     go.d/redis
  python.d/web_log            collector     go.d/weblog
* Mon May 16 2022 Mia Herkt <mia@0x0.st>
- Update to 1.34.1 (go.d.plugin 0.32.3)
  Collectors
  * New collectors
    + Add CPU throttling charts (cgroups.plugin)
    (gh#netdata/netdata#12591)
    + Add clock status chart (timex.plugin)
    (gh#netdata/netdata#12501)
    + Add Asterisk configuration file with synthetic charts
    (statsd.plugin)
    (gh#netdata/netdata#12381)
    + Add new chart for process states metrics (apps.plugin)
    (gh#netdata/netdata#12305)
    + Add thermal zone metrics collection (go.d/wmi)
    (gh#netdata/netdata#667)
    + Add SNMP data collector (go.d/snmp)
    (gh#netdata/netdata#644)
  * Improvements
    + Add 'locust' to apps_groups.conf
    (gh#netdata/netdata#12498)
    + Enable timex plugin for non-linux systems (timex.plugin)
    (gh#netdata/netdata#12489)
    + Prefer 'blkio.*_recursive' files when available
    (cgroups.plugin)
    (gh#netdata/netdata#12462)
    + Add 'stress-ng' and 'gremlin' to apps_groups.conf
    (apps.plugin)
    (gh#netdata/netdata#12165)
    + Add Apple Filing Protocol daemons into 'afp' group
    (apps.plugin)
    (gh#netdata/netdata#12078)
    + Show the number of processes/threads for empty apps groups
    (apps.plugin)
    (gh#netdata/netdata#11834)
    + Add a configuration option to set application
    (go.d/prometheus)
    (gh#netdata/netdata#669)
  * Bug fixes
    + Fix collecting data when 'ntp_adjtime' call fails
    (timex.plugin)
    (gh#netdata/netdata#12667)
    + Fix chart titles with instance-specific information
    (gh#netdata/netdata#12644)
    + Fix CPU utilization calculation (cgroups.plugin)
    (gh#netdata/netdata#12622)
    + Fix cgroup version detection with systemd (cgroups.plugin)
    (gh#netdata/netdata#12553)
    + Fix network charts context (cgroups.plugin)
    (gh#netdata/netdata#12454)
    + Fix charts context (cups.plugin)
    (gh#netdata/netdata#12444)
    + Fix recursion in apcupsd_check (charts.d/apcupsd)
    (gh#netdata/netdata#12418)
    + Fix double host prefix when Netdata running in a podman
    container (cgroups.plugin)
    (gh#netdata/netdata#12380)
    + Fix config file check in stock config directory
    (ioping.plugin)
    (gh#netdata/netdata#12327)
    + Fix setting of 'time offset' configuration option
    (timex.plugin)
    (gh#netdata/netdata#12281)
    + Fix logical drive data parsing error (python.d/hpssa)
    (gh#netdata/netdata#12206)
    + Fix getting username when UID is unknown on the host
    (python.d/nvisia_smi)
    (gh#netdata/netdata#12184)
    + Fix a typo in ZFS ARC Cache size info
    (gh#netdata/netdata#12138)
    + Fix collecting of renamed metrics (go.d/k8s_kubelet)
    (gh#netdata/netdata#674)
    + Fix reading stock configuration files in k8s (go.d.plugin)
    (gh#netdata/netdata#670)
    + Fix runtime chart context hard coding (go.d.plugin)
    (gh#netdata/netdata#668)
    + Fix failed check because of invalid metric type
    (go.d/prometheus)
    (gh#netdata/netdata#665)
    + Fix handling of replica set charts dimensions (go.d/mongodb)
    (gh#netdata/netdata#646)
  eBPF
  * Improvements
    + Improve chart titles and dashboard info
    (gh#netdata/netdata#12665)
    + Update eBPF dashboard info
    (gh#netdata/netdata#12617)
    + Update links in the dashboard info
    (gh#netdata/netdata#12581)
    + Add monitoring for inbound and outbound connections
    (gh#netdata/netdata#12532)
    + Improve eBPF dashboard info
    (gh#netdata/netdata#12467)
    + Add CO-RE support for eBPF plugin
    (gh#netdata/netdata#12318)
    + Update libbpf version and adjust eBPF modules for using
    new version of libbpf
    (gh#netdata/netdata#12190)
  * Bug fixes
    + Fix missing chart context for cgroups charts
    (gh#netdata/netdata#12671)
    + Fix eBFP plugin crash on exit
    (gh#netdata/netdata#12590)
    + Fix unnecessary error log lines for proc and sys files
    (gh#netdata/netdata#12385)
    + Fix removing pid file on exit
    (gh#netdata/netdata#12379)
  Dashboard
  * Change color of Netdata logo on left sidebar
    (gh#netdata/netdata#12607)
  * Update Community section and the links for opening a new issue
    on GitHub in 'Need Help?' modal
    (gh#netdata/netdata#12607)
  * Add 'Netdata Cloud connection status' modal
    (gh#netdata/netdata#12407)
  Streaming
  * Fix parsing of 'os_name' for older agent versions streaming to
    a parent
    (gh#netdata/netdata#12425)
  * Deactivate streaming compression at runtime in case of a
    compressor buffer overflow
    (gh#netdata/netdata#12037)
  Exporting
  * Remove backends subsystem
    (gh#netdata/netdata#12146)
  Health
  * Fix ioping_disk_latency alarm green/red thresholds
    (gh#netdata/netdata#12351)
  * Fix ioping_disk_latency alarm lookup value
    (gh#netdata/netdata#12329)
  * Adjust 10s_ipv4_tcp_resets_sent alarm warn expression
    (gh#netdata/netdata#12320)
  * Add alarms for charts.d/nut collector
    (gh#netdata/netdata#12285)
  * Fix respecting of 'delay' parameter when using 'repeat' feature
    (gh#netdata/netdata#12164)
  ML
  * Fix training/prediction stats charts context
    (gh#netdata/netdata#12610)
  * Enable streaming of anomaly_detection.* charts
    (gh#netdata/netdata#12606)
  * Update ML-related charts
    (gh#netdata/netdata#12574)
  * Reduce min 'dbengine anomaly rate every' from 60s to 30s
    (gh#netdata/netdata#12543)
  * ML-related changes to address issue/discussion comments.
    (gh#netdata/netdata#12494)
  * Skip 'foreach' alarms for dimensions of anomaly rate chart.
    (gh#netdata/netdata#12441)
  * Prepend context in anomaly rate dimension id
    (gh#netdata/netdata#12342)
  * Skip training of constant metrics
    (gh#netdata/netdata#12212)
  * Track anomaly rates with DBEngine
    (gh#netdata/netdata#12083)
  Other notable changes
  * Improvements
    + Add a chart label filter parameter in context data queries
    (gh#netdata/netdata#12652)
    + Add a timeout parameter to data queries
    (gh#netdata/netdata#12649)
    + Add k8s cluster name to host labels (GKE only)
    (gh#netdata/netdata#12638)
    + Add cloud providers info to host labels and /api/v1/info
    (gh#netdata/netdata#12613)
    + Reduce logging on child reconnect
    (gh#netdata/netdata#12594)
    + Improve ACLK sync logging
    (gh#netdata/netdata#12534)
    + Add more info to netdatacli 'aclk-state'
    (gh#netdata/netdata#12458)
    + Remove "web files" options leftovers
    (gh#netdata/netdata#12403)
    + Improve agent to cloud synchronization performance
    (gh#netdata/netdata#12348)
    + Remove owner check from webserver
    (gh#netdata/netdata#12339)
    + Change default OOM score and scheduling policy to behave
    more sanely
    (gh#netdata/netdata#12271)
    + Add more info to aclk-state API call
    (gh#netdata/netdata#12231)
    + Add -W keepopenfds option
    (gh#netdata/netdata#12211)
    + Remove chart specific configuration from netdata.conf
    except enabled
    (gh#netdata/netdata#12209)
    + Improve cleaning up of orphan hosts
    (gh#netdata/netdata#12201)
    + Add install method to /api/v1/info as label
    (gh#netdata/netdata#12040)
    + Add all query types to aclk_processed_query_type
    (gh#netdata/netdata#12036)
    + Create a removed alert event if chart goes obsolete
    (gh#netdata/netdata#12021)
    + Add chart for incoming proto msgs in new cloud protocol
    (gh#netdata/netdata#11969)
  * Bug fixes
    + Fix deadlock when deleting a child instance host and ML
    training is running
    (gh#netdata/netdata#12681)
    + Fix Netdata crash during anomaly calculation
    (gh#netdata/netdata#12672)
    + Fix not clean ACLK shutdown when agent is shutting down
    (gh#netdata/netdata#12625)
    + Fix shutting down the agent when the creation of the
    management API key file failed
    (gh#netdata/netdata#12623)
    + Fix respecting of dimension hidden option when executing a
    query
    (gh#netdata/netdata#12570)
    + Fix Agent crash on api/v1/info call
    (gh#netdata/netdata#12565)
    + Fix CPU frequency detection in system-info.sh
    (gh#netdata/netdata#12550)
    + Fix sending alert events with missing timezone data
    (gh#netdata/netdata#12547)
    + Fix invalid pointer reference when executing agent CLI
    commands
    (gh#netdata/netdata#12540)
    + Fix memory leaks on Netdata exit
    (gh#netdata/netdata#12511)
    + Fix wrong 'metrics-count' in /api/v1/info
    (gh#netdata/netdata#12504)
    + Fix issue with charts not properly synchronized with the
    cloud
    (gh#netdata/netdata#12451)
    + Fix high CPU usage for unclaimed agents
    (gh#netdata/netdata#12449)
    + Fix a case when claim_id is sent in uppercase
    (gh#netdata/netdata#12423)
    + Fix crash when netdatacli command output too long
    (gh#netdata/netdata#12393)
    + Fix Netdata crash on ACLK alerts streaming
    (gh#netdata/netdata#12392)
    + Fix build info output when dbengine is not compiled
    (gh#netdata/netdata#12354)
    + Fix container virtualization detection with
    systemd-detect-virt
    (gh#netdata/netdata#12338)
    + Fix returning 0 for unknown CPU frequency in system-info.sh
    (gh#netdata/netdata#12323)
    + Fix CPU frequency detection for containers
    (gh#netdata/netdata#12306)
    + Fix long timeouts on the cloud because the agent does not
    respond for failed queries with a failed message
    (gh#netdata/netdata#12277)
    + Fix registration of child nodes in the cloud through the
    parent
    (gh#netdata/netdata#12241)
    + Fix node information send to the cloud for older agent
    versions
    (gh#netdata/netdata#12223)
    + Fix Netdata crash on ACLK alerts streaming when 'info' field
    is missing
    (gh#netdata/netdata#12210)
    + Fix claiming with wget
    (gh#netdata/netdata#12163)
    + Fix CPU frequency calculation in system-info.sh
    (gh#netdata/netdata#12162)
    + Fix data query option allow_past to correctly work in memory
    mode ram and save
    (gh#netdata/netdata#12136)
    + Fix the format=array output in context queries
    (gh#netdata/netdata#12129)
    + Fix Netdata crash when there are charts with ids which differ
    only by symbols that are not '_' or alphanumeric and no
    unique names are provided
    (gh#netdata/netdata#12067)
  Deprecation notice
  The following items will be removed in our next minor release
  (v1.35.0):
  Patch releases (if any) will not be affected.
  Component                 Type        Replaced by
  node.d                    plugin      -
  node.d/snmp               collector   go.d/snmp
  python.d/apache           collector   go.d/apache
  python.d/couchdb          collector   go.d/couchdb
  python.d/dns_query_time   collector   go.d/dnsquery
  python.d/dnsdist          collector   go.d/dnsdist
  python.d/elasticsearch    collector   go.d/elasticsearch
  python.d/energid          collector   go.d/energid
  python.d/freeradius       collector   go.d/freeradius
  python.d/httpcheck        collector   go.d/httpcheck
  python.d/isc_dhcpd        collector   go.d/isc_dhcpd
  python.d/mysql            collector   go.d/mysql
  python.d/nginx            collector   go.d/nginx
  python.d/phpfpm           collector   go.d/phpfpm
  python.d/portcheck        collector   go.d/portcheck
  python.d/powerdns         collector   go.d/powerdns
  python.d/redis            collector   go.d/redis
  python.d/web_log          collector   go.d/weblog
  Deprecated in this release:
  Component                 Type        Replaced by
  backends                  subsystem   exporting engine
  node.d/fronius            collector   -
  node.d/sma_webbox         collector   -
  node.d/stiebeleltron      collector   -
  node.d/named              collector   go.d/bind
* Wed Feb 16 2022 Mia Herkt <mia@0x0.st>
- Update to 1.33.1
  Dashboard
  * Add legacy protocol deprecation notification in the header
  (gh#netdata/netdata#12117)
  * Fix handling of after and before URL params in direct links
  (gh#netdata/netdata#12052)
  Bug fixes
  * Fix compilation errors cased by including "lz4.h" when stream compression is disabled
  (gh#netdata/netdata#12049)
  * Disable ebpf socket thread causing crashes on some systems
  (gh#netdata/netdata#12085)
  * Fix ACLK reconnect endless loop
  (gh#netdata/netdata#12074)
  * Fix compilation errors when openssl is not available and compiling with --disable-https and --disable-cloud
  (gh#netdata/netdata#12071)
  Other notable changes
  * Adds legacy protocol deprecation banner to agent log
  (gh#netdata/netdata#12065)
* Mon Jan 31 2022 Mia Herkt <mia@0x0.st>
- Update to 1.33.0 (go.d.plugin 0.31.2)
  Collectors
  * Improvements
  + Prefer python3 if available (python.d)
    (gh#netdata/netdata#12001)
  + Add bar1 memory usage chart (python.d/nvidia_smi)
    (gh#netdata/netdata#11956)
  + Add a note that Netfilter's "new" and "ignore" counters are
    removed in the latest kernel
    (gh#netdata/netdata#11950)
  + Consider mat. views as tables in table size/count chart
    (python.d/postgres)
    (gh#netdata/netdata#11816)
  + Use block_size instead of 8*1024 (python.d/postgres)
    (gh#netdata/netdata#11815)
  * Bug fixes
  + Fix handling of port_rcv_data and port_xmit_data counters
    (proc/infiniband)
    (gh#netdata/netdata#11994)
  + Fix handling of decoding errors in ExecutableService (python.d)
    (gh#netdata/netdata#11979)
  + Fix lack of sufficient system capabilities (perf.plugin)
    (gh#netdata/netdata#11958)
  + Fix Netfilter accounting charts priority (nfacct.plugin)
    (gh#netdata/netdata#11952)
  + Fix lack of sufficient system capabilities (nfacct.plugin)
    (gh#netdata/netdata#11951)
  + Fix collecting user statistics for LDAP users
    (python.d/nvidia_smi)
    (gh#netdata/netdata#11858)
  + Fix tps decode, and add memory usage chart (python.d/spigotmc)
    (gh#netdata/netdata#11797)
  + Fix collecting replica set stats (go.d/mongodb)
    (gh#netdata/netdata#639)
  eBPF
  * Improvements
  + Add ebpf.plugin informational charts and various optimizations
    (gh#netdata/netdata#11992)
  + Update libbpf library to v0.6.1
    (gh#netdata/netdata#11865)
  * Bug fixes
  + Fix disabling specific ebpf collectors
    (gh#netdata/netdata#12014)
  + Fix cachestat on kernel 5.15.x
    (gh#netdata/netdata#11833)
  Health
  * Add sending notifications to channels support to PushBullet
    (gh#netdata/netdata#11850)
  Streaming
  * Add LZ4 streaming data compression
    (gh#netdata/netdata#11821)
  Other
  * Improvements
  + Add install type info to -W buildinfo output.
    (gh#netdata/netdata#12010)
  + Add support for NVME disks with blkext driver
    (gh#netdata/netdata#12007)
  + Perform a host metadata update on child reconnection
    (gh#netdata/netdata#11965)
  + Send ML feature information with UpdateNodeInfo
    (gh#netdata/netdata#11913)
  + Use absolute features when doing training/prediction.
    (gh#netdata/netdata#11876)
  + Send the cloud protocol used to posthog
    (gh#netdata/netdata#11842)
  + Remove ACLK Legacy
    (gh#netdata/netdata#11841)
  * Bug fixes
  + Fix access to freed memory in ACLK
    (gh#netdata/netdata#12015)
  + Fix a typo in the dashboard_info.js spigot part
    (gh#netdata/netdata#12008)
  + Fix queue removed alerts
    (gh#netdata/netdata#11996)
  + Fix coverity 374746
    (gh#netdata/netdata#11973)
  + Fix ACLK chart description
    (gh#netdata/netdata#11970)
  + Fix a broken link in dashboard_info.js
    (gh#netdata/netdata#11948)
  + Fix an error in configure.ac
    (gh#netdata/netdata#11937)
  + Fix handling of the "-url" parameter in the claiming script
    (gh#netdata/netdata#11919)
  + Fix time_t format
    (gh#netdata/netdata#11897)
  + Fix compiling with AWS Kinesis support
    (gh#netdata/netdata#11867)
  + Fix cmake build
    (gh#netdata/netdata#11862)
  + Fix compilation warnings
    (gh#netdata/netdata#11846)
  Deprecation notice
  The following items will be removed in the next release:
  * backends subsystem. Has been replaced by the exporting engine.
  * node.d/fronius collector.
  Will be moved to the netdata/community repository.
  * node.d/sma_webbox collector.
  Will be moved to the netdata/community repository.
  * node.d/stiebeleltron collector.
  Will be moved to the netdata/community repository.
  * node.d/named collector. Has been replaced by go.d/bind.
  Will be moved to the netdata/community repository.
  Deprecated in this release
  Legacy ACLK support is officially removed in this release.
* Thu Dec 23 2021 Mia Herkt <mia@0x0.st>
- Update to 1.32.1 (go.d.plugin 0.31.0)
  Bug fixes
  * Use the chart id instead of chart name in response to incoming
    cloud context queries
    (gh#netdata/netdata#11898)
  * Fix used_swap alarm calculation
    (gh#netdata/netdata#11868)
  * Initialize enabled parameter to 1 in AlarmLogHealth message
    (gh#netdata/netdata#11856)
- Changes in 1.32.0:
  New Cloud backend and Agent communication protocol
  This Agent release supports our new Cloud backend. From here, we
  will be offering much faster and simpler communication, reliable
  alerts and exchange of metadata, and first-time support for the
  parent-child relationship of Netdata agents. This is the first
  Agent release that allows Netdata Cloud to use the Netdata Agent as
  a distributed time-series database that supports replication and
  query routing, for every metric!
  eBPF latency monitoring, container monitoring, and more
  We use eBPF to monitor all running processes, without the
  cooperation of the processes and without sniffing data traffic.
  This new release includes 13 new eBPF monitoring features,
  including I/O latency, BTRFS, EXT4, NFS, XFS and ZFS latencies,
  IRQs latencies, extended swap monitoring, and more.
  Machine learning (ML) powered anomaly detection
  ​This release links Netdata Agent with dlib, the popular C++
  machine learning algorithms library, which we use to automatically
  detect anomalies out-of-the-box, at the edge! Once enabled, Netdata
  trains an ML model for every metric, which is then used to detect
  outliers in real-time. The resulting "anomaly bit" (where 0=normal,
  1=anomalous) associated with each database entry is stored
  alongside the raw metric value with zero additional storage
  overhead! This feature is still in development, so it is disabled
  by default. If you would like to test it and provide feedback, you
  can go to the new [ml] section in netdata.conf and set enabled=yes
  to turn on anomaly detection. After restarting Netdata, you should
  see the Anomaly Detection menu with charts highlighting the overall
  number and percent of anomalous metrics on your node. This can be a
  very useful single number summary of the state of your node.
  New timezone selector and time controls in the user interface
  We implemented a new timezone picker and time controls to enhance
  administrative abilities in the dashboard.
  Dashboard
  * Add various updates to dashboard info
    (gh#netdata/netdata#11639)
  * Add timex plugin chart descriptions
    (gh#netdata/netdata#11635)
  * Add proc plugin zfs chart descriptions
    (gh#netdata/netdata#11630)
  * Add proc plugin infiniband chart descriptions
    (gh#netdata/netdata#11628)
  * Add proc plugin pagetypeinfo chart descriptions
    (gh#netdata/netdata#11627)
  * Add proc plugin net_wireless chart descriptions
    (gh#netdata/netdata#11626)
  * Add proc plugin net_rpc_nfs and net_rpc_nfsd chart descriptions
    (gh#netdata/netdata#11625)
  * Add proc plugin power_supply chart descriptions
    (gh#netdata/netdata#11619)
  * Add cgroups plugin systemd services chart descriptions
    (gh#netdata/netdata#11618)
  * Add cgroups plugin chart descriptions
    (gh#netdata/netdata#11607)
  * Add apps plugin chart descriptions
    (gh#netdata/netdata#11601)
  * Add proc plugin vmstat chart descriptions
    (gh#netdata/netdata#11597)
  * Add proc plugin ksm chart descriptions
    (gh#netdata/netdata#11595)
  * Add proc plugin edac chart descriptions
    (gh#netdata/netdata#11589)
  * Add proc plugin stat chart descriptions
    (gh#netdata/netdata#11586)
  * Add proc plugin net_stat_synproxy chart descriptions
    (gh#netdata/netdata#11581)
  * Add proc plugin softirqs chart descriptions
    (gh#netdata/netdata#11577)
  * Add proc plugin net_stat_conntrack chart descriptions
    (gh#netdata/netdata#11576)
  * Add proc plugin uptime chart descriptions
    (gh#netdata/netdata#11569)
  * Add proc plugin net_sockstat and net_sockstat6 chart
    descriptions
    (gh#netdata/netdata#11567)
  * Add proc plugin net_snmp6 chart descriptions
    (gh#netdata/netdata#11565)
  * Add proc plugin net_sctp_snmp chart descriptions
    (gh#netdata/netdata#11564)
  * Add proc plugin net_snmp chart descriptions
    (gh#netdata/netdata#11557)
  * Add proc plugin net_netstat chart descriptions
    (gh#netdata/netdata#11554)
  * Add proc plugin net_ip_vs_stats chart descriptions
    (gh#netdata/netdata#11546)
  * Add proc plugin net_dev chart descriptions
    (gh#netdata/netdata#11543)
  * Add proc plugin meminfo chart descriptions
    (gh#netdata/netdata#11541)
  * Add proc plugin mdstat chart descriptions
    (gh#netdata/netdata#11537)
  * Add proc plugin interrupts chart descriptions
    (gh#netdata/netdata#11532)
  * Add proc plugin diskstats chart descriptions
    (gh#netdata/netdata#11528)
  * Add proc plugin ipc semaphores chart descriptions
    (gh#netdata/netdata#11523)
  * Remove 'vernemq.queue_messages_in_queues' from dashboard info
    (gh#netdata/netdata#11403)
  * Move MD arrays charts under Disks
    (gh#netdata/netdata#11119)
  Collectors
  * New
    + Add Traefik collector (go.d/traefik)
    (gh#netdata/go.d.plugin#605)
    + Add HAProxy collector (go.d/haproxy)
    (gh#netdata/go.d.plugin#599)
    + Add Mongodb collector (go.d/mongodb)
    (gh#netdata/go.d.plugin#598)
    + Add Ethereum Node collector (go.d/geth)
    (gh#netdata/go.d.plugin#585)
  * Improvements
    + Add AWS to apps_groups.conf
    (gh#netdata/netdata#11826)
    + Show stats for systemd protected mount points
    (diskspace plugin) (gh#netdata/netdata#11767)
    + Add support for v1.7.0+ (go.d/coredns)
    (gh#netdata/go.d.plugin#619)
    + Add "/basic_status" job nginx.conf (go.d/nginx)
    (gh#netdata/go.d.plugin#612)
    + Add sharding metrics (go.d/mongodb)
    (gh#netdata/go.d.plugin#609)
    + Add thread operations metrics (go.d/mysql)
    (gh#netdata/go.d.plugin#607)
    + Add replica sets metrics (go.d/mongodb)
    (gh#netdata/go.d.plugin#604)
    + Add databases metrics (go.d/mongodb)
    (gh#netdata/go.d.plugin#602)
    + Add more OS(OperatingSystem) charts (go.d/wmi)
    (gh#netdata/go.d.plugin#593)
    + Add caddy job to prometheus.conf (go.d/prometheus)
    (gh#netdata/go.d.plugin#581)
    + Add AOF file size metrics (go.d/redis)
    (gh#netdata/go.d.plugin#578)
    + Add openethereum/geth jobs to prometheus.con
    (go.d/prometheus) (gh#netdata/go.d.plugin#578)
    + Update whois/whois-parser packages and add timeout
    configuration option (go.d/whoisquery)
    (gh#netdata/go.d.plugin#576)
    + Disable reporting min/avg/max group uptime by default
    (apps plugin) (gh#netdata/netdata#11609)
    + Add sorting of the list of databases in alphabetical order
    (python.d/postgres) (gh#netdata/netdata#11580)
    + Add terra related binaries to blockchains group (apps plugin)
    (gh#netdata/netdata#11437)
    + Add instruction per cycle charts (perf plugin)
    (gh#netdata/netdata#11392)
    + Add autovacuum and tx wraparound charts (python.d/postgres)
    (gh#netdata/netdata#11267)
    + Add web3 and blockchains groups (apps plugin)
    (gh#netdata/netdata#11220)
    + Implement merging user/stock configuration files
    (python.d plugin) (gh#netdata/netdata#11217)
    + Rename default job from 'local' to 'anomalies'
    (python.d/anomalies) (gh#netdata/netdata#11178)
    + Add standby lag and blocking transactions charts
    (python.d/postgres) (gh#netdata/netdata#11169)
  * Bug fixes
    + Fix renaming for cgroups with dots in the path
    (cgroups plugin) (gh#netdata/netdata#11775)
    + Fix exiting on SIGPIPE (go.d plugin)
    (gh#netdata/go.d.plugin#630)
    + Fix domain syntax validation (go.d/whoisquery)
    (gh#netdata/go.d.plugin#629)
    + Fix missing NONE in valid request methods (go.d/squidlog)
    (gh#netdata/go.d.plugin#621)
    + Remove wrong "queue_messages_in_queues" chart (go.d/vernemq)
    (gh#netdata/go.d.plugin#601)
    + Fix HTTP/socket client initialization order (go.d/phpfpm)
    (gh#netdata/go.d.plugin#591)
    + Fix scraping metrics when resources are not discovered
    (go.d/vsphere)
    (gh#netdata/go.d.plugin#589)
    + Fix LTSV log format parsing (go.d/weblog)
    (gh#netdata/go.d.plugin#584)
    + Fix expiration date parsing (go.d/whoisquery)
    (gh#netdata/go.d.plugin#575)
    + Fix containers name resolution for crio/containerd runtime
    (cgroups plugin)
    (gh#netdata/netdata#11756)
    + Add sensors to charts.d.conf and add a note on how to enable
    it (charts.d plugin)
    (gh#netdata/netdata#11715)
    + Fix crashing of the wal query if wal-file was removed
    concurrently (python.d/postgres)
    (gh#netdata/netdata#11697)
    + Fix "lsns: unknown column" logging (cgroups plugin)
    (gh#netdata/netdata#11687)
    + Fix nfsd RPC metrics and remove unused nfsd charts and
    metrics (proc/nfsd)
    (gh#netdata/netdata#11632)
    + Fix "proc4ops" chart family (proc/nfsd)
    (gh#netdata/netdata#11623)
    + Fix swap size calculation (cgroups plugin)
    (gh#netdata/netdata#11617)
    + Fix RSS memory counter for systemd services (cgroups plugin)
    (gh#netdata/netdata#11616)
    + Fix VBE parsing (python.d/varnish)
    (gh#netdata/netdata#11596)
    + Remove unused synproxy chart (proc/synproxy)
    (gh#netdata/netdata#11582)
    + Fix zpool state parsing (proc/zfs)
    (gh#netdata/netdata#11545)
    + Fix null values returned by '_cat/indices' API
    (python.d/elasticsearch)
    (gh#netdata/netdata#11501)
    + Fix replication_slot chart on standby (python.d/postgres)
    (gh#netdata/netdata#11455)
    + Fix an inconsistent status check (charts.d/apcupsd)
    (gh#netdata/netdata#11435)
    + Fix plugin name (stats.d plugin)
    (gh#netdata/netdata#11400)
    + Fix lack of "module" in chart definition (all chart.d modules)
    (gh#netdata/netdata#11390)
    + Fix various python modules charts contexts
    (python.d/smartd_log, mysql, zscores)
    (gh#netdata/netdata#11310)
    + Fix current operation charts title and context (proc/mdstat)
    (gh#netdata/netdata#11289)
    + Fix handling of adding slabs after discovery
    (slabinfo plugin) (gh#netdata/netdata#11257)
  eBPF
  * New
    + Add MD flush calls tracking
    (gh#netdata/netdata#11681)
    + Add shared memory system calls tracking
    (gh#netdata/netdata#11560)
    + Add OOM kills tracking
    (gh#netdata/netdata#11470)
    + Add soft IRQ latency tracking
    (gh#netdata/netdata#11445)
    + Add hard IRQ latency tracking
    (gh#netdata/netdata#11410)
    + Add mount/umount calls tracking
    (gh#netdata/netdata#11358)
    + Add btrfs latency monitoring
    (gh#netdata/netdata#11348)
    + Add ZFS latency monitoring
    (gh#netdata/netdata#11330)
    + Add NFS latency monitoring
    (gh#netdata/netdata#11313)
    + Add disk latency monitoring
    (gh#netdata/netdata#11276)
    + Add XFS latency monitoring
    (gh#netdata/netdata#11238)
    + Add ext4 latency monitoring
    (gh#netdata/netdata#11224)
    + Add extended swap monitoring
    (gh#netdata/netdata#11090)
  * Improvements
    + Add (eBPF) to submenu
    (gh#netdata/netdata#11721)
    + Process monitoring cleanup and improvements
    (gh#netdata/netdata#11643)
    + Add integration with cgroups plugin (socket, shared memory,
    cachestat)
    (gh#netdata/netdata#11642)
    + Add integration with cgroups plugin (process,
    file descriptor, VFS, directory cache and OOMkill)
    (gh#netdata/netdata#11611)
    + Add initial integration with cgroups plugin (swap)
    (gh#netdata/netdata#11573)
    + Add integration with cgroups plugin (create shared memory
    with cgroups)
    (gh#netdata/netdata#11559)
    + Update charts descriptions
    (gh#netdata/netdata#11547)
    + Convert eBPF submenus to lowercase
    (gh#netdata/netdata#11511)
    + Socket monitoring code improvements and update charts
    descriptions
    (gh#netdata/netdata#11441)
    + Move file operation monitoring to a separate thread
    (gh#netdata/netdata#11401)
    + Add module names for threads
    (gh#netdata/netdata#11387)
    + Move repeating part of latency chart descriptions to the
    family level
    (gh#netdata/netdata#11363)
    + Reduce plugin's memory usage
    (gh#netdata/netdata#11256)
    + Assorted improvements and fixes
    (gh#netdata/netdata#11230)
    + Move VFS monitoring to a separate threads and add new charts
    (gh#netdata/netdata#11187)
  * Bug fixes
    + Fix command line arguments
    (gh#netdata/netdata#11670)
    + Fix hardirq/softirq value init logic
    (gh#netdata/netdata#11471)
    + Fix VFS index reference
    (gh#netdata/netdata#11356)
    + Fix a case when multiple eBPF plugins are running
    (gh#netdata/netdata#11287)
    + Fix applying configuration options
    (gh#netdata/netdata#11253)
    + Fix a segfault when ebpf_load_program returns null pointer
    (gh#netdata/netdata#11203)
    + Fix a wrong pointer to a function and move parser to main
    thread
    (gh#netdata/netdata#11152)
  Health
  * Improvements
    + Remove pihole_blocked_queries alert
    (gh#netdata/netdata#11829)
    + Improve check for supported -F parameter in sendmail
    (gh#netdata/netdata#11506)
    + Add custom e-mail headers
    (gh#netdata/netdata#11454)
    + Add 'cockroachdb_underreplicated_ranges' alarm
    (gh#netdata/netdata#11360)
    + Disable 'oom_kill' alarm on k8s nodes
    (gh#netdata/netdata#11359)
    + Add geth stock alarms
    (gh#netdata/netdata#11341)
    + Remove pythond modules specific last_collected alarms
    (gh#netdata/netdata#11307)
    + Remove CockroachDB deprecated alarms
    (gh#netdata/netdata#11235)
    + Add new email notification template
    (gh#netdata/netdata#11219)
    + Add system clock synchronization state alarm
    (gh#netdata/netdata#11177)
    + Add python.d/go.d jobs last_collected_secs alarms
    (gh#netdata/netdata#11168)
    + Make stocks alarms less sensitive
    (gh#netdata/netdata#11153)
  * Bug fixes
    + Fix swap_used alarm calculation
    (gh#netdata/netdata#11672)
    + Fix ram level alarms
    (gh#netdata/netdata#11452)
    + Fix 'gearman_workers_queued' alarm
    (gh#netdata/netdata#11361)
    + Fix sending MS Teams notifications to multiple channels
    (gh#netdata/netdata#11355)
    + Fix sendmail 'unrecognized option: F' issue
    (gh#netdata/netdata#11283)
    + Update old logo to new one
    (gh#netdata/netdata#11263)
    + Swap class and type attributes in stock alarm configurations
    (gh#netdata/netdata#11240)
    + Fix alarm line 'charts' matching
    (gh#netdata/netdata#11204)
  Other
  * Improvements
    + Clean compilation warnings
    (gh#netdata/netdata#11810)
    + Fix coverity issues
    (gh#netdata/netdata#11809)
    + Add commands to check and fix database corruption
    (gh#netdata/netdata#11828)
    + Use two digits after the decimal point for the anomaly rate.
    (gh#netdata/netdata#11804)
    + Always queue alerts to aclk_alert
    (gh#netdata/netdata#11806)
    + Add some logging for cloud new architecture to access.log
    (gh#netdata/netdata#11788)
    + Delete from aclk alerts table if ack'ed from cloud one day
    ago
    (gh#netdata/netdata#11779)
    + Remove feature flag for ACLK new cloud architecture
    (gh#netdata/netdata#11774)
    + Insert alert into aclk_alert directly instead of queuing it
    (gh#netdata/netdata#11769)
    + Store and submit dimension delete messages for new cloud
    architecture
    (gh#netdata/netdata#11765)
    + Implement cloud initiated disconnect command
    (gh#netdata/netdata#11723)
    + Announce proto capability and enable if cloud supports
    (gh#netdata/netdata#11476)
    + Add exit points between env and OTP
    (gh#netdata/netdata#11751)
    + Improve the ACLK sync process for the new cloud architecture
    (gh#netdata/netdata#11744)
    + Disable C++ warnings from dlib library.
    (gh#netdata/netdata#11738)
    + Add queue removed alerts to cloud for new architecture
    (gh#netdata/netdata#11704)
    + Add support to stream chart labels on a parent - child setup
    (gh#netdata/netdata#11675)
    + Add snapshot message for cloud new architecture
    (gh#netdata/netdata#11664)
    + Add protobuf to -W buildinfo output.
    (gh#netdata/netdata#11634)
    + Add new alarm status protocol messages
    (gh#netdata/netdata#11612)
    + Add local webserver API/v1 call "aclk"
    (gh#netdata/netdata#11588)
    + Make New Cloud architecture optional for ACLK-NG
    (gh#netdata/netdata#11587)
    + Enable additional functionality for the new cloud
    architecture
    (gh#netdata/netdata#11579)
    + Add alert message support for ACLK new architecture
    (gh#netdata/netdata#11552)
    + Add support for Anomaly Detection MVP
    (gh#netdata/netdata#11548)
    + Add New Cloud Protocol files to CMake
    (gh#netdata/netdata#11536)
    + Add archive uploads for dist, package build, and static
    build checks.
    (gh#netdata/netdata#11534)
    + Add node message support for ACLK new architecture
    (gh#netdata/netdata#11514)
    + Clean netdata naming
    (gh#netdata/netdata#11484)
    + Add aclk/cloud state command to netdatacli
    (gh#netdata/netdata#11462)
    + Add chart message support for ACLK new architecture
    (gh#netdata/netdata#11447)
    + Add Alert Related API for new protocol
    (gh#netdata/netdata#11424)
    + Update SQLite version from v3.33.0 to 3.36.0
    (gh#netdata/netdata#11423)
    + Add SQLite unit tests
    (gh#netdata/netdata#11422)
    + Add NodeInstanceInfo API
    (gh#netdata/netdata#11419)
    + Use SQLite to store the health log and alert configurations.
    (gh#netdata/netdata#11399)
    + Add ACLK synchronization event loop
    (gh#netdata/netdata#11396)
    + Add HTTP basic authentication to Prometheus remote write and
    HTTP versions of Graphite, JSON, OpenTSDB
    (gh#netdata/netdata#11394)
    + Add new Cloud chart related parsers and generators
    (gh#netdata/netdata#11393)
    + Remove warning when GCC 8.x is used
    (gh#netdata/netdata#11389)
    + Add support to allow ACLK-NG to grow MQTT buffer
    (gh#netdata/netdata#11340)
    + Add support for bundled protobuf
    (gh#netdata/netdata#11335)
    + Add ACLK-NG cloud request type charts
    (gh#netdata/netdata#11326)
    + Add HTTP access log messages for ACLK-NG
    (gh#netdata/netdata#11318)
    + Add a log message when the page cache manager sleeps for
    more than 1 second.
    (gh#netdata/netdata#11314)
    + Add hop count for children
    (gh#netdata/netdata#11311)
    + Remove access check for install-type file
    (gh#netdata/netdata#11288)
    + Support TLS SNI in ACLK-NG
    (gh#netdata/netdata#11285)
    + Make ACLK-NG the default if available
    (gh#netdata/netdata#11272)
    + Add extra posthog attributes
    (gh#netdata/netdata#11237)
    + Add support to ACLK-NG for new Cloud NodeInstance related
    msgs
    (gh#netdata/netdata#11234)
    + Add support so ACLK NG and Legacy can coexist
    (gh#netdata/netdata#11225)
    + Move cleanup of obsolete charts to a separate thread
    (gh#netdata/netdata#11222)
    + Add check to only report the exit code when anonymous
    statistics script fails
    (gh#netdata/netdata#11215)
    + Reduce memory needed per dimension
    (gh#netdata/netdata#11212)
    + Improve dbengine intialization to ignore journal files that
    can not be read
    (gh#netdata/netdata#11210)
    + Use memory mode RAM if memory mode dbengine is specified but
    not available
    (gh#netdata/netdata#11207)
    + Improve return status check for the execution of anonymous
    statistics script
    (gh#netdata/netdata#11188)
    + Reuse the SN_EXISTS bit to track anomaly status.
    (gh#netdata/netdata#11154)
    + Remove deprecated command line options
    (gh#netdata/netdata#11149)
    + Remove unecessary relative paths when including headers.
    (gh#netdata/netdata#11124)
    + Add field to provide UTC offset in seconds and edit health
    config command
    (gh#netdata/netdata#11051)
  * Bug fixes
    + Set NETDATA_CONTAINER_OS_DETECTION properly
    (gh#netdata/netdata#11827)
    + Fix agent crash when ACLK sync thread is not initialized
    (gh#netdata/netdata#11820)
    + Simple fix for the data API query
    (gh#netdata/netdata#11787)
    + Use the proper format specifier when logging configuration
    options.
    (gh#netdata/netdata#11795)
    + Use correct hop count if host is already in memory
    (gh#netdata/netdata#11785)
    + Fix proc/interrupts parser
    (gh#netdata/netdata#11783)
    + Skip sending hidden dimensions via ACLK
    (gh#netdata/netdata#11770)
    + Fix host hop count reported to the cloud
    (gh#netdata/netdata#11768)
    + Fix log if D_ACLK is used
    (gh#netdata/netdata#11763)
    + Fix retention message duration when no local metrics are
    found
    (gh#netdata/netdata#11762)
    + Fix an issue with incomplete payload served when https is
    enabled
    (gh#netdata/netdata#11754)
    + Fix a type in the popocorn information message
    (gh#netdata/netdata#11745)
    + Fix /api/v1/info if ml-info is missing
    (gh#netdata/netdata#11739)
    + Fix typo in aclk_query.c
    (gh#netdata/netdata#11737)
    + Fix online chart in NG not updated properly
    (gh#netdata/netdata#11734)
    + Fix coverity CID #373610
    (gh#netdata/netdata#11719)
    + Fix loading old and custom dashboards
    (gh#netdata/netdata#11710)
    + Fix coverity issues 373612 & 373611
    (gh#netdata/netdata#11684)
    + Fix warnings from -Wformat-truncation=2
    (gh#netdata/netdata#11676)
    + Fix interval usage and reduce I/O
    (gh#netdata/netdata#11662)
    + Fix build issue related to legacy aclk and new arch code
    (gh#netdata/netdata#11655)
    + Fix typo in URL when calling env
    (gh#netdata/netdata#11651)
    + Fix false poll timeout
    (gh#netdata/netdata#11650)
    + Fix chart config overflow
    (gh#netdata/netdata#11645)
    + Fix an overflow when unsigned integer subtracted
    (gh#netdata/netdata#11638)
    + Fix coverity issues 373400-373402
    (gh#netdata/netdata#11631)
    + Fix proper initialization struct with zeroes
    (gh#netdata/netdata#11621)
    + Fix https client
    (gh#netdata/netdata#11608)
    + Fix CID 339027 and reverse arguments
    (gh#netdata/netdata#11578)
    + Fix resource leak when analytics thread stops
    (gh#netdata/netdata#11575)
    + Fix coverity report issues CID_373247-373251
    (gh#netdata/netdata#11549)
    + Fix coverity issues for health config
    (gh#netdata/netdata#11535)
    + Fix issue with log messages appearing in the terminal
    instead of the error.log on startup
    (gh#netdata/netdata#11524)
    + Fix issues in Alarm API
    (gh#netdata/netdata#11491)
    + Fix list corruption in ACLK sync code and remove fatal
    (gh#netdata/netdata#11444)
    + Fix coverity reported issues 372243 - 372248
    (gh#netdata/netdata#11429)
    + Fix CID 372233 to CID 372236
    (gh#netdata/netdata#11411)
    + Fix bundled protobuf linkage on systems needing -latomic
    (gh#netdata/netdata#11406)
    + Fix coverity issue 372222
    (gh#netdata/netdata#11404)
    + Fix typo in analytics.c
    (gh#netdata/netdata#11329)
    + Fix coverity errors in ACLK
    (gh#netdata/netdata#11322)
    + Fix confusing error in ACLK Legacy
    (gh#netdata/netdata#11278)
    + Fix an issue to send correct aclk implementation used by
    agent to posthog.
    (gh#netdata/netdata#11247)
    + Fix error on --disable-cloud
    (gh#netdata/netdata#11244)
    + Fix mqtt_websockets submodule version
    (gh#netdata/netdata#11196)
    + Fix claiming script exit code when daemon not running and
    the claim was successful
    (gh#netdata/netdata#11195)
    + Fix loading of class, component and type from health log
    when sufficient fields are detected.
    (gh#netdata/netdata#11193)
    + Fix typo in aclk.c
    (gh#netdata/netdata#11170)
* Tue Nov 23 2021 Wolfgang Engel <wolfgang.engel@suse.com>
- Fix build on s390x
  (Adding s390x to ifnarch statement for xenstat in spec file)
* Wed Jun 23 2021 Mia Herkt <mia@0x0.st>
- Update to 1.31.0 (go.d.plugin 0.29.0)
  The v1.31.0 release of Netdata comes with re-packaged and
  redesigned elements of the dashboard to help you focus on your
  metrics, even more Linux kernel insights via eBPF, on-node machine
  learning to help you find anomalies, and much more.
  This release contains 10 new collectors, 54 improvements (7 in the
  dashboard), 31 documentation updates, and 29 bug fixes.
  At a glance
  We re-packaged and redesigned portions of the dashboard to improve
  the overall experience. Part of this effort is better handling of
  dashboard code during installation—anyone using third-party
  packages (such as the Netdata Homebrew formula) will start seeing
  new features and the new designs starting today. The timeframe
  picker has moved to the top panel, and just to its right are two
  counters with live CRITICAL and WARNING alarm statuses for your
  node. Click on either of these two open the alarms modal.
  We've also pushed a number of powerful new collectors, including
  directory cache monitoring via eBPF. By monitoring directory cache,
  developers and SREs alike can find opportunities to optimize memory
  usage and reduce disk-intensive operations.
  Our new Z-scores and changefinder collectors use machine learning
  to let you know, at a glance, when key metrics start to behave
  oddly. We'd love to get feedback on these sophisticated, subjective
  new brand of collectors!
  Improvements
  * Automatically trigger Helmchart PR on Agent release.
    (gh#netdata/netdata#11084)
  * Implement ACLK env endpoint. (gh#netdata/netdata#10833)
  * Implement new HTTPS client for ACLK. (gh#netdata/netdata#10805)
  * Update ACLK passwd endpoint to match specifications of the new
    architecture. (gh#netdata/netdata#10859)
  * Implement ACLK new backoff (TBEB) architecture.
    (gh#netdata/netdata#10941)
  * Add functionality to store node_id for a host.
    (gh#netdata/netdata#11059)
  * Remove version negotiation from ACLK-NG.
    (gh#netdata/netdata#10980)
  * Persist claim IDs in local database for parent and children.
    (gh#netdata/netdata#10993)
  * Provide more agent analytics to PostHog.
    (gh#netdata/netdata#11020)
  * Reduce logging when sending agent analytics.
    (gh#netdata/netdata#11091)
  * Remove error message on Netdata restart.
    (gh#netdata/netdata#8685)
  * Add a timeout when sending anonymous statistics using curl.
    (gh#netdata/netdata#11010)
  * Improve dash-example.html. (gh#netdata/netdata#10870)
  * Add host_cloud_enabled attribute to analytics.
    (gh#netdata/netdata#11100)
  Dashboard
  * Bundle the react dashboard code into the agent repo directly.
    (gh#netdata/netdata#11139)
  * Add dashboard info strings for systemdunits collector.
    (gh#netdata/netdata#10904)
  * Update dashboard version to v2.17.0. (gh#netdata/netdata#10856)
    + Top bar, side panel and overall navigation has been
    redesigned.
    + Top bar now includes a light bulb icon with news/features and
    the number of CRITICAL or WARNING alarms.
    + Documentation and settings buttons moved to the sidebar.
    + Improved rendering of sign in/sign up option button along
    with an operational status option (under user settings).
    + In the left panel, nodes show a status badge and are now
    searchable if there are more than 4.
  Health
  * Improvements
    + Add charts configuration option to templates.
    (gh#netdata/netdata#11054)
    + Add new attributes to health configuration files.
    (gh#netdata/netdata#10961)
    + Add inconsistent state to the mysql_galera_cluster_state
    alarm. (gh#netdata/netdata#10945)
    + Add systemdunits collector alarms. (gh#netdata/netdata#10906)
    + Use average instead of sum in VerneMQ alarms.
    (gh#netdata/netdata#11037)
    + Check configuration for CUSTOM and MSTEAM.
    (gh#netdata/netdata#11113)
    + Reduce alarms notifications dump logging.
    (gh#netdata/netdata#11116)
  * Bug fixes
    + Add synchronization.conf to the Makefile.
    (gh#netdata/netdata#10907)
    + Fix Microsoft Teams naming. (gh#netdata/netdata#9905)
  Collectors
  * New
    + Add a chart for out of memory kills.
    (gh#netdata/netdata#10880)
    + Add a chart with Netdata uptime. (gh#netdata/netdata#10997)
    + Add a module for ZFS pool state. (gh#netdata/netdata#11071)
    + Add a plugin for the system clock synchronization state.
    (gh#netdata/netdata#10895)
    + Add new charts for extended disk metrics.
    (gh#netdata/netdata#10939)
    + Add support for renaming libvirtd LXC containers.
    (gh#netdata/netdata#11006)
    + Add a metric for Percpu memory. (gh#netdata/netdata#10964)
    + Add an eBPF directory cache collector.
    (gh#netdata/netdata#10855)
    + Add a Z-scores python collector. (gh#netdata/netdata#10673)
    + Add changefinder python collector. (gh#netdata/netdata#10672)
  * Improvements
    + Remove dots in cgroup IDs. (gh#netdata/netdata#11050)
    + Add support for attribute 249 (NAND Writes 1GiB) to the
    smartd_log module. (gh#netdata/netdata#10872)
    + Add RAID level to the mdstat collector chart families.
    (gh#netdata/netdata#11024)
    + Update fping version. (gh#netdata/netdata#10977)
    + Add plugin and module names to the python.d.plugin runtime
    charts. (gh#netdata/netdata#11007)
    + Move global stats to a separate thread.
    (gh#netdata/netdata#10991)
    + Add memory size adjustments for eBPF hash tables.
    (gh#netdata/netdata#10962)
    + Add improvements to anomalies collector.
    (gh#netdata/netdata#11003)
    + Add support for loading of kprobe names in the eBPF plugin.
    (gh#netdata/netdata#11034)
    + Don't repeat the cgroup discovery cleanup info message.
    (gh#netdata/netdata#11101)
    + Change ACLK statistics charts units from kB/s to KiB/s.
    (gh#netdata/netdata#11103)
  * Bug fixes
    + Fix the detection of cgroups v2 by checking the version of
    the default cgroup mountpoint. (gh#netdata/netdata#11102)
    + Fix eBPF cachestat chart type. (gh#netdata/netdata#11074)
    + Fix gaps in eBPF cachestat charts. (gh#netdata/netdata#10972)
    + Fix detection of opensipsctl executable.
    (gh#netdata/netdata#10978)
    + Fix network interfaces detection when using virsh.
    (gh#netdata/netdata#11096)
    + Fix eBPF plugin crash during shutdown.
    (gh#netdata/netdata#10957)
  Exporting
  * Improvements
    + Allow the remote write configuration to have multiple
    destinations (gh#netdata/netdata#11005)
  * Bug fixes
    + Fix backend chart filtering backward compatibility.
    (gh#netdata/netdata#11002)
  Bug fixes
  * Reduce the number of ACLK chart updates during chart
    obsoletion. (gh#netdata/netdata#11133)
  * Fix SSL random failures when using multithreaded web server
    with OpenSSL < 1.1.0. (gh#netdata/netdata#11089)
  * Fix storing an NULL claim ID on a parent node.
    (gh#netdata/netdata#11036)
  * Prevent MQTT connection attempt on OTP failure.
    (gh#netdata/netdata#10839)
  * Rename struct fields from class to classification.
    (gh#netdata/netdata#11019)
  * Fix spelling mistakes in various components:
    + aclk (gh#netdata/netdata#10910)
    + build (gh#netdata/netdata#10909)
    + collectors (gh#netdata/netdata#10912)
    + daemon (gh#netdata/netdata#10913)
    + database (gh#netdata/netdata#10914)
    + exporting (gh#netdata/netdata#10915)
    + libnetdata (gh#netdata/netdata#10917)
    + health (gh#netdata/netdata#10916)
    + streaming (gh#netdata/netdata#10919)
    + tests (gh#netdata/netdata#10920)
    + backend (gh#netdata/netdata#10911)
    + bidirectional (gh#netdata/netdata#10918)
    + HTTP API (gh#netdata/netdata#10921)
    + web (gh#netdata/netdata#10922)
* Wed Apr  7 2021 Mia Herkt <mia@0x0.st>
- Update to 1.30.0 (go.d.plugin 0.28.1)
  The v1.30.0 release of Netdata completely replaces Google
  Analytics/GTM for product telemetry (disabled by default in
  openSUSE). We're also releasing the first changes in an upcoming
  overhaul to both our dashboard UI/UX and the suite of preconfigured
  alarms that comes with every installation.
  v1.30.0 contains 3 new collectors, 3 enhancements to notifications
  method, 38 improvements (13 in the dashboard), 16 documentation
  updates, and 17 bug fixes.
  At a glance
  The ACLK-NG is a much faster method of securely connecting a node
  to Netdata Cloud. In addition, there are no external dependencies
  to our custom libmosquitto and libwebsockets libraries, which means
  there's no more need to build these during installation.
  We replaced Google Analytics/GTM, which we used for collecting
  product telemetry, with a self-hosted instance of the open-source
  PostHog project. When sending statistics to PostHog, any fields
  that might contain identifiable information, such as an IP address
  or URL, are hardcoded. If you previously opted-out of anonymous
  statistics, this migration does not change your existing settings.
  Improvements
  * Add check for children connecting to a parent agent with an
    unsupported memory mode.
  * Add lock check to avoid shutdown when compiled with internal
    and locking checks.
  * Update chart's metadata in database when it already exists
    during creation.
  * ACLK separate HTTPS client.
  * Add new ACLK implementation (ACLK-NG).
  * Add CPU statistics per ALCK query thread.
  * Add _aclk_impl label to the /api/v1/info endpoint.
  * Add a new chart parameter to the /api/v1/alarm_log endpoint.
  * Add data query support for archived charts.
  * Add HTTP cookie (SameSite, Secure).
  * Add statistics per Cloud query type.
  * Add support for changing the number of pages per database
    engine extent.
  * Add the ability to store chart labels in the database.
  * Enable metadata persistence in all memory modes.
  * Increase curl connect-timeout and decrease number of claim
    attempts.
  * Increase the ACLK exponential backoff randomness.
  * Log ACLK Cloud commands to access.log.
  * Remove an unused function warning in legacy version of the
    ACLK.
  * Remove unreachable #else directives in plugins.
  * Rename struct avl to avl_element and the typedef to avl_t.
  * Replace Google Analytics with PostHog for backend telemetry
    events.
  * Skip C++ incompatible header in main libnetdata header.
  * Try to keep all pages from extents read from disk in the cache.
  * Use a parameter name that is not a reserved keyword in C++.
  * Use of out-of-line struct definitions.
  Dashboard
  * Add max value to the nvidia_smi.fan_speed gauge.
  * Add state map to duplex and operstate charts.
  * Add supervisord to dashboard_info.js.
  * Fix broken external links.
  * Make network state map syntax consistent in dashboard_info.js.
  * Fix alarms log export.
  * Persist relative timeframe.
  * Allow multirow names in the replicated nodes list.
  * Fix the date & time picker overlap.
  * Update Font Awesome.
  * Truncate long names.
  * Update links: change docs.netdata.cloud to learn.netdata.cloud.
  Health
  * Bug fixes
    + Fix delaying CLEAR notifications when using the repeat
    feature.
    + Fix wrong count of entries in the alarm.log.
  * Alarms
    + Add wmi_ prefix to the wmi collector network alarms.
    + Add collector prefix to the external collectors alarms.
    + Apply adapter_raid alarms for every logical/physical device.
    + Apply megacli alarms for every adapter/physical disk.
    + Exclude cgroups network interfaces from packets dropped
    alarms.
    + Fix various alarms critical and warning thresholds
    hysteresis.
    + Improve alarms info fields.
    + Make VerneMQ alarms less sensitive.
    + Make alarms less sensitive.
    + Remove exporting_metrics_lost template.
    + Remove ram_in_swap alarm.
    + Use separate packets_dropped_ratio alarms for wireless
    network interfaces.
  * Notifications
    + Add ability to change port number when using IRC notification
    method.
    + Add dump_methods parameter to alarm-notify.sh.in.
    + Log an error if there is a failure during an email alarm
    notification.
  Collectors
  * New
    + Add monitoring of synchronization system calls to the eBPF
    collector.
    + Add monitoring of Linux page cache to the eBPF collector.
  * Improvements
    + Add k6.conf to the StatsD collector.
    + Clean up the eBPF collector.
    + Use working set for memory utilization in the cgroups
    collector.
    + Add new configuration parameters to the example Python
    collector.
    + Add carrier and MTU charts for network interfaces.
    + Improve email, cron, and UPS groups in the apps.plugin
    configuration.
    + Add Wireguard to the vpn group in the apps.plugin
    configuration.
    + Add alarm values collection to the Python alarms collector.
    + Add attribute 233 (Media Wearout Indicator (SSD)) collection
    to the python smartd_log collector.
    + Move network interface speed, duplex, and operstate variables
    to charts.
    + Update go.d.plugin version to v0.28.1.
    + Add a noauthcodecheck workaround flag to the freeipmi
    collector.
  * Bug fixes
    + Fix eBPF collector compatibility with kernels v5.11+.
    + Fix disks identification in the diskstats collector.
    + Fix the count of cpuset.cpus in the cgroups collector.
    + Fix disk utilization and backlog charts in the diskstats
    collector.
  Exporting
  * Bug fixes
    + Fix adding duplicate _total suffixes for the Prometheus
    collector.
  Bug fixes
  * Fix a typo in main.h.
  * Fix a typo in backend_prometheus.c.
  * Fix a typo in dashboard_info.js.
  * Fix segfault due to misalignment between global and StatsD
    memory modes.
  * Fix zombie alarms for charts that are obsolete/removed.
  * Fix a Coverity warning in the new MQTT library.
  * Fix a parameter binding issue when storing chart names in the
    database.
  * Fix crash when executing data query with context and
    non-existing chart_label_key.
  * Fix claiming behind Squid proxy.
  * Fix Coverity issue (CID 367566).
  * Fix memory leak when archived data is requested.
  * Fix clash with C++ standard definitions by changing abs to ABS.
* Tue Feb 23 2021 Mia Herkt <mia@0x0.st>
- Update to 1.29.3
  Release v1.29.3 is a patch release to improve the stability of the
  Netdata Agent.
  We discovered a bug that when proc.plugin attempts to collect the
  operstate parameter for a virtual network interface. If the chart
  is obsoleted, the Netdata Agent crashes.
  This release also contains additional bug fixes and improvements.
  Bug fixes
  * Fix proc.plugin to invalidate RRDSETVAR pointers on obsoletion.
* Thu Feb 18 2021 Mia Herkt <mia@0x0.st>
- Update to 1.29.2
  Release v1.29.2 is a patch release to improve the stability of the
  Netdata Agent.
  We discovered that an improvement introduced in v1.29.0 could
  inadvertently set all os_* host labels to unknown, which could
  affect users who leverage these host labels to organize their
  nodes, deploy health entities, or export metrics to external
  time-series databases. This bug has been fixed.
  This release also contains additional bug fixes and improvements.
  Improvements
  * Make the Opsgenie API URL configurable.
  * Add k8s_cluster_id host label.
  * Enable apps.plugin aggregation debug messages.
  * Add configuration parameter to disable stock alarms.
  * Add ACLK proxy setting as host label.
  * Add freeswitch to apps_groups.conf.
  * Simplify thread creation and remove unnecessary variables in
    the eBPF plugin.
  Bug fixes
  * Fix the context filtering on the data query endpoint.
  * Fix container/host detection in the system-info.sh script.
  * Add a small delay to the ipv4_tcp_resets alarms.
  * Fix collecting operstate for virtual network interfaces.
  * Fix sendmail unrecognized option F error.
  * Fix so that raw binary data should never be printed.
  * Change KSM memory chart type to stacked.
  * Allow the REMOVED alarm status via ACLK if the previous status
    was WARN/CRIT.
  * Reduce excessive logging in the ACLK.
- Changes in 1.29.1
  Release v1.29.1 is a hotfix release to address a crash in the
  Netdata Agent.
  A locking bug in one of the internal collectors in Netdata could
  cause it to crash during shutdown in a way that would result in the
  Netdata Agent taking an excessively long time to exit.
  Bug fixes
  * Fix crash during shutdown of cgroups internal plugin.
* Wed Feb  3 2021 Mia Herkt <mia@0x0.st>
- Update to 1.29.0 (go.d.plugin 0.27.0)
  The v1.29.0 release of the Netdata Agent is a maintenance release
  that brings incremental but necessary improvements that make your
  monitoring experience more robust. We've pushed improvements and
  bug fixes to the installation and update scripts, enriched our
  library of collectors, and focused on fixing bugs reported by the
  community.
  At a glance
  Netdata now collects and meaningfully organizes metrics from both
  the Couchbase JSON document database and the nginx-module-vts
  module for exposing metrics about NGINX virtual hosts.
  We've also migrated more collectors from Python to Go in our
  continued efforts to make data collection faster and more robust.
  The newest effort includes our Redis, Pika, and Energi Core Wallet
  collectors.
  On the dashboard, we improved the responsiveness of panning forward
  and backward through historical metrics data by preventing
  unnecessary updates and reducing the number of calls. The charts
  should also now immediately update when you stop panning.
  Improvements
  * Reduce the number of alarm updates on ACLK.
  * Remove unused entries from structures.
  * Improve the retry/backoff during claiming.
  * Support multiple chart label keys in data queries.
  * Truncate excessive information from titles for apps and
    cgroups collectors.
  * Use mguid instead of hostname in the ACLK collector list.
  * Cleanup and minor fixes to eBPF collector.
  * Add _is_k8s_node label to the host labels.
  * Move ACLK into a legacy subfolder.
  * Exclude autofs by default in the diskspace plugin.
  * Mark internal functions as static in health code.
  * Remove unused struct in health code.
  * Add support for per series styling for dygraphs.
  Dashboard
  * Fix minor vulnerability alert by updating socket-io dependency.
  * Fix dygraph panning responsiveness, chart heights and
    performance improvements.
  * Make legend position configurable.
  Collectors
  * Add Go version of the redis collector.
  * Add Go version of the pika collector.
  * Add Go version of the energis collector.
  * Add a new nginxvts collector.
  * Add a new couchbase collector.
  * Add Traefik v2 to the prometheus collector default
    configuration.
  * Add an expected_prefix configuration option to the prometheus
    collector.
  * Add patterns support to the filecheck collector.
  Bug fixes
  * Fix container detection from systemd-detect-virt.
  * Fix handling of TLS config so that cURL works in all cases.
  * Fix disconnect message sent via ACLK on agent shutdown
  * Fix prometheus remote write header
  * Fix values in Prometheus export for metrics, collected by the
    Prometheus collector
  * Fix handling spaces in labels values in the Prometheus
    collector
  * Fix mysql.slave_status alarm for go mysql collector
  * Make mdstat_mismatch_cnt alarm less strict
  * Dispatch cgroup discovery into another thread
  * Fix data source option for Prometheus web API in exporting
    configuration
  * Fix anomalies collector custom model bug
  * Fix broken dbengine stress tests.
  * Fix segmentation fault in the agent
  * Fix memory allocation when computing standard deviation
  * Fix temperature parsing in the hddtemp collector
  * Fix postgres password bug and change default config
  * Add handling "yes" and "no" and flexible space match in the
    python.d/fail2ban plugin
  * Fix spelling mistakes in the Python plugin and documentation.
* Mon Dec 28 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to v1.28
  Release v1.28.0 is a hotfix release to address a deadlock in the
  Netdata Agent. If the Agent-Cloud link (ACLK) connection drops and
  the Agent fails to queue an on_connect message, it also fails to
  properly release a lock in the web server thread.
* Fri Dec 25 2020 Mia Herkt <mia@0x0.st>
- Enable additional dependencies (gprc, json, libcurl, libelf,
  libwebsockets, protobuf, snappy, xenstat, yajl)
- Update to v1.27.0 (go.d.plugin 0.26.2)
  The v1.27.0 release of the Netdata Agent brings dramatic
  improvements to long-term metrics storage via the database engine,
  and new dashboard features like a time & date picker for
  visualizing precise timeframes. Two new collectors bring incredible
  new value to existing features, including a bit of machine learning
  magic.
  This release contains 8 new collectors, 1 new notification method
  (2 others enhanced), 54 improvements, 41 documentation updates, and
  58 bug fixes.
  Improvements
  * Add labels for Kubernetes pods and containers.
  * Add plugin and module health entities.
  * Migrate the metadata log to SQLite.
  * Add an extent cache to the database engine.
  * Added new data query option allow_past.
  Netdata Cloud
  * Add the ability to query child nodes by their GUID.
  * Add child availability messages to the ACLK.
  * Add a metric showing how long a query spent in the queue.
  * Completely hide the SSO iframe.
  Collectors
  * Add alarms obsoletion and disable alarms collector by default.
  * Add calls for tcp_sendmsg, tcp_retransmit_skb, tcp_cleanup_rcv,
    udp_sendmsg, udp_recvmsg functions charts to the eBPF
    collector.
  * Add two more insignificant warnings to suppress in anomalies
    collector.
  * Add the number of allocated/stored objects within each storage
    to the varnish collector.
  * Add a wireless statistics collector.
  * Add support for MSE (Massive Storage Engine) to the varnish
    collector.
  * Remove remove crit from unmatched alarms in the web_log
    collector.
  * Add GPU key metrics (nvidia_smi collector) to
    dashboard_info.js.
  * Add allocated space metrics to the oracledb collector.
  * Restructure the eBPF collector to improve usability.
  * Add an anomaly detection collector.
  * Add a Netdata alarms collector.
  * Add a configuration option to exclude users with zero memory
    allocated to the nvidia_smi collector.
  * Add per queue charts to the rabbitmq collector.
  * Add support for HBA drives to the hpssa collector.
  * Update the cgroups collector default filtering by adding pod
    level cgroups.
  * Add a Go version of the CouchDB collector (couchdb).
  * Add collecting HTTP method per URL pattern (url_pattern option)
    to the web_log collector.
  * Add custom time fields feature to the web_log collector.
  * Add a Go version of the PowerDNS Authoritative Nameserver
    collector (powerdns).
  * Add a Go version of the PowerDNS Recursor collector
    (powerdns_recursor).
  * Add a Go version of the PowerDNS DNSdist collector (dnsdist).
  * Add a Dnsmasq DNS Forwarder collector (dnsmasq).
  * Add collecting directories size to the filecheck collector.
  * Add old systemd versions support to the systemdunits collector.
  * Add unmatched lines logging to the web_log collector.
  Notifications
  * Add API V2 support to the PagerDuty health integration.
  * Add threads support to the Google Hangouts health integration.
  * Add a Opsgenie health integration.
  Exporting
  * Add HTTP and HTTPS support to the simple exporting connector.
  Packaging/installation
  * Update React dashboard v2.11.
  * Update go.d.plugin version to v0.26.2.
  * Update eBPF collector to 0.4.9.
  * Add ability to use system libwebsockets instead of bundled
    version.
  * Update the version of libJudy that we bundle to 1.0.5-netdata2.
  Bug fixes
  * Fix crash in the eBPF plugin by initializing variables.
  * Fix sending chart definition on every data collection in alarms
    collector.
  * Fix a lock check.
  * Fix issue with chart metadata sent multiple times over ACLK.
  * Fix a buffer overflow when extracting information from a
    streaming connection.
  * Fix hostname configuration in the exporting engine.
  * Fix units and data source exporting options.
  * Fix exporting config.
  * Fix health by disabling used_file_descriptors alarm.
  * Fix GPU data filtering in the nvidia_smi collector.
  * Fix username resolution in the nvidia_smi collector.
  * Fix compilation with HTTPS disabled.
  * Fix hostname when syslog is used in syslog health integration.
  * Fix streaming buffer size.
  * Fix database endless loop when cleaning obsolete charts.
  * Disable chart obsoletion code for archived chart creation.
  * Fix Prometheus remote write exporter so that it doesn't stop
    when data is not available for dimension formatting.
  * Fix memory calculation by moving shared from cached to used
    dimension.
  * Fix parsing in the libreswan collector.
  * Fix an infinite loop in the statsd plugin
  * Disregard host tags configuration pointer.
  * Fix platform dependent printf format.
  * Fix cgroups collector resolving container names in k8s.
  * Fix python.d plugin runtime chart creation.
  * Fix race condition in rrdset_first_entry_t() and
    rrdset_last_entry_t().
  * Fix the data endpoint so that the context param is correctly
    applied to children.
  * Fix Coverity errors (CID 364045,364046).
  * Fix the elasticsearch_last_collected alarm.
  * Fix spelling error in xenstat.plugin.
  * Fix chart filtering.
  * Fix libnetdata headers to be compatible with C++.
  * Fix registry responses to remove caching.
  * Fix eBPF memory management.
  * Fix overlapping memory issue.
  * Fix response and upstream response time histogram charts in the
    web_log collector.
  * Fix logs timestamps always in UTC issue in the go.d.plugin
  * Fix collecting slave status for MariaDB v10.2.0- in the mysql
    collector
  * Fix cumulative_stats configuration option in the unbound
    collector
  * Fix parsing configuration file (respect 'include-toplevel'
    directive) in unbound collector
  * Fix handling charts with type.id >= 200 (netdata limit) in
    go.d.plugin
  * Fix parsing version query response in the mysql collector
  * Fix Netsplits chart dimensions algorithm in the the vernemq
    collector.
  * Fix a typo in dashboard_info.js for VerneMQ.
* Sat Nov 21 2020 Duarte Pousa <pousaduarte@gmail.com>
- Allow go plugin to build for Tumbleweed
* Wed Oct 14 2020 Mia Herkt <mia@0x0.st>
- Fix RPM file list
- Update to v1.26.0 (go.d.plugin 0.23.0):
  Improvements
  * Add the ability to send Agent alarm notifications to StackPulse
  * Add a way to get build configuration info from the Agent
  * Add chart for churn rates to python.d/rabbitmq
  * Add failed dim to the connection_fails alarm in the Portcheck
    alarm
  * Improve the data query when using the context parameter
  * Add a context parameter to the data endpoint
  (Netdata Cloud)
  * Change default ACLK query thread count
  * Remove leading whitespace before JSON in ACLK
  * Allow using libwebsockets without SOCKS5
  * Add information about Cloud disabled status to -W buildinfo
  (Collectors)
  * Update go.d.plugin version to v0.23.0
    + Add new filecheck collector
    + Add new systemd unit state collector
    + Add new ISC DHCP collector
  (Dashboard)
  * Add missing period in Netdata dashboard
  Bug Fixes
  * Fix systemd comment syntax
  * Fix file descriptor leak in Infiniband collector (proc.plugin)
  * Fix the data endpoint to prioritize chart over context if both
    are present
  * Fix cleanup of obsolete charts
  * Fix build for the AWS Kinesis exporting connector
  * Fix gauges for go.d.plugin/web_log collector
  * Fix locking order to address CID_362348
  * Fix chart's last accessed time during context queries
  * Fix resource leak in case of malformed request to Netdata Cloud
* Thu Oct  1 2020 Andreas Schneider <asn@cryptomilk.org>
- Move edit-config to libexeddir
- Fix conf.d path in edit-config
* Wed Sep 23 2020 Andreas Schneider <asn@cryptomilk.org>
- Fix building with go support on openSUSE 15.2
* Tue Sep 22 2020 Andreas Schneider <asn@cryptomilk.org>
- Build with python3
- Protect /etc/netdata as it contains sensitive data (passwords, secrets)
* Wed Sep 16 2020 Paolo Stivanin <info@paolostivanin.com>
- update to 1.25.0:
  Improvements
  * Add code to release memory used by the global GUID map (#9729, @stelfrag)
  * Add check for spurious wakeups
  Netdata Cloud
  * Add v2 HTTP message with compression to ACLK (#9895, @underhood)
  * Add version negotiation to ACLK (#9819, @underhood)
  * Add claimed_id for child nodes streamed to their parents (#9804, @underhood)
  * Update netdata-installer.sh to enable Netdata Cloud support in macOS (#9360, @mrbrutti)
  Collectors
  * Update go.d.plugin version to v0.22.0 (#9898, @ilyam8)
  * Add support for IP ranges to Python-based isc_dhcpd collector (#9755, @vsc55)
  * Add Network viewer charts to ebpf.plugin (#9591, @thiagoftsm)
  * Add collecting active processes limit on Linux systems (#9843, @Ancairon)
  * Improve eBPF plugin by removing unnecessary debug messages (#9754, @thiagoftsm)
  * Add CAP_SYS_CHROOT for netdata service to read LXD network interfaces (#9726, @vlvkobal)
  * Add collecting maxmemory to python.d/redis (#9767, @ilyam8)
  * Add option for multiple storage backends in python.d/varnish (#9668, @florianmagnin)
  * Dashboard
  * Update dashboard v1.4.2 (#9837, @jacekkolasa)
  * Lots of documentation improvements and bug fixes
* Wed Aug 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.24.0:
  * The v1.24.0 release of the Netdata Agent brings enhancements to the breadth of metrics we collect with a new generic Prometheus/OpenMetrics collector and enhanced storage and querying with a new multi-host database mode.
  * Add generic Prometheus/OpenMetrics collector (#9644, @ilyam8)
  * Add locking between different collectors for the same application, implemented in different technologies (#9584, @vlvkobal), (#9564, @ilyam8)
  * Implement multihost database (#9556, @stelfrag)
  * Add alarms for FreeBSD interface errors (#8340, @lassebm)
  * Many bugfixes, see https://github.com/netdata/netdata/releases/tag/v1.24.0
* Thu Jul 16 2020 Mia Herkt <mia@0x0.st>
- Update to v1.23.2:
  * Fixed a buffer overrun vulnerability in Netdata's JSON parsing
    code. This vulnerability could be used to crash Agents
    remotely, and in some circumstances, could be used in an
    arbitrary code execution (ACE) exploit.
  Improvements:
  * Add support for multiple ACLK query processing threads
  * Add Infiniband monitoring to collector proc.plugin
  * Change the HTTP method to make the IPFS collector compatible
    with 0.5.0+
  * Add support for returning headers using python.d's UrlService
  Bug fixes:
  * Fix vulnerability in JSON parsing
  * Fixed stored number accuracy
  * Fix transition from archived to active charts not generating
    alarms
  * Fix PyMySQL library to respect my.cnf parameter
  * Remove health from archived metrics
  * Update exporting engine to read the prefix option from instance
    config sections
  * Fix display error in Swagger API documentation
  * Wrap exporting engine header definitions in compilation
    conditions
  * Improve cgroups collector to autodetect unified cgroups
  * Fix CMake build failing if ACLK is disabled
  * Fix now_ms in charts.d collector to prevent tc-qos-helper
    crashes
  * Fix python.d crashes by adding a lock to stdout write function
  * Fix an issue with random crashes when updating a chart's
    metadata on the fly
  * Fix ACLK protocol version always parsed as 0
  * Fix the check condition for chart name change
  * Fix the exporting engine unit tests
  * Fix a Coverity defect for resource leaks
* Mon Jul  6 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- update to v1.23.1:
  - Lots of fixes and improvements, please see CHANGELOG.md
  - update go.d plugin to v0.19.2
* Fri May 15 2020 Mia Herkt <mia@0x0.st>
- Update to v1.22.1:
  Bug fixes:
  - Fixed the latency issue on the ACLK and suppress the diagnostics.
  - Restored old semantics of "netdata -W set" command.
  - Removed check for old alarm status.
- Changes for v1.22.0:
  Breaking Changes:
  * The previous iteration of Netdata Cloud, accessible through
    various Sign in and Nodes view (beta) buttons on the Agent
    dashboard, is deprecated in favor of the new Cloud experience.
  * Our old documentation site (docs.netdata.cloud) was replaced
    with Netdata Learn. All existing backlinks redirect to the new
    site.
  * Our localization project is no longer actively maintained.
    We're grateful for the hard work of its contributors.
  Improvements:
  * Netdata Cloud:
  - Enabled support for Netdata Cloud.
  - Added TTL headers to ACLK responses.
  - Improved the thread exit fixes in #8750.
  - Improved ACLK reconnection sequence.
  - Improved ACLK memory management and shutdown sequence.
  - Added session-id to ACLK using connect timestamp.
  * Collectors:
  - Improved the index size for the eBPF collector.
  - Added health alarm templates for the whoisquery collector.
  - Added a whoisquery collector.
  - Removed an automatic restart of apps.plugin.
  * Exporting:
  - Enabled internal statistics for the exporting engine in the
    Agent dashboard.
  - Implemented a Prometheus exporter web API endpoint.
  * Notifications:
  - Added a certificate revocation alarm for the x509check
    collector.
  - Added the ability to send Agent alarm notifications to
    Dynatrace.
  * Other:
  - Updated main copyright and links for the year 2020 in daemon
    help output.
  - Moved bind to to [web] section and update
    netdata.service.v235.in to sync it with recent changes.
  - Put old dashboard behind a prefix instead of using a script
    to switch.
  - Enabled the truthy rule in yamllint.
  - Added Borg backup, Squeezebox servers, Hiawatha web server,
    and Microsoft SQL to apps.plugin so that it can appropriately
    group them by type of service.
  * Bug fixes:
  - Fixed mdstat failed devices alarm.
  - Fixed rare race condition in old Cloud iframe.
  - Removed no-clear-notification options from portcheck health
    templates.
  - Fixed old URLs to silence Netlify's mixed content warnings.
  - Fixed master streaming fatal exits.
  - Fixed email authentiation to Cloud/Nodes View.
  - Fixed non-escaped characters in private registry URLs.
  - Fixed crash when shutting down an Agent with the ACLK
    disabled.
  - Fixed status checks for UPS devices using the apcupsd
    collector.
  - Fixed alarm notification script by adding a check to the
    Dynatrace notification method.
  - Fixed threads_creation_rate chart context in the
    python.d MySQL collector.
  - Fixed sudo check in charts.d libreswan collector to prevent
    daily security notices.
* Mon Apr 13 2020 Mia Herkt <mia@0x0.st>
- Update to v1.21.1:
  Release v1.21.1 is a hotfix release to improve the performance of
  the new React dashboard, which was merged and enabled by default in
  v1.21.0.
  The React dashboard shipped in v1.21.0 did not properly freeze
  charts that were outside of the browser's viewport. If a user who
  loaded many charts by scrolling through the dashboard, charts
  outside of their browser's viewport continued updating. This excess
  of chart updates caused all charts to update more slowly than every
  second.
  v1.21.1 includes improvements to the way the Netdata dashboard
  freezes, maintains state, and restores charts as users scroll.
* Mon Apr  6 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to v1.21.0 (go.d.plugin v0.18.0):
  Improvements:
  * Extended TLS support for 1.3.
  * Switched to the React dashboard code as the default dashboard.
  * Collectors:
  - Added a new Pulsar collector.
  - Added a new VerneMQ collector.
  - Added high precision timer support for plugins such as
    idlejitter.
  - Added an alarm to the dns_query collector that detects DNS
    query failure.
  - Added the ability to get the pod name from cgroup with
    kubectl in bare-metal deployments.
  - Added the ability to connect to non-admin user IDs for a Ceph
    storage cluster.
  - Added connections (backend) usage to Postgres monitoring.
  * Exporting:
  - Added a MongoDB connector to the exporting engine.
  - Added a Prometheus Remote Write connector to the exporting
    engine.
  - Added an AWS Kinesis connector to the exporting engine.
  Bug fixes:
  * Removed notifications from the dashboard and fixed the
    /default.html route.
  * Fixed help-tooltips styling, private registry node deletion,
    and the right-hand sidebar "jumping" on document clicks.
  * Fixed errors reported by Coverity.
  * Fixed broken pipe ignoring in apps.plugin.
  * Fixed the bytespersec chart context in the Python Apache
    collector.
  * Fixed charts.d.plugin to exit properly during Netdata
    service restart
  * Fixed minimist dependency vulnerability.
  * Fixed how SimpleService truncates Python module names.
  * Added proper prefix to Python module names during loading.
  * Fixed the flushing error threshold with the database engine.
  * Fixed memory leak for host labels streaming from slaves to
    master.
  * Fixed streaming scaling.
  * Fixed missing characters in kernel version field by encoding
    slave fields.
  * Fixed Ceph collector to get osd_perf_infos in versions 14.2
    and higher.
  * Removed extraneous commas from chart information in dashboard.
  * Removed tmem collection from xenstat_plugin to allow Netdata
    on Xen 4.13 to compile successfully.
  * Restricted messages to Google Analytics.
  * Fixed Python 3 dict access in OpenLDAP collector module.
* Wed Feb 26 2020 Martin Herkt <9+suse@cirno.systems>
- Update to v1.20.0 (go.d.plugin v0.15.0)
  Breaking Changes:
  * Removed deprecated bash collectors apache, cpu_apps, cpufreq,
    exim, hddtemp, load_average, mem_apps, mysql, nginx, phpfpm,
    postfix, squid, tomcat. If you were still using one of these
    collectors with custom configurations, you can find the new
    collector that replaces it in the supported collectors list.
  Improvements:
  * Host labels:
    + Added support for host labels
    + Improved the monitored system information detection.
    Added CPU freq & cores, RAM and disk space.
    + Started distinguishing the monitored system's (host)
    OS/Kernel etc. from those of the docker container's
    + Started creating host labels from collected system info
    + Started passing labels and container environment variables
    via the streaming protocol
    + Started sending host labels via exporting connectors
    + Added label support to alarm definitions and started
    recording them in alarm logs
    + Added support for host labels to the API responses
    + Added configurable host labels to netdata.conf
    + Added kubernetes labels
  * New collectors:
    + eBPF kernel collector
    + CockroachDB
    + squidlog: squid access log parser
  * Collector improvements:
    + apps.plugin: Created dns group, improved database group,
    improved ceph & samba groups
    + varnish: Added SMF metrics (cache on disk)
    + phpfpm: Fixed per process chart titles and readme
    + python.d: Formatted the code in all modules
    + node.d/snmp: - Added snmpv3 support, formatted the code in
    snmp.node.js
    + cgroups: Improved LXC monitoring by filtering out irrelevant
    LXC cgroups
    + litespeed: Added support for different .rtreport format
    + proc.plugin: Added pressure stall information
    + sensors: Improved collection logic
    + proc: Started monitoring network interface speed, duplex,
    operstate
    + smartd_log: Fixed the setting in the reallocated sectors
    count, by setting ATTR5 chart algorithm to absolute
    + nvidia-smi: Allow executing nvidia-smi in normal instead of
    loop mode
    + wmi: collect logon metrics, collect logical_disk disk
    latency metrics
    + weblog: handle MKCOL, PROPFIND, MOVE, SEARCH http request
    methods
    + scaleio: storage pools and sdcs metrics
  * Exporting engine:
    + Implemented the main flow for the Exporting Engine
  * Streaming:
    + Add versioning to the streaming protocol
  * Installation/Packages:
    + Improved the systemd service files, by removing unecessary
    ExecStartPre lines and moving global options to netdata.conf
  * Privacy:
    + Added support for opting out of telemetry via the
    DO_NOT_TRACK environment variable (telemetry is disabled by
    default on openSUSE)
  * Other:
    + Preparations for the next netdata cloud release. Added custom
    libmosquitto, netdata-cli and other prerequisites.
    + Applied linter fixes in shell scripts
    + Started supporting -fno-common in CFLAGS
    + Completely removed the unbound python collector (dead code)
    + Added possibility to change badges' text font color
    + Small updates to sample multi-host dashboard, dash.html
    + Added missing quoting in shell scripts
    + Bump handlebars from 4.2.0 to 4.5.3
    + Reduce log level for uv_thread_set_name_np from error to info
    + Set standard name to non-libnetdata threads (libuv, pthread)
  * Bug fixes:
    + Fixed problems reported by Coverity for eBPF collector plugin
    + Fixed invalid literal for float\(\): NN.NNt error in the
    elasticsearch python plugin, by adding terabyte unit parsing
    + Fixed timeout failing in docker containers which broke some
    python.d collectors
    + Fixed problem with the httpcheck python collector not being
    able to check URLs with the POST method, by adding body to
    the URLService. Also record the new options in httpcheck.conf
    + Fixed dbengine repeated global flushing errors and collectors
    being blocked, by dropping dirty dbengine pages if the disk
    cannot keep up
    + Fixed issue with alarm notifications occasionally ignoring
    the configured severity filter when the ROLE was set to root
    + Fixed Netlink Connection Tracker charts in the nfacct plugin
    + Fixed metric values sent via remote write to Prometheus
    backends, when using average/sum
    + Fixed unclosed brackets in softnet alarm
    + Fixed SEGFAULT when localhost initialization failed
    + Reduced the number of broken pipe error log entries,
    after a SIGKILL
    + Fixed Coverity errors by restoring support for protobuf 3.0
    + Fixed inability to disable Prometheus remote API
    + Fixed SEGFAULT from the cpuidle plugin
    + Fixed samba collector not working, due to inability to run
    sudo
    + Fixed invalid css/js resource errors when URL for slave node
    has no final / on streaming master
    + Fixed keys_redis chart in the redis collector, by populating
    keys at runtime
    + Fixed UrlService bytes decoding and logger unicode encoding
    in the python.d plugin
    + Fixed a warning in the prometheus remote write backend
    + Fixed not detecting more than one adapter in the hpssa
    collector
    + Fixed race conditions in dbengine
    + Fixed race condition with the dbenging page cache descriptors
    + Fixed dbengine dirty page flushing warning
    + Fixed missing parenthesis on alarm softnet.conf
    + Fixed "Master thread EXPORTING takes too long to exit.
    Giving up" error, by cleaning up the main exporting engine
    thread on exit
    + Fixed rabbitmq error "update() unhandled exception: invalid
    literal for int() with base 10"
    + Fixed some LGTM alerts
    + Fixed valgrind errors
    + Fixed monit collector LGTM warnings
    + Fixed the following go.d.plugin collector issues:
    . mysql: panic in Cleanup (#326)
    . unbound: gather metrics via unix socket (#319)
    . logstash: pipelines chart (#317)
    . unbound: configuration file parsing.
    . Support include mechanism. (#298)
    . logstash: pipelines metrics parsing (#293)
    . phpfpm: processes metrics parsing (#297)
* Sun Jan 19 2020 Martin Herkt <9+suse@cirno.systems>
- Also package go.d.plugin (v0.14.1)
- Update to v1.19.0
  Improvements:
  * New collectors:
    + AM2320 sensor collector plugin
    + Added parsing of /proc/pagetypeinfo to provide metrics on
    fragmentation of free memory pages
    + The unbound collector module was completely rewritten, in Go
  * Collector improvements:
    + We rewrote our web log parser in Go, drastically improving
    its flexibility and performance
    + The Kubernetes kubelet collector now reads the service
    account token and uses it for authorization. We also added a
    new default job to collect metrics from
    https://localhost:10250/metrics
    + Added a new default job to the Kubernetes coredns collector
    to collect metrics from
    http://kube-dns.kube-system.svc.cluster.local:9153/metrics
    + apps.plugin: Synced FRRouting daemons configuration with the
    frr 7.2 release
    + apps.plugin: Added process group for git-related processes
    + apps.plugin: Added balena to the container-engines
    application group
    + web_log: Treat 401 Unauthorized requests as successful
    + xenstat.plugin: Prepare for xen 4.13 by checking for check
    xenstat_vbd_error presence
    + mysql: Added galera cluster_status alarm
  * Metrics database:
    + Netdata generates alarms if the disk cannot keep up with
    data collection
  * Health:
    + Fine tune various default alarm configurations
    + Update SYN cookie alarm to be less aggressive
    + Added support for IRC alarm notifications
  Bug fixes:
  * Prevented freezes due to isolated CPUs
  * Fixed missing streaming when slave has SSL activated
  * Fixed error 421 in IRC notifications, by removing a line break
    from the message
  * proc/pagetypeinfo collection could under particular
    circumstances cause high CPU load. As a workaround,
    we disabled pagetypeinfo by default
  * Fixed incorrect memory allocation in proc plugin’s
    pagetypeinfo collector
  * Eliminated cached responses from the postgres collector
  * rabbitmq: Fixed "disk_free": "disk_free_monitoring_disabled"
    error
  * Fixed Apache module not working with letsencrypt certificate
    by allowing the python UrlService to skip tls_verify for http
    scheme
  * Fixed invalid spikes appearing in certain charts, by improving
    the incremental counter reset/wraparound detection algorithm
  * Fixed issue with unknown variables in alarm configuration
    expressions always being evaluated to zero
  * Fixed issue of automatically picking up Pi-hole stats from a
    Pi-hole instance installed on another device by disabling the
    default job that collects metrics from http://pi.hole
* Mon Oct 21 2019 Martin Herkt <9+suse@cirno.systems>
- Update to v1.18.1
  Improvements:
  * Disable slabinfo plugin by default to reduce the total number
    of metrics collected
  * Add dbengine RAM usage statistics
  * Support Google Hangouts chat notifications
  * Add CMocka unit tests
  * Add prerequisites to enable automatic updates for installations
    via the static binary (kickstart-static64.sh)
  Bug fixes:
  * Fix unbound collector timings: Convert recursion timings to
    milliseconds.
  * Fix unbound collector unhandled exceptions
  * Fix megacli collector binary search and sudo check
  * Fix Clang warnings
  * Fix python.d error logging: change chart suppress msg level
    from ERROR to INFO
  * Fix freeipmi update frequency check: was warning that 5 was too
    frequent and it was setting it to 5.
  * Fix alarm configurations not getting loaded, via better
    handling of chart names with special characters
  * Don't write HTTP response 204 messages to the logs
  * Fix build when CMocka isn't installed
  * Prevent zombie processes when a child is re-parented to netdata
    when its running in a container, by adding child process reaper
- Update to v1.18.0
  Improvements:
  * Database engine:
    + Make dbengine the default memory mode
    + Increase dbengine default cache size
    + Reduce overhead during write IO
    + Detect deadlock in dbengine page cache
    + Remove hard cap from page cache size to eliminate deadlocks.
  * New collectors:
    + SLAB cache mechanism
    + Gearman worker statistics
    + vCenter Server Appliance
    + Zookeeper servers
    + Hadoop Distributed File System (HDFS) nodes
  * Collector improvements:
    + rabbitmq: Add vhosts message metrics from /api/vhosts
    + elasticsearch: collect metrics from _cat/indices
    + mysql: collect galera cluster metrics
    + Allow configuration of the python.d launch command from
    netdata.conf
    + x509check: smtp cert check support
    + dnsmasq_dhcp: respect conf-dir,conf-file,dhcp-host options
    + plugin: respect previously running jobs after plugin restart
    + httpcheck: add current state duration chart
    + springboot2: fix context
  * Health:
    + Enable alarm templates for chart dimensions
    + Center the chart on the proper chart and time whenever an
    alarm link is clicked
  * Other:
    + API: Include family into the allmetrics JSON response
    + API: Add fixed width option to badges
    + Allow hostnames in Access Control Lists
  Bug fixes:
  * Fix issue error in alarm notification script, when executed
    without any arguments
  * Fix Coverity warnings
  * Fix dbengine consistency when a writer modifies a page
    concurrently with a reader querying its metrics
  * Fix memory leak on netdata exit
  * Fix for missing boundary data points in certain cases
  * Fix unhandled exception log warnings in the python.d collector
    orchestrator start\_job
  * Fix CORS errors when accessing the health management API,
    by permitingt x-auth-token in Access-Control-Allow-Headers
  * Fix misleading error log entries RRDSET: chart name 'XXX' on
    host 'YYY' already exists, by changing the log level for
    chart updates
  * Properly resolve all Kubernetes container names
  * Fix LGTM warnings
  * Fix agent UI redirect loop during cloud sign-in
  * Fix python.d.plugin bug in parsing configuration files with no
    explicitly defined jobs
  * Fix potential buffer overflow in the web server
  * Fix netdata group deletion on linux for uninstall script
  * Various cppcheck fixes
  * Fix handling of illegal metric timestamps in database engine
  * Fix a resource leak
  * Fix rabbitmq collector error when no vhosts are available.
* Wed Sep  4 2019 Martin Herkt <9+suse@cirno.systems>
- Update to v1.17.0
  Improvements:
  * Database engine:
    + Variable granularity support for data collection
    + Added tips on the UI to encourage users to try the new DB
    Engine, when they reach the end of their metrics history
  * Health:
    + Added support for plain text only email notifications
    + Started showing “hidden” alarm variables in the responses of
    the chart and data API calls
    + Added a new API call for alarm status counters, as a first
    step towards badges that will show the total number of alarms
  * Security:
    + Added configurable default locations for trusted CA
    certificates
    + Added safer way to get container names
    + Added SSL connection support to the python mongodb collector
  * New collectors:
    + VSphere collector
  * Archiving:
    + Added a new MongoDB backend
  * Other:
    + Added apps grouping debug messages
    + GCC warning and linting improvements
    + Added global configuration option to show charts with zero
    metrics
    + Improved the way we parse HTTP requests, so we can avoid
    issues from edge cases
  * Bug fixes:
    + Fixed sensor chips filtering in python sensors collector
    + Fixed user and group names in apps.plugin when running in a
    container, by mounting and reading /etc/passwd
    + Fixed possible buffer overflow in the JSON parser used for
    health notification silencers
    + Fixed handling of corrupted DB files in dbengine, that could
    cause netdata to not start properly
    (CRC and I/O error handling)
    + Fixed an issue with Netdata snapshots that could sometimes
    cause a problem during import
    + Fixed bug that would cause netdata to attempt to kill already
    terminated threads again, on shutdown
    + Fixed out of memory (12) errors by reimplementing the
    myopen() function family
    + Fixed wrong redirection of users signing in after clicking
    Nodes
    + Fixed python.d smartd collector increasing CPU usage
    + Fixed mongodb python collector stock configuration mistake,
    by changing password to pass
    + Fixed handling of UTF8 characters in badges and added
    International Support to the URL parser
    + Fixed nodes menu sizing (responsive)
    + Fixed issues with http redirection to https and streaming
    encryption
    + Fixed broken links to arcstat.py and arc_summary.py in
    dashboard_info.js
    + Fixed bug with the nfacct plugin that resulted in missing
    dimensions from the charts
    + Stopped anonymous stats from trying to write a log under /tmp
    + Properly delete obsolete dimensions for inactive disks in
    smartd_log
    + Fixed handling of disconnected sockets in unbound python.d
    collector
    + Fixed crash in malloc
    + Fixed issue with mysql collector that resulted in showing
    only a single slave_status chart, regardless of the number
    of replication channels
    + Fixed a segmentation fault in backends
    + Fixed spigotmc plugin bugs
    + Fixed dbengine 100%% CPU usage due to corrupted transaction
    payload handling
* Mon Jul  8 2019 Martin Herkt <9+suse@cirno.systems>
- Update to v1.16.0
  Improvements:
  * Health:
    + Easily disable alarms, by persisting the silencers
    configuration
    + Repeating alarm notifications
    + Simplified the health cmdapi tester - no setup/cleanup needed
    + Αdd last_collected alarm to the x509check collector
    + New alarm for abnormally high number of active processes.
  * Security:
    + SSL support in the web server and streaming/replication
    + Support encrypted connections to OpenTSDB backends
  * New collectors:
    + Go.d collector modules for WMI, Dnsmasq DHCP leases
    and Pihole
    + Riak KV instances collector
    + CPU performance statistics using Performance Monitoring Units
    via the perf_event_open() system call. (perf plugin)
  * Collector improvements:
    + Handle different sensor IDs for the same element in the
    freeipmi plugin
    + Increase the cpu_limit chart precision in cgroup plugin
    + Added userstats and deadlocks charts to the python mysql
    collector
    + Add perforce server process monitoring to the apps plugin
  * Backends:
    + Prometheus remote write backend
  * DB engine improvements:
    + Reduced memory requirements by 40-50%%
    + Reduced the number of pages needed to be stored and indexed
    when using memory mode = dbengine, by adding empty page
    detection
  * Rebranding:
    + Updated the netdata logo and changed links to point to the
    new website
  * Other:
    + Pass the the cloud base url parameter to the notifications
    mechanism, so that modifications to the configuration are
    respected when creating the link to the alarm
    + Improved logging, to be able to trace the
    CRITICAL: main[main] SIGPIPE received. error
  Bug fixes:
  * Fixed ram_available alarm
  * Stop monitoring /dev and /run in the disk space and inode
    usage charts
  * Fixed the monitoring of the “time” group of processes
  * Fixed compilation error PERF_COUNT_HW_REF_CPU_CYCLES'
    undeclared here in old Linux kernels (perf plugin)
  * Fixed invalid XML page error (tomcat plugin)
  * Remove obsolete monit metrics
  * Fixed Failed to parse error in adaptec_raid
  * Fixed cluster_health_nodes and cluster_stats_nodes charts in
    the elasticsearch collector
  * A modified slave chart's "name" was not properly transferred
    to the master
  * Netdata could run out of file descriptors when using the
    new DB engine
  * Fixed UI behavior when pressing the End key
  * Fixed UI link to check the configuration file,
    to open in a new tab
  * Prevented Error: 'module' object has no attribute 'Retry'
    messages from python collectors, by enforcing minimum version
    check for the UrlService library
  * Fixed typo that causes nfacct.plugin log messages to
    incorrectly show freeipmi
  * The daemon could get stuck during collection or during
    shutdown, when using the new dbengine. Reduced new dbengine IO
    utilization by forcing page alignment per dimension of chart.
  * Properly handle timeouts/no response in dns_query_time
    python collector
  * When a collector restarted after having stopped for a long
    time, the new dbengine would consume a lot of CPU resources.
  * Fixed error Assertion old_state & PG_CACHE_DESCR_ALLOCATED'
    failed` of the new dbengine. Eliminated a page cache descriptor
    race condition
  * tv.html failed to load the three left charts when accessed via
    https. Turn tv.html links to https
  * Change print level from error to info for messages about
    clearing old files from the database
  * Fixed warning regarding the x509check_last_collected_secs
    alarms. Changed the template update frequency to 60s, to match
    the chart’s update frequency
  * Email notification header lines were not terminated with \r\n
    as per the RFC
  * Some log entries would not be caught by the python web_log
    plugin. Fixed the regular expressions
  * Corrected the date used in pushbullet notifications
  * Fixed FATAL error when using the new dbengine with no direct
    I/O support, by falling back to buffered I/O
  * Fixed compatibility issues with varnish v4 (varnish collector)
  * The total number of disks in mdstat.XX_disks chart was
    displayed incorrectly.
    Fixed the "inuse" and "down" disks stacking.
  * The config option --disable-telemetry was being checked after
    restarting netdata, which means that we would still send
    anonymous statistics the first time netdata was started.
    (NOTE: Telemetry is disabled by default on openSUSE.)
  * Fixed apcupsd collector errors, by passing correct info to the
    run function.
  * apcupsd and libreswan were not enabled by default
  * Fixed incorrect module name: energi to energid
  * The nodes view did not work properly when a reverse proxy was
    configured to access netdata via paths containing subpaths
    (e.g. myserver/netdata)
  * Fix error message PLUGINSD : cannot open plugins directory
  * Corrected invalid links to web_log.conf that appear on the
    agent UI
  * Fixed ScaleIO collector endpoint paths
  * Fixed web client timeout handling in the go.d plugin httpcheck
    collector
* Tue May 21 2019 Martin Herkt <9+suse@cirno.systems>
- Update to v1.15.0
  Bug Fixes:
  * Prowl notifications were not being sent, unless another
    notification method was also active
  * Fix exception handling in the python.d plugin
  * The node applications group did not include all node processes.
  * The nvidia_smi collector displayed incorrect power usage
  * The python.d plugin would sometimes hang, because it lacked
    a connect timeout
  * The mongodb collector raised errors due to various KeyErrors
  * The smartd_log collector would show incorrect temperature
    values
  Improvements:
  * Support for aggregate node view
  * Database engine
  * New collector modules:
    + Go.d collectors for OpenVPN, the Tengine web server and
    ScaleIO (VxFlex OS) instances
    + Monitor disk access latency like ioping does
  * Energi Core daemon monitoring, suits other Bitcoin forks
  * Collector improvements:
    + Add docker swarm manager metrics to the go.d docker_engine
    collector
    + Implement unified cgroup cpu limit
    + python.d.plugin: Allow monitoring of HTTP(S) endpoints which
    require POST data and make the UrlService more flexible
  * Support the AWS Kinesis backend for long-term storage
  * Add a new "text-only" chart renderer
  * API Improvements:
    + Smarter caching of API calls. Do not cache alarms and info
    api calls and extend no-cache headers.
    + Extend the api/v1/info call response with system and
    collector information
    + k6 script for API load testing
  * Kubernetes helmchart improvements:
    + Added the init container, where sysctl params could be
    managed, to bypass the Cannot allocate memory issue
    + Better startup/shutdown of slaves and reduced memory usage
    with liveness/readiness probes and default memory mode none
    + Added the option of overriding the default settings for
    kubelet, kubeproxy and coredns collectors via values.yaml
    + Make the use of persistent volumes optional, add apiVersion
    to fix linting errors and correct the location of the env
    field
* Fri May  3 2019 Martin Herkt <9+suse@cirno.systems>
- Update to v1.14.0
  The release introduces major additions to Kubernetes monitoring,
  with tens of new charts for Kubelet, kube-proxy and coredns
  metrics, as well as significant improvements to the netdata
  helm chart.
  Two new collectors were added, to monitor Docker hub and Docker
  engine metrics.
  Finally, v1.14 adds support for version 2 cgroups, OpenLDAP
  over TLS, NVIDIA SMI free and per process memory and configurable
  syslog facilities.
  Bug Fixes:
  * Fixed problem autodetecting failed jobs in python.d plugin.
    It now properly restarts jobs that are being rechecked,
    as soon as they are able to run.
  * CouchdDB monitoring would stop sometimes with an exception.
    Fixed the unhandled exception causing the issue.
  * The netdata api deliberately returned http error 400 when
    netdata ran in memory mode none. Modified the behavior to
    return responses, regardless of the memory mode
  * The python.d plugin sometimes does not receive SIGTERM when
    netdata exits, resulting in zombie processes. Added a heartbeat
    so that the process can exit on SIGPIPE.
  * The new SMS Server Tools notifications did not handle errors
    well, resulting in cryptic error messages.
    Improved error handling.
  * Fix segmentation fault in streaming, when two dimensions had
    similar names.
  * Kubernetes Helm Chart: Fixed incorrect use of namespaces in
    ServiceAccount and ClusterRoleBinding RBAC fixes.
  * Elastic search: The option to enable HTTPS was not included in
    the config file, giving the erroneous impression that HTTPS was
    not supported. The option was added.
  * RocketChat notifications were not being sent properly.
    Added default recipients for roles in the health alarm
    notification configuration.
  Improvements:
  * go.d.plugin v0.4.0 : Docker Hub and k8s coredns collectors,
    springboot2 URI filters support.
  * go.d.plugin v0.3.1 : Add default job to run k8s_kubelet.conf,
    k8s_kubeproxy, activemq modules
  * go.d.plugin v0.3.0 : Docker engine, kubelet and kub-proxy
    collectors. x509check module reading certs from file support
  * Added unified cgroup support that includes v2 cgroups
  * Disk stats: Added preferred disk id pattern, so that users can
    see the id they prefer, when multiple ids appear for the same
    device
  * NVIDIA SMI: Added memory free and per process memory usage
    charts to the collector
  * OpenLDAP: Added TLS support, to allow monitoring of LDAPS.
  * PHP-FPM: Add health check to raise alarms when the phpfm server
    is unreachable
  * PostgreSQL: Our configuration options to connect to a DB did
    not support all possible option. Added option to connect to a
    PostreSQL instance by defining a connection string (URI).
  * python.d.plugin: There was no way to delete obsolete dimensions
    in charts created by the python.d plugin. The plugin can now
    delete dimension at runtime.
  * netdata supports sending its logs to Syslog, but the facility
    was hard-coded. We now support configurable Syslog facilities
    in netdata.conf.
  * Kubernetes Helm Chart improvements:
    + Added serviceName in statefulset spec to align with the k8s
    documentation
    + Added preStart command to persist slave machine GUIDs,
    so that pod deletion/addition during upgrades doesn't lose
    the slave history.
    + Disabled non-essential master netdata collector plugins to
    avoid duplicate data
    + Added preStop command to wait for netdata to exit gracefully
    before removing the container
    + Extended configuration file support to provide more control
    from the helm command line
    + Added option to disable Role-based access control
    + Added liveness and readiness probes.
* Fri Mar 15 2019 Martin Herkt <9+suse@cirno.systems>
- Update to v1.13.0
  netdata has taken the first step into the world of Kubernetes,
  with a beta version of a Helm chart for deployment to a k8s
  cluster and proper naming of the cgroup containers.
  We have big plans for Kubernetes, so stay tuned!
  A major refactoring of the python.d plugin has resulted in a
  dramatic decrease of the required memory, making netdata even
  more resource efficient.
  We also added charts for IPC shared memory segments and total
  memory used.
  Improvements:
  * Kubernetes: Helm chart and proper cgroup naming
  * python.d.plugin: Reduce memory usage with separate process
    for initial module checking and loaders cleanup
  * IPC shared memory charts
  * mysql module add ssl connection support
  * FreeIPMI: Have the debug option apply the internal freeipmi
    debug flags
  * Prometheus backend: Support legacy metric names for source=avg
  * Registry: Allow deleting the host we are looking at
  * SpigotMC: Use regexes for parsing.
  Bug Fixes:
  * Postgres: fix connection issues
  * Proxmox container: Fix cgroup naming and use total_* memory
    counters for cgroups
  * proc.plugin and plugins.d: Fix memory leaks
  * SpigotMC: Fix UnicodeDecodeError and py2 compatibility fix
  * Fix non-obsolete dimension deletion
  * UI: Fix incorrect icon for the streaming master
  * Docker container names: Retry renaming when a name is not found
  * apps.plugin: Don't send zeroes for empty process groups
  * go.d.plugin: Correct sha256sum check
  * Unbound module: Documentation corrected with troubleshooting
    section.
  * Streaming: Prevent UI issues upon GUID duplication between
    master and slave netdata instances
  * Linux power supply module: Fix missing zero dimensions
  * Minor fixes around plugin_directories initialization
- Update to v1.12.2
  Bug Fixes:
  * Zombie processes exist after restart netdata - add heartbeat
    to python.d plugin
  * RocketChat notifications not working
  * SIGSEGV crash during shutdown of tc plugin
  * CMake warning for nfacct plugin
  Improvements:
  * Oracledb python module
  * Show streamed servers even for users that are not signed in
* Fri Feb 22 2019 Martin Herkt <9+suse@cirno.systems>
- Drop GPG signature (no longer used)
- Drop spec compatibility with old distro versions
- Drop netdata-automake-no-dist-xz.patch
- Refresh netdata-smartd-log-path.patch
- Update to v1.12.1
  Fixes:
  * Fix SIGSEGV at startup: Don't free vars of charts that do not
    exist #5455
  * Prevent invalid Linux power supply alarms during startup #5447
  * Correct duplicate flag enum in health.h #5441
  * Remove extra 'v' for netdata version from Server response
    header #5440 and spec URL #5427
  * apcupsd - Treat ONBATT status the same as ONLINE #5435
  * Fix #5430 - LogService._get_raw_data under python3 fails on
    undecodable data #5431
  * Correct version check in UI #5429
  * Fix ERROR 405: Cannot download charts index from server -
    cpuidle handle newlines in names #5425
  * Fix clock_gettime() failures with the CLOCK_BOOTTIME argument
    [#5415]
  * Use netnsid for detecting cgroup networks; #5413
  * Python module sensors fix #5406
  * Fix ceph.chart.py for Python3 #5396 (GaetanF)
  * Fix warning condition for mem.available #5353
  * cups.plugin: Support older versions #5350
  Improvements:
  * Add driver-type option to the freeipmi plugin #5384
  * Add support of tera-byte size for Linux bcache. #5373
  * Split nfacct plugin into separate process #5361
  * Add cgroup cpu and memory limits and alarms #5172
  * Add message queue statistics #5115
- Update to v1.12.0
  Key improvements:
  * Introducing netdata.cloud, the free netdata service for all
    netdata users
  * High performance plugins with go.d.plugin (data collection
    orchestrator written in Go)
  * 7 new data collectors and 11 rewrites of existing data
    collectors for improved performance
  * A new management API for all netdata servers
  * Bind different functions of the netdata APIs to different ports
  Management API:
  Netdata now has a management API. We plan to provide a full set
  of configuration commands using this API.
  In this release, the management API supports disabling or
  silencing alarms during maintenance periods.
  For more information about the management API, check
  https://docs.netdata.cloud/web/api/health/#health-management-api
  Anonymous statistics:
  Anonymous usage information can be collected and sent to Google
  Analytics. This functionality is disabled by default in openSUSE.
  Remove /etc/netdata/.opt-out-from-anonymous-statistics to enable.
  The statistics calculated from this information will be used for:
  1. Quality assurance, to help us understand if netdata behaves as
    expected and help us identify repeating issues for certain
    distributions or environment.
  2. Usage statistics, to help us focus on the parts of netdata
    that are used the most, or help us identify the extend our
    development decisions influence the community.
  Information is sent to Netdata via two different channels:
  * Google Tag Manager is used when an agent's dashboard is
    accessed.
  * The script anonymous-statistics.sh is executed by the Netdata
    daemon, when Netdata starts, stops cleanly, or fails.
  Both methods are controlled via the same opt-out mechanism.
  For more information, check
  https://docs.netdata.cloud/docs/anonymous-statistics/
  Data collection:
  This release introduces a new Go plugin orchestrator.
  This plugin has its own github repo
  (https://github.com/netdata/go-orchestrator). It is open-source,
  using the same license and we welcome contributions.
  The orchestrator can also be used to build custom data collection
  plugins written in Go. We have used the orchestrator to write
  many new Go plugins in our go.d plugin github repo.
  For more information, check
  https://github.com/netdata/go-orchestrator#go-orchestrator-wip
  New data collectors:
  * Activemq (Go)
  * Consul (Go)
  * Lighttpd2 (Go)
  * Solr (Go)
  * Springboot2 (Go)
  * mdstat - nonredundant arrays (C)
  * CUPS printing system (C)
  High performance versions of older data collectors:
  * apache (Go)
  * dns_query (Go)
  * Freeradius (Go)
  * Httpcheck (Go)
  * Lighttpd (Go)
  * Portcheck (Go)
  * Nginx (Go)
  * cpufreq (C)
  * cpuidle (C)
  * mdstat (C)
  * power supply (C)
  Other improved data collectors:
  * Fix the python plugin clock (collectors falling behind).
  * adaptec_raid: add to python.d.conf.
  * apcupsd: Detect if UPS is online.
  * apps: Fix process statistics collection for FreeBSD.
  * apps: Properly lookup docker container name when running in ECS
  * fail2ban: Add 'Restore Ban' action.
  * go_expavar: Don't check for duplicate expvars.
  * hddtemp: Don't use disk model as dim name.
  * megacli: add to python.d.conf.
  * nvidia_smi: handle N/A values.
  * postgres: Fix integer out of range error on Postgres 11,
    fix locks count.
  * proc: Don't show zero charts for ZFS filesystem.
  * proc; Fix cached memory calculation.
  * sensors: Don't ignore 0 RPM fans on start.
  * smartd_log: check() unhandled exception: list index out of
    range.
  * SNMP: Gracefully ignore the offset if the value is not a number
  Health Monitoring:
  * Add Prowl notifications for iOS users.
  * Show count of active alarms per state in email notifications.
  * Show evaluated expression and expression variable values in
    email notifications.
  * Improve support for slack recipients (channels/users).
  * Custom notifications: Fix bug with alarm role recipients.
  Dashboards:
  * Server filtering in my-netdata menu when signed in to
    netdata.cloud
  * All units are now IEC-compliant abbreviations (KiB, MiB etc.).
  * GUI: Make entire row clickable in the registry menu showing
    the list of servers.
  Backends:
  * Do not report stale metrics to prometheus.
  Other:
  * Treat DT_UNKNOWN files as regular files.
  * API: Stricter rules for URL separators.
- Update to v1.11.1
  Improved internal database:
  Overflown incremental values (counters) do not show a zero point
  at the charts. Netdata detects the width (8bit, 16bit, 32bit,
  64bit) of each counter and properly calculates the delta when
  the counter overflows.
  The internal database format has been extended to support values
  above 64bit.
  New data collection plugins:
  * openldap, to collect performance statistics from OpenLDAP
    servers.
  * tor, to collect traffic statistics from Tor.
  * nvidia_smi to monitor NVIDIA GPUs.
  Improved data collection plugins:
  * BUG FIX: network interface names with colon (:) in them were
    incorrectly parsed and resulted in faulty data collection
    values.
  * BUG FIX: smartd_log has been refactored, has better python v2
    compatibility, and now supports SCSI smart attributes
  * cpufreq has been re-written in C - since this module if common,
    we decided to convert to an internal plugin to lower the
    pressure on the python ones. There are a few more that will be
    transitioned to C in the next release.
  * BUG FIX: sensors got some compatibility fixes and improved
    handling for lm-sensors errors.
  Health monitoring:
  * BUG FIX: max network interface speed data collection was
    faulty, which resulted in false-positive alarms on systems with
    multiple interfaces using different speeds (the speed of the
    first network interface was used for all network interfaces).
    Now the interface speed is shown as a badge.
  * alerta.io notifications got a few improvements
  * BUG FIX: conntrack_max alarm has been restored (was not working
    due to an invalid variable name referenced)
  Registry (my-netdata menu):
  * It has been refactored a bit to reveal the URLs known for each
    node and now it supports deleting individual URLs.
- Update to 1.11.0
  * Stock config files are now in /usr/lib/netdata; use the
    /etc/netdata/edit-config script to copy and edit them.
  * The query engine of netdata has been re-written to support
    query plugins. We have already added the following algorithms
    that are available for alarm, charts and badges:
    + stddev, for calculating the standard deviation on any
    time-frame.
    + ses or ema or ewma, for calculating the exponential weighted
    moving average, or single/simple exponential smoothing on
    any time-frame.
    + des, for calculating the double exponential smoothing on any
    time-frame.
    + cv or rsd, for calculating the coefficient of variation for
    any time-frame.
  Fixed security issues:
  * CVE-2018-18836 Fixed JSON Header Injection (an attacker could
    send \n encoded in the request to inject a JSON fragment into
    the response). boo#1139094
  * CVE-2018-18837 Fixed HTTP Header Injection (an attacker could
    send \n encoded in the request to inject an HTTP header into
    the response). boo#1139095
  * CVE-2018-18838 Fixed LOG Injection (an attacker could send \n
    encoded in the request to inject a log line at access.log).
    boo#1139098
  * CVE-2018-18839 Not fixed Full Path Disclosure, since these are
    intended (netdata reports the absolute filename of web files,
    alarm config files and alarm handlers).
  * Fixed Privilege Escalation by manipulating apps.plugin or
    cgroup-network error handling.
  * Fixed LOG injection (by sending URLs with \n in them).
  New data collection modules:
  * rethinkdbs for monitoring RethinkDB performance
  * proxysql for monitoring ProxySQL performance
  * litespeed for monitoring LiteSpeed web server performance.
  * uwsgi for monitoring uWSGI performance
  * unbound for monitoring the performance of Unbound DNS servers.
  * powerdns for monitoring the performance of PowerDNS servers.
  * dockerd for monitoring the health of dockerd
  * puppet for monitoring Puppet Server and Puppet DB.
  * logind for monitoring the number of active users.
  * adaptec_raid and megacli for monitoring the relevant raid
    controller
  * spigotmc for monitoring minecraft server statistics
  * boinc for monitoring Berkeley Open Infrastructure Network
    Computing clients.
  * w1sensor for monitoring multiple 1-Wire temperature sensors.
  * monit for collecting process, host, filesystem, etc checks
    from monit.
  * linux_power_supplies for monitoring Linux Power Supplies
    attributes
  Data collection orchestrators changes:
  * node.d.plugin does not use the js command any more.
  * python.d.plugin now uses monotonic clocks. There was a
    discrepancy in clocks used in netdata that resulted in a shift
    in time of python module after some time (it was missing 1 sec
    per day).
  * added MySQLService for quickly adding plugins using mysql
    queries.
  * URLService now supports self-signed certificates and supports
    custom client certificates.
  * all python.d.plugin modules that require sudo to collect
    metrics, are now disabled by default, to avoid security alarms
    on installations that do not need them.
  Improved data collection modules:
  * apps.plugin now detects changes in process file descriptors,
    also fixed a couple of memory leaks. Its default configuration
    has been enriched significantly, especially for IoT.
  * freeipmi.plugin now supports option ignore-status to ignore
    the status reported by given sensors.
  * statsd.plugin (for collecting custom APM metrics)
    + The charting thread has been optimized for lowering its CPU
    consumption when several millions of metrics are collected.
    + sets now report zeros instead of gaps when no data are
    collected
    + histograms and timers have been optimized for lowering their
    CPU consumption to support several thousands of such metrics
    are collected.
    + histograms had wrong sampling rate calculations.
    + gauges now ignore sampling rate when no sign is included in
    the value.
    + the minimum sampling rate supported is now 0.001.
    + netdata statsd is now drop-in replacement for datadog statsd
    (although statsd tags are currently ignored by netdata).
  * proc.plugin (Linux, system monitoring)
    + Unused interrupts and softirqs are not used in charts
    (this saves quite some processing power and memory on systems
    with dozens of CPU cores).
    + fixed /proc/net/snmp parsing of IcmpMsg lines that failed on
    a few systems.
    + Veritas Volume Manager disks are now recognized and named
    accordingly.
    + Now netdata collects TcpExtTCPReqQFullDrop and re-organizes
    metrics in charts to properly monitor the TCP SYN queue and
    the TCP Accept queue of the kernel.
    + Many charts that were previously reported as IPv4, were
    actually reflecting metrics for both IPv4 and IPv6.
    They have been renamed to ip.*.
    + netdata now monitors SCTP.
    + Fixed BTRFS over BCACHE sector size detection.
    + BCACHE data collection is now faster.
    + /proc/interrupts and /proc/softirqs parsing fixes.
  * diskspace.plugin (Linux, disk space usage monitoring)
    + It does not stat() excluded mount points any more (it was
    interfering with kerberos authenticated mount points).
    + several filesystems are now by default excluded from
    disk-space monitoring, to avoid breaking suspend on
    workstations.
  * python.d.plugin PYTHON modules (applications monitoring)
    + web_log module now supports virtual hosts, reports http/https
    metrics, support squid logs
    + nginx_plus module now handles non-continuous peer IDs
    + ipfs module is optimized, the use of its Pin API is now
    disabled by default and can enabled with a netdata module
    option (using the IPFS Pin API increases the load on the
    IPFS server).
    + fail2ban module now supports IPv6 too.
    + ceph module now checks permissions and properly reports
    issues
    + elasticsearch module got better error handling
    + nginx_plus module now uses upstream ip:port instead of
    transient id to identify dimensions.
    + redis, now it supports Pika, collects evited keys, fixes
    authentication issues reported and improves exception
    handling.
    + beanstalk, bug fix for yaml config loading.
    + mysql, the %% of active connections is now monitored,
    query types are also charted.
    + varnish, now it supports versions above 5.0.0
    + couchdb
    + phpfpm, now supports IPv6 too.
    + apache, now supports IPv6 too.
    + icecast
    + mongodb, added support for connect URIs
    + postgress
    + elasticsearch, now it supports versions above 6.3.0,
    fixed JSON parse errors
    + mdstat , now collects mismatch_cnt
    + openvpn_log
  * node.d.plugin NODE.JS modules
    + snmp was incorrectly parsing a new OID names as float.
  * charts.d.plugin BASH modules
    + nut now supports naming UPSes.
  Health monitoring:
  * Added variable $system.cpu.processors.
  * Added alarms for detecting abnormally high load average.
  * TCP SYN and TCP accept queue alarms, replacing the old softnet
    dropped alarm that was too generic and reported many false
    positives.
  * system alarms are now enabled on FreeBSD.
  * netdata now reads NIC speed and sets alarms on each interface
    to detect congestion.
  * Network alarms are now relaxed to avoid false positives.
  * New bcache alarms.
  * New mdstat alarms.
  * New apcupsd alarms.
  * New mysql alarms.
  * New notification methods:
    + rocket.chat
    + Microsoft Teams
    + syslog
    + fleep.io
    + Amazon SNS
  Backends:
  * Host tags are now sent to Graphite
  * Host variables are now sent to Prometheus
  Streaming:
  * Each netdata slave and proxy now filter the charts that are
    streamed. This allows exposing netdata masters to third parties
    by limiting the number of charts available at the master.
  * Fixed a bug in streaming slaves that randomly prevented them
    to resume streaming after network errors.
  * Fixed a bug that on slaves that sent duplicated chart names
    under certain conditions.
  * Fixed a bug that caused slaves to consume 100%% CPU (due to a
    misplaced lock) when multiple threads were adding dimensions
    on the same chart.
  * The receiving nodes of streaming (netdata masters and proxies)
    can now rate-limit the rate of inbound streaming requests
    received.
  * Re-worked time synchronization between netdata slaves and
    masters.
  API:
  * Badges that report time, now show "undefined" instead of
    "never".
  Dashboard:
  * Added UTC timezone to the list of available time-zones.
  * The dashboard was sending some non-HTTP compliant characters
    at the URLs that made netdata dashboards break when used under
    certain proxies.
* Tue Mar 27 2018 9+suse@cirno.systems
- Remove _service
- Add GPG signature
- Use %%license macro
- Update to v1.10.0
  * new plugins:
  - BTRFS - monitor the allocations of BTRFS filesystems (netdata can now
    properly detect when btrfs is going out of space)
  - BCACHE - monitor the caching block layer that allows building hybrid
    disks using normal HDDs and SSDs
  - Ceph - monitor ceph distributed storage
  - nginx plus - monitor the nginx+ web servers
  - libreswan - monitor IPSEC tunnels
  - Traefik - monitor traefik reverse proxies
  - icecast - monitor icecast streaming servers
  - ntpd - monitor NTP servers
  - httpcheck - monitor any remote web server
  - portcheck - monitor any remote TCP port
  - spring-boot - monitor java spring boot applications
  - dnsdist - monitor dnsdist name servers
  - hugepages - monitor the allocation of Linux hugepages
  * enhanced/improved plugins:
  - statsd
    + statsd dimensions now support the options the external plugin
    dimensions support (currently the only usable option is hidden to add
    the dimension, but make it hidden on the dashboard - a hidden
    dimension can participate in various calculations, including alarms).
    + statsd now reports the CPU usage of its threads at the netdata
    section.
    + statsd metrics are logged to access.log the first time they are
    encountered.
    + statsd metrics now accept the special value zinit to allow them get
    initialized without altering their values (this is useful if you have
    rare metrics that you need to initialize when netdata starts).
    + statsd over TCP is now a lot faster - netdata can process up to 3.5mil
    statsd metrics / second using just one core. Added options to control
    the timeouts of TCP statsd connections.
    + fixed the title and context of statsd private charts
    + statsd private charts can now be hidden from the dashboard
  - web_log
    + Added web server response timings histogram
  - containers monitoring
    + netdata now monitors systemd-nspawn containers.
    + netdata now renames charts of kubernetes containers.
    + virsh is now called with -r to avoid prompting for password
    + cgroup-network is now a lot more strict, preventing unauthorized
    privilege escalation
    + cgroup-network now searches for container processes in sub-cgroups
    too - this improves the mapping of network interfaces to containers
    + cgroup-network now works even when there are no veth interfaces
    in the system
  - system memory
    + treat slab memory as cached
    + added a new chart for monitoring the memory available for use,
    before hitting swap
    + netdata now monitors Linux hugepages and (transparent) hugepages
  - diskspace
    + support huge amounts of mountpoints - netdata was crashing with stack
    overflow due to recursion - now it is a loop, so any number of mount
    points is supported
  - network interfaces
    + moved tcp passive and active opens to a separate chart, to allow the
    TCP issues dimensions scale better by default
    + updated the information presented on TCP charts to match the latest
    v4.15 kernel source
  - postgres
    + new charts:
    checkpointer
    bgwriter
    autovacuum
    replication delta
    WAL archive
    WAL
    temporary files
    + The postgres plugin now also works when postgres is in recovery mode.
  - rabbitmq
    + added Erlang run queue chart. This is useful in conjunction with the
    existing Erlang processes chart to get a better overall idea of what's
    going on in the Erlang VM.
    + added rabbitmq information on the dashboard to complement the charts.
  - apps.plugin
    netdata prior to this version was detecting the user and group of
    processes by examining the ownership of /proc/PID/stat. Unfortunately it
    seems that the owneship of files in /proc do not change when the process
    switches user. So, netdata could not detect the user and group of
    processes that started as root and then switched to another user.
    Now netdata reads /proc/PID/status:
    + process ownship information is now accurate
    + eliminated the need to read /proc/PID/statm (all the information of
    /proc/PID/statm is available in /proc/PID/status)
    + allowed netdata to read VmSwap, so a new chart has been added to
    monitor the swap memory usage per process, user and group.
    + The new plugin is 20%% more expensive in terms of CPU. We tried hard
    to optimize it, but this is as good as it can get.
  - haproxy
    + hrsp_1xx, hrsp_2xx, hrsp_3xx, hrsp_4xx, hrsp_5xx, hrsp_other,
    hrsp_total for backands and frontends
    + qtime, ctime, rtime, ttime metrics for backend servers
    + backend servers In UP state
  - uptime
    + netdata now uses /proc/uptime when CLOCK_BOOTTIME does not report the
    same uptime. In containers CLOCK_BOOTTIME reports the uptime of the
    host, while /proc/uptime reports the uptime of the container, so now
    netdata correctly reports the uptime of the container.
  - ksm
    + removed to_scan dimension
    + the savings %% reported by netdata was less than the actual - fixed it.
  - mdstat
    + various fixes to better monitor rebuild time and rate
  - elasticsearch
    + Added several charts for translog / indices segments statistics and
    JVM buffer pool utilization, which are often helpful when evaluating
    an elasticsearch node health
  - apcupsd
    + netdata now supports monitoring multiple APC UPSes.
  - isc-dhcpd
    + netdata now also supports monitoring IPv6 leases
  - fronius
    + added a new dimension solar_consumption
    + added alarms
  - stiebeleltron
    + added alarms
  - python.d
    + python.d.plugin can now start even if /etc/netdata/python.d.conf
    is missing
    + python.d.plugin now has an internal run counter
    + the unicode decoding of the plugin has been fixed
    + the plugin now does not validate self-signed certificates
    + the plugin can not revive obsolete charts
  - charts.d
    + charts.d.plugin BASH modules can now have custom number of retries in
    case of data collection failures
  * new alarm notifications plugins:
  - alerta
  - IRC
  * web server:
  - netdata now has a new internal web server that supports a fixed number
    of threads - we call it static web server. This web server allows
    netdata to work around memory fragmentation (since the treads are fixed,
    the underlying memory allocators reuse the same memory arenas) and cpu
    utilization (we can control the number of threads that will be used by
    netdata). This is the default now.
  - now the static threads web server reports the CPU usage of each of its
    threads.
  - the HTTP response headers now include the netdata version
  * dashboard:
  - the print button now respects the URL path netdata is hosted.
  - dygraphs updated to the latest version - this fixes an issue that
    prevented netdata charts from being interactive under certain conditions
  - added dygraph theme logscale
  - fontawesome updated to version 5
  - d3 updated to the latest version (this broke c3 charts that require an
    older version)
  - added d3pie charts
  - custom dashboards can now have alarms for specific roles (all, none,
    one or more).
  - allow stacked charts to zoom vertically when dimensions are selected
  - netdata now has a global XSS protection
  - netdata now uses intersectionObserver when available - this improves the
    scrolling performance of the dashboard.
  - prevent date, time and units from wrapping at the charts legends
  - various units scaling improvements
  - added data-common-colors="NAME" chart option for custom dashboards
  - added wiki page for creating custom dashboards on Atlassian's Confluence
  - prevented a double click on the charts' toolbox to select the text of
    the buttons.
  - fixed the alignment of dashboard icons
  - added a simple js, called refresh-badges.js, to update badges on a
    custom web page
  * badges:
  - netdata badges can now be scaled
  * API:
  - added gtime parameter, for group time. This is used to request from
    netdata to return values in a different rate (i.e. gtime=60 on a X/sec
    dimension, will return X/min).
  - fixed a rounding bug in JSON generation
  - the dimensions= parameter now supports simple patterns and added option
    values match-ids and match-names to control which matches are executed
    for dimensions.
  * alarms:
  - "system.swap" alarms now send notifications with a 30 seconds delay,
    to work-around a kernel bug that incorrectly reports all swap as
    instantly used under containers
  - added alarm to predict the time a mount point will run out of inodes
  - added alerta.io notifications
  - added available memory alarm
  - removed unsupported html tags from hipchat notifications.
  - pagerduty notifications have been modified to avoid incident duplication
  - alarm definitions can now use both chart IDs and chart names (prior to
    this version only chart IDs were allowed).
  - curl options (eg for disabling SSL certificates verification) for
    alarm-notify.sh can now be defined in health_alarm_notify.conf.
  - netdata can now send notifications to IRC channels
  * backends:
  - on netdata masters, allow filtering the hosts that will be sent to
    backends with send hosts matching = * pattern.
  - improved connection error handling and added retries to allow netdata
    connect to certain backends that failed with EALREADY or EINPROGRESS.
  - json backends now receive host tags (the tags have to be formatted in a
    json friendly way)
  - re-worked the alarm that triggers when backend data are lost,
    to avoid flip-flops.
  - prometheus backends:
    + added URL option timestamps=yes|no to /api/v1/allmetrics to support
    prometheus Pushgateway
    + added netdata_info variable with the version of netdata
    + renamed netdata_host_tags to netdata_host_tags_info (the old exists
    but is deprecated and will be removed eventually)
    + when prometheus uses average metrics, netdata remembers the last
    access time the prometheus collected metrics, on a per host basis.
  * metrics streaming between netdata:
  - netdata masters and proxies now expose the version of the netdata
    collecting the metrics, not their own. So, now a netdata master shows
    on the dashboard and sends to backends the version of the netdata
    collecting the metrics
  - added stream.conf option multiple "connections = accept | deny" to allow
    or deny multiple connection for the same netdata host. The default
    remains "accept", but it is likely to be changed to no on future
    versions.
  * other:
  - added global option gap when lost iterations to control the number of
    iterations that should be lost to show a gap on the charts.
  - various fixes/improvements related to netdata logs - the main change is
    that now netdata logs the thread name that logged the message, providing
    helpful insights about the thread that complained.
  - re-worked the exit procedure of netdata to allow it cleanup properly -
    sometimes netdata was deadlocked during exit, waiting forever - now
    netdata always exits promptly
  - fixed compilation on ancient gcc versions
  - netdata was always setting itself to the idle process scheduling
    priority, even when it was configured to do otherwise. Fixed it.
* Sun Dec 17 2017 9@cirno.systems
- Update to v1.9.0
  * new features:
  - IP address ACLs
  - auto-scaling units (KB → MB → GB → TB etc.)
  - dashboard snapshots for any timeframe/resolution
  - detection of TCP overflows and dropped connections
  - detection of redis background save failures
  - export dashboards to PDF
  - flock.com and kavenegar.com alarm notifications
  - highlighting timeframes on all charts by holding Ctrl or Alt
  - monitoring of couchdb, powerdns, beanstalkd and dnsdist
  - monitoring of libvirt VMs
  - new alarms:
    1. too many tcp orphan sockets
    2. tcp memory that detects that the tcp stack is under memory pressure
    or close to giving memory errors
    3. too many tcp connections (for kernels that do not support dynamic
    allocation of connections)
  - timezone support
  - unit conversion (temperatures, time, etc.)
  * fixes/improvements:
  - better/faster dashboard scrolling
  - python.d.plugin rewritten
    + supports option autodetection_retry: SECONDS
    + the new URL service disables certificates checks by default,
    to allow self-signed certificates to work without configuration.
  - streaming:
    + netdata proxies with more than 100 slaves had a timing issue that
    caused them to crash randomly on slave reconnects. Parts of the code
    have been rewritten to get rid of the timing issue.
    + netdata slaves and proxies now have a protection that ensures they will
    never use 100%% CPU, even if the master is misbehaving.
    + expired orphaned hosts are now removed from the my-netdata menu of the
    dashboard.
    + streaming functions can now be monitored via access.log
    + streaming now transfers alarm variables too
  - web_log plugin
    + custom regex now supports parsing hostnames and IPs
    + now parses lines with error 408 (request timeout - these are a special
    case, since the request has not received by the web server, so the log
    line is incomplete)
    + now properly parses resp_length with value
  - disks under Linux are renamed using /dev/disk/by-label. An option has been
    added at netdata.conf to also allow renaming based on /dev/disk/by-id.
  - chrony is now disabled by default, because there have been reports that
    chronyc enters an infinite loop in CentOS and RHEL.
  - tomcat improvements to support flavors of the tomcat server
  - chart system.io (the total system Disk I/O) is now calculated by
    aggregating the reads and writes of all physical disks. The previous
    system.io chart (that is based on pgpgin and pgpgout from /proc/vmstat)
    is now named system.pgpgio. The key difference is that the new system.io
    now sees ZFS I/O, and it also correctly and accurately sums the real disk
    bandwidth of RAID arrays.
  - chart system.net (the total system network bandwidth) is now calculated
    by aggregating the bandwidth of all physical network interfaces and is
    common for both IPv4 and IPv6.
  - tc (QoS) charts now sort the dimensions on the legends, the same way tc
    reports them.
  - mysql (and mariadb) got new charts for galera replication
  - postgres versions <= 10 the WAL directory was named pg_xlog' and from 10
    upwards has been renamed to pg_wal
  - freeipmi.plugin got a command line option (can be given in netdata.conf)
    to ignore certain sensor IDs that are faulty.
  - minor openvpn_log, smartd, smartd_log, varnish, mdstat, dns_query_time,
    isc_dhcpd, freeradius and node.d.plugin fixes/improvements
  - netdata now supports multiple plugin directories. The setting is the same
    in netdata.conf, plugins directory = "DIRECTORY1" "DIRECTORY2" ...,
    up to 20 directories.
  - netdata now supports alarms variables. Each plugin can now define host
    global and chart local variables with static values that can be used in
    alarms' expressions.
  - dashboard:
    + hover selection of charts is now faster on all browsers
    + the dashboard is now fixed when a modal is open, preventing scrolling
    + the dashboard now uses fontawesome 5.0.1 for icons
    + chart names can now be searched with browser control-F
    + netdata now detects libvirt VM network interfaces and moves them to the
    VM section of the dashboard
    + now shows the context, resolution and plugin/module of each chart in
    tooltips
    + should now put a lot less CPU pressure on the browser when the page
    does not have focus
  - statsd:
    + metrics can now be added to statsd synthetic charts using patterns
    + dimensions added to statsd synthetic charts can automatically be renamed
    using a dictionary
    + timers and histograms now report zeros when nothing is collected
  - badges:
    + fixed a bug in netdata badges that was incorrectly matching zero values
    with the null color condition
    + added API option display_absolute to allow badges use the signed value
    for color evaluation, but present the absolute value
  - alarms/notifications:
    + warning emails sent by netdata are now a little bit more orange
    (they were a bit greenish)
    + fixed a bug in email notifications that was triggering a corrupted MIME
    match by anti-spam solutions
    + pushbullet notifications now track the devices, so that per-device
    filtering at pushbullet is possible. Also improved the formatting a bit.
    + correct priority of warnings for pushover notifications
    + alarms can now use variables like this:
    ${variable with spaces or +, -, *, / in it}
  - other:
    + access.log has been refactored to support monitoring all netdata
    operations
    + inodes monitoring is now by default disabled for mount points based on
    filesystems that do not have a maximum inode threshold (such as cephfs)
    + rabbitmq has been added to apps_groups.conf so that apps.plugin now
    monitors (cpu, memory, disk I/O, sockets, etc) rabbitmq instances
    + several email and log management apps have been added to email and logs
    targets of apps_groups.conf
    + ceph target added to apps_groups.conf to allow netdata to monitor Ceph
    + refactored several internal data collection plugins to eliminate a few
    hundreds of index lookups per second
    + netdata.conf settings that are loaded from disk, but were the same with
    the default ones, were generated commented when the server was asked to
    return its config. Now all loaded settings are generated uncommented.
    + netdata simple patterns can now extract the the wildcarded part of the
    string they match (used in statsd synthetic charts)
    + netdata simple patterns can allow escaping spaces by prefixing them
    with a backslash
- Update netdata-smartd-log-path.patch
- Remove netdata-main-return.patch (fixed upstream)
- Fix rpmlint env-script-interpreter warnings
* Sun Sep 17 2017 9@cirno.systems
- Add return statement to main function (-Wreturn-type)
  * netdata-main-return.patch
* Sun Sep 17 2017 9@cirno.systems
- Update to v1.8.0
  * fixed bugs:
  - streaming slaves consuming 100%% CPU
  - missing alarm notifications on netdata masters
  - API generating corrupted JSON
  - crashing when starting on systems without writable disks
  - python.d.plugin URLService did not support HTTP keep-alive
  - streamed charts with duplicate names
  * netdata enhancements:
  - netdata can now listen on UNIX domain sockets
  - systemd netdata.service now allows setting negative netdata
    OOM score and restarts netdata if it crashes
  * new plugins:
  - CPU thermal throttling charts
  - chrony plugin
  - Stiebel Eltron plugin to collect metrics from heat pumps and
    hot water installations from Stiebel Eltron ISG
  * improved plugins:
  - web_log bugfixes, enhancements and optimizations
    (including squid logs)
  - web_log now enables parsing HTTP/2 logs in custom_log_format
  - redis bugfixes
  - haproxy bugfixes
  - elasticsearch bugfixes and optimizations
  - rabbitmq bugfixes and optimizations
  - mdstat bugfixes
  - tomcat improvements
  - mysql improvements
  - dovecot improvements
  - postgres improvements
  - cpufreq fixed a bug that prevented accurate reporting of
    CPU frequencies.
  - cpuidle performance improvements (faster under load)
  - fail2ban bugfixes
  - SNMP plugin new uses latest net-snmp and the corrupted 64-bit
    counters encountered under certain node.js versions is fixed
  * dashboard improvements:
  - easypiecharts and gauges can now render arbitrary ranges and
    animate clockwise or counterclockwise
  - container network interfaces are now moved to the container
    section
  - containers and VMs now have summary gauges on the dashboard
  - traditionally netdata was using 1024 bits = 1 kilobit.
    It is fixed: 1000 bits = 1 kilobit.
  - netdata charts should now work on wordpress pages
  * alarms and notifications:
  - alarm-notify.sh now supports debug mode, showing the exact
    commands it runs to send notifications,
    when export NETDATA_ALARM_NOTIFY_DEBUG=1
  - alarm-notify.sh now supports setting the sender email address
    of the emails it sends
  - emails sent by alarm-notify.sh now include headers to reduce
    the possibility of them being scored as spam
  - network related alarms got new thresholds and improved badges
  - netdata now detects if the system has been suspended and
    pauses all alarms for 60 seconds on resume, to prevent false
    alarms
  - netdata alarms now support filtering based on hostname and OS
  - slack notifications now show the host that sent the alarm
  * statsd:
  - the number of fractional points supported by statsd is now
    configurable (1 to 7)
  - fixed: 95th percentile calculation on statsd histograms and
    timers was incorrectly averaging the values
  - fixed: statsd metrics with non-ASCII text were processed by
    the statsd server, but were breaking JSON data generated by
    netdata
* Thu Jul 27 2017 9@cirno.systems
- Add download_files _service
- update source tarball to match upstream copy
* Sun Jul 16 2017 9@cirno.systems
- Update to v1.7.0
  * netdata is now a fully featured statsd server
  * improved metrics streaming and replication
  * backend enhancements, including:
  - host tags and metrics filtering on the netdata side
  - rewritten prometheus support to utilize more prometheus
    features and provide more flexibility and integration options
  * now monitors ZFS, ElasticSearch, RabbitMQ, Go applications
    (via expvar), samba, squid logs (with web_log plugin).
  * improved dashboard loading times
  * custom hook support for alarms
- Update netdata-smartd-log-path.patch
* Sat Jul 15 2017 plinnell@opensuse.org
- mention patches added in last commit
  * add netdata-automake-no-dist-xz.patch
  * add netdata-logrotate-su.patch
  * add netdata-smartd-log-path.patch
* Sun Jul  9 2017 9@cirno.systems
- Adjust default smartd log path to openSUSE default
* Mon Jun 26 2017 9@cirno.systems
- Update dependencies
  * Enable more features
  * Add soft dependencies
- Build on all enabled SUSE flavors
- Improve package description
- Use upstream .service/init.d/logrotate files (virtually identical)
- Fix permissions
- Clean up %%install section (more readable)
- spec-cleaner
* Mon Apr 24 2017 jengelh@inai.de
- Do not suppress errors from user/group creation.
- Trim sensationalist wording from description.
  Replace -exec rm by just -delete.
* Fri Apr 21 2017 ndas@suse.de
- Add netdata-rpmlintrc for spec file.
- Fix url and source link.
* Thu Apr 20 2017 benedikt@g5r.eu
- Update to version 1.6.0
- Add systemd unit, init script and logrotate config from netdata git repo
* Tue Jan 24 2017 aloisio@gmx.com
- Update to version 1.5.0 (see included ChangeLog)
- Added netdata-rpmlintrc
- Spec cleanup
* Fri Jun 17 2016 nirmoy.das@suse.com
- Upgraded to 1.2.0
* Fri Apr  1 2016 nirmoy.das@suse.com
- Initial package, version: 1.0.1
